Class: Google::Apis::SecuritycenterV1::AgentDataAccessEvent
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::AgentDataAccessEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Details about a data access attempt made by an agent principal not authorized under applicable data security policy.
Instance Attribute Summary collapse
-
#event_id ⇒ String
Unique identifier for data access event.
-
#event_time ⇒ String
Timestamp of data access event.
-
#operation ⇒ String
The operation performed by the principal to access the data.
-
#principal_subject ⇒ String
The agent principal that accessed the data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentDataAccessEvent
constructor
A new instance of AgentDataAccessEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentDataAccessEvent
Returns a new instance of AgentDataAccessEvent.
326 327 328 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
Unique identifier for data access event.
Corresponds to the JSON property eventId
309 310 311 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 309 def event_id @event_id end |
#event_time ⇒ String
Timestamp of data access event.
Corresponds to the JSON property eventTime
314 315 316 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 314 def event_time @event_time end |
#operation ⇒ String
The operation performed by the principal to access the data.
Corresponds to the JSON property operation
319 320 321 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 319 def operation @operation end |
#principal_subject ⇒ String
The agent principal that accessed the data.
Corresponds to the JSON property principalSubject
324 325 326 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 324 def principal_subject @principal_subject end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
331 332 333 334 335 336 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 331 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) @operation = args[:operation] if args.key?(:operation) @principal_subject = args[:principal_subject] if args.key?(:principal_subject) end |