Class: Google::Apis::SecuritycenterV1::AttackPathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Represents one point that an attacker passes through in this attack path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttackPathNode

Returns a new instance of AttackPathNode.



816
817
818
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associated_findingsArray<Google::Apis::SecuritycenterV1::PathNodeAssociatedFinding>

The findings associated with this node in the attack path. Corresponds to the JSON property associatedFindings



786
787
788
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 786

def associated_findings
  @associated_findings
end

#attack_stepsArray<Google::Apis::SecuritycenterV1::AttackStepNode>

A list of attack step nodes that exist in this attack path node. Corresponds to the JSON property attackSteps



791
792
793
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 791

def attack_steps
  @attack_steps
end

#display_nameString

Human-readable name of this resource. Corresponds to the JSON property displayName

Returns:

  • (String)


796
797
798
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 796

def display_name
  @display_name
end

#resourceString

The name of the resource at this point in the attack path. The format of the name follows the Cloud Asset Inventory resource name format Corresponds to the JSON property resource

Returns:

  • (String)


803
804
805
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 803

def resource
  @resource
end

#resource_typeString

The supported resource type Corresponds to the JSON property resourceType

Returns:

  • (String)


809
810
811
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 809

def resource_type
  @resource_type
end

#uuidString

Unique id of the attack path node. Corresponds to the JSON property uuid

Returns:

  • (String)


814
815
816
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 814

def uuid
  @uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



821
822
823
824
825
826
827
828
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 821

def update!(**args)
  @associated_findings = args[:associated_findings] if args.key?(:associated_findings)
  @attack_steps = args[:attack_steps] if args.key?(:attack_steps)
  @display_name = args[:display_name] if args.key?(:display_name)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @uuid = args[:uuid] if args.key?(:uuid)
end