Class: Google::Apis::SecuritycenterV1::AwsOrganization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

An organization is a collection of accounts that are centrally managed together using consolidated billing, organized hierarchically with organizational units (OUs), and controlled with policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AwsOrganization

Returns a new instance of AwsOrganization.



1018
1019
1020
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier (ID) for the organization. The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits. Corresponds to the JSON property id

Returns:

  • (String)


1016
1017
1018
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1016

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1023
1024
1025
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1023

def update!(**args)
  @id = args[:id] if args.key?(:id)
end