Class: Google::Apis::SecuritycenterV1::AzureTenant
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::AzureTenant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents a Microsoft Entra tenant.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the Azure tenant.
-
#id ⇒ String
The ID of the Microsoft Entra tenant, for example, "a11aaa11-aa11-1aa1-11aa- 1aaa11a".
Instance Method Summary collapse
-
#initialize(**args) ⇒ AzureTenant
constructor
A new instance of AzureTenant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AzureTenant
Returns a new instance of AzureTenant.
1084 1085 1086 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The display name of the Azure tenant.
Corresponds to the JSON property displayName
1076 1077 1078 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1076 def display_name @display_name end |
#id ⇒ String
The ID of the Microsoft Entra tenant, for example, "a11aaa11-aa11-1aa1-11aa-
1aaa11a".
Corresponds to the JSON property id
1082 1083 1084 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1082 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1089 1090 1091 1092 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1089 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) end |