Class: Google::Apis::SecuritycenterV1::BulkMuteFindingsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Request message for bulk findings update. Note: 1. If multiple bulk update requests match the same resource, the order in which they get executed is not defined. 2. Once a bulk operation is started, there is no way to stop it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkMuteFindingsRequest

Returns a new instance of BulkMuteFindingsRequest.



1383
1384
1385
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Expression that identifies findings that should be updated. The expression is a list of zero or more restrictions combined via logical operators AND and OR. Parentheses are supported, and OR has higher precedence than AND. Restrictions have the form and may have a - character in front of them to indicate negation. The fields map to those defined in the corresponding resource. The supported operators are: * = for all value types. * >, <, `

=,<=for integer values. *:, meaning substring matching, for strings. The supported value types are: * string literals in quotes. * integer literals without quotes. * boolean literalstrueandfalsewithout quotes. Corresponds to the JSON propertyfilter`

Returns:

  • (String)


1368
1369
1370
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1368

def filter
  @filter
end

#mute_annotationString

This can be a mute configuration name or any identifier for mute/unmute of findings based on the filter. Corresponds to the JSON property muteAnnotation

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1374

def mute_annotation
  @mute_annotation
end

#mute_stateString

Optional. All findings matching the given filter will have their mute state set to this value. The default value is MUTED. Setting this to UNDEFINED will clear the mute state on all matching findings. Corresponds to the JSON property muteState

Returns:

  • (String)


1381
1382
1383
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1381

def mute_state
  @mute_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1388
1389
1390
1391
1392
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1388

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @mute_annotation = args[:mute_annotation] if args.key?(:mute_annotation)
  @mute_state = args[:mute_state] if args.key?(:mute_state)
end