Class: Google::Apis::SecuritycenterV1::Chokepoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Chokepoint

Returns a new instance of Chokepoint.



1409
1410
1411
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

List of resource names of findings associated with this chokepoint. For example, organizations/123/sources/456/findings/789. This list will have at most 100 findings. Corresponds to the JSON property relatedFindings

Returns:

  • (Array<String>)


1407
1408
1409
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1407

def related_findings
  @related_findings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1414
1415
1416
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1414

def update!(**args)
  @related_findings = args[:related_findings] if args.key?(:related_findings)
end