Class: Google::Apis::SecuritycenterV1::CloudArmor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Fields related to Google Cloud Armor findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudArmor

Returns a new instance of CloudArmor.



1459
1460
1461
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptive_protectionGoogle::Apis::SecuritycenterV1::AdaptiveProtection

Information about Google Cloud Armor Adaptive Protection. Corresponds to the JSON property adaptiveProtection



1428
1429
1430
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1428

def adaptive_protection
  @adaptive_protection
end

#attackGoogle::Apis::SecuritycenterV1::Attack

Information about DDoS attack volume and classification. Corresponds to the JSON property attack



1433
1434
1435
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1433

def attack
  @attack
end

#durationString

Duration of attack from the start until the current moment (updated every 5 minutes). Corresponds to the JSON property duration

Returns:

  • (String)


1439
1440
1441
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1439

def duration
  @duration
end

#requestsGoogle::Apis::SecuritycenterV1::Requests

Information about the requests relevant to the finding. Corresponds to the JSON property requests



1444
1445
1446
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1444

def requests
  @requests
end

#security_policyGoogle::Apis::SecuritycenterV1::SecurityPolicy

Information about the Google Cloud Armor security policy relevant to the finding. Corresponds to the JSON property securityPolicy



1450
1451
1452
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1450

def security_policy
  @security_policy
end

#threat_vectorString

Distinguish between volumetric & protocol DDoS attack and application layer attacks. For example, "L3_4" for Layer 3 and Layer 4 DDoS attacks, or "L_7" for Layer 7 DDoS attacks. Corresponds to the JSON property threatVector

Returns:

  • (String)


1457
1458
1459
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1457

def threat_vector
  @threat_vector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1464
1465
1466
1467
1468
1469
1470
1471
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1464

def update!(**args)
  @adaptive_protection = args[:adaptive_protection] if args.key?(:adaptive_protection)
  @attack = args[:attack] if args.key?(:attack)
  @duration = args[:duration] if args.key?(:duration)
  @requests = args[:requests] if args.key?(:requests)
  @security_policy = args[:security_policy] if args.key?(:security_policy)
  @threat_vector = args[:threat_vector] if args.key?(:threat_vector)
end