Class: Google::Apis::SecuritycenterV1::CloudDlpDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

The data profile associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudDlpDataProfile

Returns a new instance of CloudDlpDataProfile.



1533
1534
1535
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profileString

Name of the data profile, for example, projects/123/locations/europe/ tableProfiles/8383929. Corresponds to the JSON property dataProfile

Returns:

  • (String)


1520
1521
1522
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1520

def data_profile
  @data_profile
end

#info_typesArray<Google::Apis::SecuritycenterV1::InfoType>

Type of information detected by SDP. Info type includes name, version and sensitivity of the detected information type. Corresponds to the JSON property infoTypes



1526
1527
1528
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1526

def info_types
  @info_types
end

#parent_typeString

The resource hierarchy level at which the data profile was generated. Corresponds to the JSON property parentType

Returns:

  • (String)


1531
1532
1533
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1531

def parent_type
  @parent_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1538
1539
1540
1541
1542
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1538

def update!(**args)
  @data_profile = args[:data_profile] if args.key?(:data_profile)
  @info_types = args[:info_types] if args.key?(:info_types)
  @parent_type = args[:parent_type] if args.key?(:parent_type)
end