Class: Google::Apis::SecuritycenterV1::Compliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Contains compliance information about a security standard indicating unmet recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Compliance

Returns a new instance of Compliance.



1755
1756
1757
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idsArray<String>

Policies within the standard or benchmark, for example, A.12.4.1 Corresponds to the JSON property ids

Returns:

  • (Array<String>)


1743
1744
1745
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1743

def ids
  @ids
end

#standardString

Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


1748
1749
1750
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1748

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property version

Returns:

  • (String)


1753
1754
1755
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1753

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1760
1761
1762
1763
1764
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1760

def update!(**args)
  @ids = args[:ids] if args.key?(:ids)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end