Class: Google::Apis::SecuritycenterV1::CustomModuleValidationError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

An error encountered while validating the uploaded configuration of an Event Threat Detection Custom Module.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomModuleValidationError

Returns a new instance of CustomModuleValidationError.



2004
2005
2006
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of the error, suitable for human consumption. Required. Corresponds to the JSON property description

Returns:

  • (String)


1986
1987
1988
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1986

def description
  @description
end

#endGoogle::Apis::SecuritycenterV1::Position

A position in the uploaded text version of a module. Corresponds to the JSON property end



1991
1992
1993
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1991

def end
  @end
end

#field_pathString

The path, in RFC 8901 JSON Pointer format, to the field that failed validation. This may be left empty if no specific field is affected. Corresponds to the JSON property fieldPath

Returns:

  • (String)


1997
1998
1999
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1997

def field_path
  @field_path
end

#startGoogle::Apis::SecuritycenterV1::Position

A position in the uploaded text version of a module. Corresponds to the JSON property start



2002
2003
2004
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2002

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2009
2010
2011
2012
2013
2014
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2009

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @end = args[:end] if args.key?(:end)
  @field_path = args[:field_path] if args.key?(:field_path)
  @start = args[:start] if args.key?(:start)
end