Class: Google::Apis::SecuritycenterV1::Cve

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

CVE stands for Common Vulnerabilities and Exposures. Information from the CVE record that describes this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cve

Returns a new instance of Cve.



2097
2098
2099
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvssv3Google::Apis::SecuritycenterV1::Cvssv3

Common Vulnerability Scoring System version 3. Corresponds to the JSON property cvssv3



2046
2047
2048
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2046

def cvssv3
  @cvssv3
end

#exploit_release_dateString

Date the first publicly available exploit or PoC was released. Corresponds to the JSON property exploitReleaseDate

Returns:

  • (String)


2051
2052
2053
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2051

def exploit_release_date
  @exploit_release_date
end

#exploitation_activityString

The exploitation activity of the vulnerability in the wild. Corresponds to the JSON property exploitationActivity

Returns:

  • (String)


2056
2057
2058
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2056

def exploitation_activity
  @exploitation_activity
end

#first_exploitation_dateString

Date of the earliest known exploitation. Corresponds to the JSON property firstExploitationDate

Returns:

  • (String)


2061
2062
2063
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2061

def first_exploitation_date
  @first_exploitation_date
end

#idString

The unique identifier for the vulnerability. e.g. CVE-2021-34527 Corresponds to the JSON property id

Returns:

  • (String)


2066
2067
2068
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2066

def id
  @id
end

#impactString

The potential impact of the vulnerability if it was to be exploited. Corresponds to the JSON property impact

Returns:

  • (String)


2071
2072
2073
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2071

def impact
  @impact
end

#observed_in_the_wildBoolean Also known as: observed_in_the_wild?

Whether or not the vulnerability has been observed in the wild. Corresponds to the JSON property observedInTheWild

Returns:

  • (Boolean)


2076
2077
2078
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2076

def observed_in_the_wild
  @observed_in_the_wild
end

#referencesArray<Google::Apis::SecuritycenterV1::Reference>

Additional information about the CVE. e.g. https://cve.mitre.org/cgi-bin/ cvename.cgi?name=CVE-2021-34527 Corresponds to the JSON property references



2083
2084
2085
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2083

def references
  @references
end

#upstream_fix_availableBoolean Also known as: upstream_fix_available?

Whether upstream fix is available for the CVE. Corresponds to the JSON property upstreamFixAvailable

Returns:

  • (Boolean)


2088
2089
2090
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2088

def upstream_fix_available
  @upstream_fix_available
end

#zero_dayBoolean Also known as: zero_day?

Whether or not the vulnerability was zero day when the finding was published. Corresponds to the JSON property zeroDay

Returns:

  • (Boolean)


2094
2095
2096
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2094

def zero_day
  @zero_day
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2102

def update!(**args)
  @cvssv3 = args[:cvssv3] if args.key?(:cvssv3)
  @exploit_release_date = args[:exploit_release_date] if args.key?(:exploit_release_date)
  @exploitation_activity = args[:exploitation_activity] if args.key?(:exploitation_activity)
  @first_exploitation_date = args[:first_exploitation_date] if args.key?(:first_exploitation_date)
  @id = args[:id] if args.key?(:id)
  @impact = args[:impact] if args.key?(:impact)
  @observed_in_the_wild = args[:observed_in_the_wild] if args.key?(:observed_in_the_wild)
  @references = args[:references] if args.key?(:references)
  @upstream_fix_available = args[:upstream_fix_available] if args.key?(:upstream_fix_available)
  @zero_day = args[:zero_day] if args.key?(:zero_day)
end