Class: Google::Apis::SecuritycenterV1::DataFlowEvent
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::DataFlowEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Details about a data flow event, in which either the data is moved to or is accessed from a non-compliant geo-location, as defined in the applicable data security policy.
Instance Attribute Summary collapse
-
#event_id ⇒ String
Unique identifier for data flow event.
-
#event_time ⇒ String
Timestamp of data flow event.
-
#operation ⇒ String
The operation performed by the principal for the data flow event.
-
#principal_email ⇒ String
The email address of the principal that initiated the data flow event.
-
#violated_location ⇒ String
Non-compliant location of the principal or the data destination.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataFlowEvent
constructor
A new instance of DataFlowEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataFlowEvent
Returns a new instance of DataFlowEvent.
2185 2186 2187 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
Unique identifier for data flow event.
Corresponds to the JSON property eventId
2162 2163 2164 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2162 def event_id @event_id end |
#event_time ⇒ String
Timestamp of data flow event.
Corresponds to the JSON property eventTime
2167 2168 2169 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2167 def event_time @event_time end |
#operation ⇒ String
The operation performed by the principal for the data flow event.
Corresponds to the JSON property operation
2172 2173 2174 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2172 def operation @operation end |
#principal_email ⇒ String
The email address of the principal that initiated the data flow event. The
principal could be a user account, service account, Google group, or other.
Corresponds to the JSON property principalEmail
2178 2179 2180 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2178 def principal_email @principal_email end |
#violated_location ⇒ String
Non-compliant location of the principal or the data destination.
Corresponds to the JSON property violatedLocation
2183 2184 2185 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2183 def violated_location @violated_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2190 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) @operation = args[:operation] if args.key?(:operation) @principal_email = args[:principal_email] if args.key?(:principal_email) @violated_location = args[:violated_location] if args.key?(:violated_location) end |