Class: Google::Apis::SecuritycenterV1::Detection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Memory hash detection contributing to the binary family match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Detection

Returns a new instance of Detection.



2494
2495
2496
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binaryString

The name of the binary associated with the memory hash signature detection. Corresponds to the JSON property binary

Returns:

  • (String)


2487
2488
2489
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2487

def binary
  @binary
end

#percent_pages_matchedFloat

The percentage of memory page hashes in the signature that were matched. Corresponds to the JSON property percentPagesMatched

Returns:

  • (Float)


2492
2493
2494
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2492

def percent_pages_matched
  @percent_pages_matched
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2499
2500
2501
2502
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2499

def update!(**args)
  @binary = args[:binary] if args.key?(:binary)
  @percent_pages_matched = args[:percent_pages_matched] if args.key?(:percent_pages_matched)
end