Class: Google::Apis::SecuritycenterV1::DiscoveredWorkload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Represents discovered, customer managed workload that is not registered with the respective GCP service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveredWorkload

Returns a new instance of DiscoveredWorkload.



2541
2542
2543
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceString

The confidence in detection of this workload. Corresponds to the JSON property confidence

Returns:

  • (String)


2513
2514
2515
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2513

def confidence
  @confidence
end

#detected_relevant_hardwareBoolean Also known as: detected_relevant_hardware?

A boolean flag set to true if associated hardware strongly predicts the workload type. Corresponds to the JSON property detectedRelevantHardware

Returns:

  • (Boolean)


2519
2520
2521
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2519

def detected_relevant_hardware
  @detected_relevant_hardware
end

#detected_relevant_keywordsBoolean Also known as: detected_relevant_keywords?

A boolean flag set to true if associated keywords strongly predict the workload type. Corresponds to the JSON property detectedRelevantKeywords

Returns:

  • (Boolean)


2526
2527
2528
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2526

def detected_relevant_keywords
  @detected_relevant_keywords
end

#detected_relevant_packagesBoolean Also known as: detected_relevant_packages?

A boolean flag set to true if installed packages strongly predict the workload type. Corresponds to the JSON property detectedRelevantPackages

Returns:

  • (Boolean)


2533
2534
2535
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2533

def detected_relevant_packages
  @detected_relevant_packages
end

#workload_typeString

The type of workload. Corresponds to the JSON property workloadType

Returns:

  • (String)


2539
2540
2541
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2539

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2546
2547
2548
2549
2550
2551
2552
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2546

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @detected_relevant_hardware = args[:detected_relevant_hardware] if args.key?(:detected_relevant_hardware)
  @detected_relevant_keywords = args[:detected_relevant_keywords] if args.key?(:detected_relevant_keywords)
  @detected_relevant_packages = args[:detected_relevant_packages] if args.key?(:detected_relevant_packages)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end