Class: Google::Apis::SecuritycenterV1::EffectiveEventThreatDetectionCustomModule
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::EffectiveEventThreatDetectionCustomModule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
An EffectiveEventThreatDetectionCustomModule is the representation of an Event
Threat Detection custom module at a specified level of the resource hierarchy:
organization, folder, or project. If a custom module is inherited from a
parent organization or folder, the value of the enablement_state property in
EffectiveEventThreatDetectionCustomModule is set to the value that is
effective in the parent, instead of INHERITED. For example, if the module is
enabled in a parent organization or folder, the effective enablement_state
for the module in all child folders or projects is also enabled.
EffectiveEventThreatDetectionCustomModule is read-only.
Instance Attribute Summary collapse
-
#cloud_provider ⇒ String
The cloud provider of the custom module.
-
#config ⇒ Hash<String,Object>
Output only.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#enablement_state ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EffectiveEventThreatDetectionCustomModule
constructor
A new instance of EffectiveEventThreatDetectionCustomModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EffectiveEventThreatDetectionCustomModule
Returns a new instance of EffectiveEventThreatDetectionCustomModule.
2681 2682 2683 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_provider ⇒ String
The cloud provider of the custom module.
Corresponds to the JSON property cloudProvider
2644 2645 2646 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2644 def cloud_provider @cloud_provider end |
#config ⇒ Hash<String,Object>
Output only. Config for the effective module.
Corresponds to the JSON property config
2649 2650 2651 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2649 def config @config end |
#description ⇒ String
Output only. The description for the module.
Corresponds to the JSON property description
2654 2655 2656 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2654 def description @description end |
#display_name ⇒ String
Output only. The human readable name to be displayed for the module.
Corresponds to the JSON property displayName
2659 2660 2661 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2659 def display_name @display_name end |
#enablement_state ⇒ String
Output only. The effective state of enablement for the module at the given
level of the hierarchy.
Corresponds to the JSON property enablementState
2665 2666 2667 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2665 def enablement_state @enablement_state end |
#name ⇒ String
Output only. The resource name of the effective ETD custom module. Its format
is: * organizations/organization/eventThreatDetectionSettings/
effectiveCustomModules/module. * `folders/`folder`/
eventThreatDetectionSettings/effectiveCustomModules/`module. * projects/
project/eventThreatDetectionSettings/effectiveCustomModules/module`.
Corresponds to the JSON propertyname`
2674 2675 2676 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2674 def name @name end |
#type ⇒ String
Output only. Type for the module. e.g. CONFIGURABLE_BAD_IP.
Corresponds to the JSON property type
2679 2680 2681 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2679 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2686 2687 2688 2689 2690 2691 2692 2693 2694 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2686 def update!(**args) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @config = args[:config] if args.key?(:config) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enablement_state = args[:enablement_state] if args.key?(:enablement_state) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |