Class: Google::Apis::SecuritycenterV1::EventThreatDetectionCustomModule
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::EventThreatDetectionCustomModule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents an instance of an Event Threat Detection custom module, including its full module name, display name, enablement state, and last updated time. You can create a custom module at the organization, folder, or project level. Custom modules that you create at the organization or folder level are inherited by child folders and projects.
Instance Attribute Summary collapse
-
#ancestor_module ⇒ String
Output only.
-
#cloud_provider ⇒ String
The cloud provider of the custom module.
-
#config ⇒ Hash<String,Object>
Config for the module.
-
#description ⇒ String
The description for the module.
-
#display_name ⇒ String
The human readable name to be displayed for the module.
-
#enablement_state ⇒ String
The state of enablement for the module at the given level of the hierarchy.
-
#last_editor ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#type ⇒ String
Type for the module.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventThreatDetectionCustomModule
constructor
A new instance of EventThreatDetectionCustomModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventThreatDetectionCustomModule
Returns a new instance of EventThreatDetectionCustomModule.
2805 2806 2807 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ancestor_module ⇒ String
Output only. The closest ancestor module that this module inherits the
enablement state from. The format is the same as the
EventThreatDetectionCustomModule resource name.
Corresponds to the JSON property ancestorModule
2752 2753 2754 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2752 def ancestor_module @ancestor_module end |
#cloud_provider ⇒ String
The cloud provider of the custom module.
Corresponds to the JSON property cloudProvider
2757 2758 2759 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2757 def cloud_provider @cloud_provider end |
#config ⇒ Hash<String,Object>
Config for the module. For the resident module, its config value is defined at
this level. For the inherited module, its config value is inherited from the
ancestor module.
Corresponds to the JSON property config
2764 2765 2766 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2764 def config @config end |
#description ⇒ String
The description for the module.
Corresponds to the JSON property description
2769 2770 2771 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2769 def description @description end |
#display_name ⇒ String
The human readable name to be displayed for the module.
Corresponds to the JSON property displayName
2774 2775 2776 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2774 def display_name @display_name end |
#enablement_state ⇒ String
The state of enablement for the module at the given level of the hierarchy.
Corresponds to the JSON property enablementState
2779 2780 2781 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2779 def enablement_state @enablement_state end |
#last_editor ⇒ String
Output only. The editor the module was last updated by.
Corresponds to the JSON property lastEditor
2784 2785 2786 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2784 def last_editor @last_editor end |
#name ⇒ String
Immutable. The resource name of the Event Threat Detection custom module. Its
format is: * organizations/organization/eventThreatDetectionSettings/
customModules/module. * `folders/`folder`/eventThreatDetectionSettings/
customModules/`module. * projects/project/eventThreatDetectionSettings/
customModules/module`.
Corresponds to the JSON propertyname`
2793 2794 2795 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2793 def name @name end |
#type ⇒ String
Type for the module. e.g. CONFIGURABLE_BAD_IP.
Corresponds to the JSON property type
2798 2799 2800 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2798 def type @type end |
#update_time ⇒ String
Output only. The time the module was last updated.
Corresponds to the JSON property updateTime
2803 2804 2805 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2803 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2810 def update!(**args) @ancestor_module = args[:ancestor_module] if args.key?(:ancestor_module) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @config = args[:config] if args.key?(:config) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enablement_state = args[:enablement_state] if args.key?(:enablement_state) @last_editor = args[:last_editor] if args.key?(:last_editor) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |