Class: Google::Apis::SecuritycenterV1::File
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::File
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
File information about the related binary/library used by an executable, or the script used by a script interpreter
Instance Attribute Summary collapse
-
#contents ⇒ String
Prefix of the file contents as a JSON-encoded string.
-
#disk_path ⇒ Google::Apis::SecuritycenterV1::DiskPath
Path of the file in terms of underlying disk/partition identifiers.
-
#file_load_state ⇒ String
The load state of the file.
-
#hashed_size ⇒ Fixnum
The length in bytes of the file prefix that was hashed.
-
#operations ⇒ Array<Google::Apis::SecuritycenterV1::FileOperation>
Operation(s) performed on a file.
-
#partially_hashed ⇒ Boolean
(also: #partially_hashed?)
True when the hash covers only a prefix of the file.
-
#path ⇒ String
Absolute path of the file as a JSON encoded string.
-
#sha256 ⇒ String
SHA256 hash of the first hashed_size bytes of the file encoded as a hex string.
-
#size ⇒ Fixnum
Size of the file in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ File
constructor
A new instance of File.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ File
Returns a new instance of File.
3189 3190 3191 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
Prefix of the file contents as a JSON-encoded string.
Corresponds to the JSON property contents
3144 3145 3146 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3144 def contents @contents end |
#disk_path ⇒ Google::Apis::SecuritycenterV1::DiskPath
Path of the file in terms of underlying disk/partition identifiers.
Corresponds to the JSON property diskPath
3149 3150 3151 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3149 def disk_path @disk_path end |
#file_load_state ⇒ String
The load state of the file.
Corresponds to the JSON property fileLoadState
3154 3155 3156 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3154 def file_load_state @file_load_state end |
#hashed_size ⇒ Fixnum
The length in bytes of the file prefix that was hashed. If hashed_size == size,
any hashes reported represent the entire file.
Corresponds to the JSON property hashedSize
3160 3161 3162 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3160 def hashed_size @hashed_size end |
#operations ⇒ Array<Google::Apis::SecuritycenterV1::FileOperation>
Operation(s) performed on a file.
Corresponds to the JSON property operations
3165 3166 3167 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3165 def operations @operations end |
#partially_hashed ⇒ Boolean Also known as: partially_hashed?
True when the hash covers only a prefix of the file.
Corresponds to the JSON property partiallyHashed
3170 3171 3172 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3170 def partially_hashed @partially_hashed end |
#path ⇒ String
Absolute path of the file as a JSON encoded string.
Corresponds to the JSON property path
3176 3177 3178 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3176 def path @path end |
#sha256 ⇒ String
SHA256 hash of the first hashed_size bytes of the file encoded as a hex string.
If hashed_size == size, sha256 represents the SHA256 hash of the entire file.
Corresponds to the JSON property sha256
3182 3183 3184 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3182 def sha256 @sha256 end |
#size ⇒ Fixnum
Size of the file in bytes.
Corresponds to the JSON property size
3187 3188 3189 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3187 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 3204 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3194 def update!(**args) @contents = args[:contents] if args.key?(:contents) @disk_path = args[:disk_path] if args.key?(:disk_path) @file_load_state = args[:file_load_state] if args.key?(:file_load_state) @hashed_size = args[:hashed_size] if args.key?(:hashed_size) @operations = args[:operations] if args.key?(:operations) @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed) @path = args[:path] if args.key?(:path) @sha256 = args[:sha256] if args.key?(:sha256) @size = args[:size] if args.key?(:size) end |