Class: Google::Apis::SecuritycenterV1::Framework

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Compliance framework associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Framework

Returns a new instance of Framework.



3732
3733
3734
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryArray<String>

Category of the framework associated with the finding. E.g. Security Benchmark, or Assured Workloads Corresponds to the JSON property category

Returns:

  • (Array<String>)


3706
3707
3708
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3706

def category
  @category
end

#controlsArray<Google::Apis::SecuritycenterV1::Control>

The controls associated with the framework. Corresponds to the JSON property controls



3711
3712
3713
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3711

def controls
  @controls
end

#display_nameString

Display name of the framework. For a standard framework, this will look like e. g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined string like MyFramework Corresponds to the JSON property displayName

Returns:

  • (String)


3718
3719
3720
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3718

def display_name
  @display_name
end

#nameString

Name of the framework associated with the finding Corresponds to the JSON property name

Returns:

  • (String)


3723
3724
3725
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3723

def name
  @name
end

#typeString

Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property type

Returns:

  • (String)


3730
3731
3732
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3730

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3737
3738
3739
3740
3741
3742
3743
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3737

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @controls = args[:controls] if args.key?(:controls)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end