Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Binding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Binding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents a Kubernetes RoleBinding or ClusterRoleBinding.
Instance Attribute Summary collapse
-
#name ⇒ String
Name for the binding.
-
#ns ⇒ String
Namespace for the binding.
-
#role ⇒ Google::Apis::SecuritycenterV1::Role
Kubernetes Role or ClusterRole.
-
#subjects ⇒ Array<Google::Apis::SecuritycenterV1::Subject>
Represents one or more subjects that are bound to the role.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Binding
constructor
A new instance of GoogleCloudSecuritycenterV1Binding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Binding
Returns a new instance of GoogleCloudSecuritycenterV1Binding.
3972 3973 3974 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name for the binding.
Corresponds to the JSON property name
3954 3955 3956 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3954 def name @name end |
#ns ⇒ String
Namespace for the binding.
Corresponds to the JSON property ns
3959 3960 3961 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3959 def ns @ns end |
#role ⇒ Google::Apis::SecuritycenterV1::Role
Kubernetes Role or ClusterRole.
Corresponds to the JSON property role
3964 3965 3966 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3964 def role @role end |
#subjects ⇒ Array<Google::Apis::SecuritycenterV1::Subject>
Represents one or more subjects that are bound to the role. Not always
available for PATCH requests.
Corresponds to the JSON property subjects
3970 3971 3972 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3970 def subjects @subjects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3977 3978 3979 3980 3981 3982 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3977 def update!(**args) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) @role = args[:role] if args.key?(:role) @subjects = args[:subjects] if args.key?(:subjects) end |