Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ExternalSystem
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ExternalSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Representation of third party SIEM/SOAR fields within SCC.
Instance Attribute Summary collapse
-
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
-
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
-
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
-
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
-
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
-
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
-
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
-
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the external system.
-
#name ⇒ String
Full resource name of the external system, for example: "organizations/1234/ sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/ findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/ 123456/externalSystems/jira" Corresponds to the JSON property
name. -
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the external system.
-
#ticket_info ⇒ Google::Apis::SecuritycenterV1::TicketInfo
Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem
constructor
A new instance of GoogleCloudSecuritycenterV1ExternalSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem
Returns a new instance of GoogleCloudSecuritycenterV1ExternalSystem.
4278 4279 4280 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
Corresponds to the JSON property assignees
4220 4221 4222 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4220 def assignees @assignees end |
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
Corresponds to the JSON property caseCloseTime
4225 4226 4227 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4225 def case_close_time @case_close_time end |
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
Corresponds to the JSON property caseCreateTime
4230 4231 4232 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4230 def case_create_time @case_create_time end |
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
Corresponds to the JSON property casePriority
4235 4236 4237 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4235 def case_priority @case_priority end |
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
Corresponds to the JSON property caseSla
4240 4241 4242 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4240 def case_sla @case_sla end |
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
Corresponds to the JSON property caseUri
4245 4246 4247 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4245 def case_uri @case_uri end |
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
Corresponds to the JSON property externalSystemUpdateTime
4250 4251 4252 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4250 def external_system_update_time @external_system_update_time end |
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the
external system.
Corresponds to the JSON property externalUid
4256 4257 4258 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4256 def external_uid @external_uid end |
#name ⇒ String
Full resource name of the external system, for example: "organizations/1234/
sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/
findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/
123456/externalSystems/jira"
Corresponds to the JSON property name
4264 4265 4266 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4264 def name @name end |
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the
external system.
Corresponds to the JSON property status
4270 4271 4272 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4270 def status @status end |
#ticket_info ⇒ Google::Apis::SecuritycenterV1::TicketInfo
Information about the ticket, if any, that is being used to track the
resolution of the issue that is identified by this finding.
Corresponds to the JSON property ticketInfo
4276 4277 4278 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4276 def ticket_info @ticket_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4283 def update!(**args) @assignees = args[:assignees] if args.key?(:assignees) @case_close_time = args[:case_close_time] if args.key?(:case_close_time) @case_create_time = args[:case_create_time] if args.key?(:case_create_time) @case_priority = args[:case_priority] if args.key?(:case_priority) @case_sla = args[:case_sla] if args.key?(:case_sla) @case_uri = args[:case_uri] if args.key?(:case_uri) @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time) @external_uid = args[:external_uid] if args.key?(:external_uid) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @ticket_info = args[:ticket_info] if args.key?(:ticket_info) end |