Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1MuteConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1MuteConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of the mute config.
-
#display_name ⇒ String
The human readable name to be displayed for the mute config.
-
#expiry_time ⇒ String
Optional.
-
#filter ⇒ String
Required.
-
#most_recent_editor ⇒ String
Output only.
-
#name ⇒ String
This field will be ignored if provided on config creation.
-
#type ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1MuteConfig
constructor
A new instance of GoogleCloudSecuritycenterV1MuteConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1MuteConfig
Returns a new instance of GoogleCloudSecuritycenterV1MuteConfig.
4371 4372 4373 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4371 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the mute config was created. This field is set
by the server and will be ignored if provided on config creation.
Corresponds to the JSON property createTime
4307 4308 4309 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4307 def create_time @create_time end |
#description ⇒ String
A description of the mute config.
Corresponds to the JSON property description
4312 4313 4314 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4312 def description @description end |
#display_name ⇒ String
The human readable name to be displayed for the mute config.
Corresponds to the JSON property displayName
4317 4318 4319 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4317 def display_name @display_name end |
#expiry_time ⇒ String
Optional. The expiry of the mute config. Only applicable for dynamic configs.
If the expiry is set, when the config expires, it is removed from all findings.
Corresponds to the JSON property expiryTime
4323 4324 4325 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4323 def expiry_time @expiry_time end |
#filter ⇒ String
Required. An expression that defines the filter to apply across create/update
events of findings. While creating a filter string, be mindful of the scope in
which the mute configuration is being created. E.g., If a filter contains
project = X but is created under the project = Y scope, it might not match any
findings. The following field and operator combinations are supported: *
severity: =, : * category: =, : * resource.name: =, : * resource.
project_name: =, : * resource.project_display_name: =, : * resource.
folders.resource_folder: =, : * resource.parent_name: =, : * resource.
parent_display_name: =, : * resource.type: =, : * finding_class: =,
: * indicator.ip_addresses: =, : * indicator.domains: =, :
Corresponds to the JSON property filter
4337 4338 4339 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4337 def filter @filter end |
#most_recent_editor ⇒ String
Output only. Email address of the user who last edited the mute config. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property mostRecentEditor
4344 4345 4346 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4344 def most_recent_editor @most_recent_editor end |
#name ⇒ String
This field will be ignored if provided on config creation. Format
organizations/organization/muteConfigs/mute_config`folders/`folder`/
muteConfigs/`mute_config projects/project/muteConfigs/mute_config`
organizations/`organization`/locations/global/muteConfigs/`mute_config
folders/folder/locations/global/muteConfigs/mute_config`projects/`
project`/locations/global/muteConfigs/`mute_config
Corresponds to the JSON property name
4354 4355 4356 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4354 def name @name end |
#type ⇒ String
Optional. The type of the mute config, which determines what type of mute
state the config affects. The static mute state takes precedence over the
dynamic mute state. Immutable after creation. STATIC by default if not set
during creation.
Corresponds to the JSON property type
4362 4363 4364 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4362 def type @type end |
#update_time ⇒ String
Output only. The most recent time at which the mute config was updated. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property updateTime
4369 4370 4371 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4369 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4376 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @filter = args[:filter] if args.key?(:filter) @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |