Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Property

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

An individual name-value pair that defines a custom source property.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Property

Returns a new instance of GoogleCloudSecuritycenterV1Property.



4393
4394
4395
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the property for the custom output. Corresponds to the JSON property name

Returns:

  • (String)


4372
4373
4374
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4372

def name
  @name
end

#value_expressionGoogle::Apis::SecuritycenterV1::Expr

Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information. Corresponds to the JSON property valueExpression



4391
4392
4393
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4391

def value_expression
  @value_expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4398
4399
4400
4401
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4398

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value_expression = args[:value_expression] if args.key?(:value_expression)
end