Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceValueConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceValueConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
A resource value configuration (RVC) is a mapping configuration of user's resources to resource values. Used in Attack path simulations.
Instance Attribute Summary collapse
-
#cloud_provider ⇒ String
Cloud provider this configuration applies to Corresponds to the JSON property
cloudProvider. -
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the resource value configuration.
-
#name ⇒ String
Name for the resource value configuration Corresponds to the JSON property
name. -
#resource_labels_selector ⇒ Hash<String,String>
List of resource labels to search for, evaluated with
AND. -
#resource_type ⇒ String
Apply resource_value only to resources that match resource_type.
-
#resource_value ⇒ String
Required.
-
#scope ⇒ String
Project or folder to scope this configuration to.
-
#sensitive_data_protection_mapping ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping
Resource value mapping for Sensitive Data Protection findings.
-
#tag_values ⇒ Array<String>
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceValueConfig
constructor
A new instance of GoogleCloudSecuritycenterV1ResourceValueConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceValueConfig
Returns a new instance of GoogleCloudSecuritycenterV1ResourceValueConfig.
4830 4831 4832 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_provider ⇒ String
Cloud provider this configuration applies to
Corresponds to the JSON property cloudProvider
4765 4766 4767 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4765 def cloud_provider @cloud_provider end |
#create_time ⇒ String
Output only. Timestamp this resource value configuration was created.
Corresponds to the JSON property createTime
4770 4771 4772 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4770 def create_time @create_time end |
#description ⇒ String
Description of the resource value configuration.
Corresponds to the JSON property description
4775 4776 4777 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4775 def description @description end |
#name ⇒ String
Name for the resource value configuration
Corresponds to the JSON property name
4780 4781 4782 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4780 def name @name end |
#resource_labels_selector ⇒ Hash<String,String>
List of resource labels to search for, evaluated with AND. For example, "
resource_labels_selector":"key": "value", "env": "prod"`will match
resources with labels "key": "value"AND"env": "prod" https://cloud.google.
com/resource-manager/docs/creating-managing-labels
Corresponds to the JSON propertyresourceLabelsSelector`
4788 4789 4790 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4788 def resource_labels_selector @resource_labels_selector end |
#resource_type ⇒ String
Apply resource_value only to resources that match resource_type. resource_type
will be checked with AND of other resources. For example, "storage.
googleapis.com/Bucket" with resource_value "HIGH" will apply "HIGH" value only
to "storage.googleapis.com/Bucket" resources.
Corresponds to the JSON property resourceType
4796 4797 4798 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4796 def resource_type @resource_type end |
#resource_value ⇒ String
Required. Resource value level this expression represents
Corresponds to the JSON property resourceValue
4801 4802 4803 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4801 def resource_value @resource_value end |
#scope ⇒ String
Project or folder to scope this configuration to. For example, "project/456"
would apply this configuration only to resources in "project/456" scope will
be checked with AND of other resources.
Corresponds to the JSON property scope
4808 4809 4810 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4808 def scope @scope end |
#sensitive_data_protection_mapping ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping
Resource value mapping for Sensitive Data Protection findings. If any of these
mappings have a resource value that is not unspecified, the resource_value
field will be ignored when reading this configuration.
Corresponds to the JSON property sensitiveDataProtectionMapping
4815 4816 4817 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4815 def sensitive_data_protection_mapping @sensitive_data_protection_mapping end |
#tag_values ⇒ Array<String>
Required. Tag values combined with AND to check against. For Google Cloud
resources, they are tag value IDs in the form of "tagValues/123". Example: [ "
tagValues/123", "tagValues/456", "tagValues/789" ] https://cloud.google.com/
resource-manager/docs/tags/tags-creating-and-managing
Corresponds to the JSON property tagValues
4823 4824 4825 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4823 def tag_values @tag_values end |
#update_time ⇒ String
Output only. Timestamp this resource value configuration was last updated.
Corresponds to the JSON property updateTime
4828 4829 4830 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4828 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4835 4836 4837 4838 4839 4840 4841 4842 4843 4844 4845 4846 4847 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4835 def update!(**args) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @resource_labels_selector = args[:resource_labels_selector] if args.key?(:resource_labels_selector) @resource_type = args[:resource_type] if args.key?(:resource_type) @resource_value = args[:resource_value] if args.key?(:resource_value) @scope = args[:scope] if args.key?(:scope) @sensitive_data_protection_mapping = args[:sensitive_data_protection_mapping] if args.key?(:sensitive_data_protection_mapping) @tag_values = args[:tag_values] if args.key?(:tag_values) @update_time = args[:update_time] if args.key?(:update_time) end |