Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1p1beta1Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Resource

Returns a new instance of GoogleCloudSecuritycenterV1p1beta1Resource.



5221
5222
5223
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#foldersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1p1beta1Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



5193
5194
5195
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5193

def folders
  @folders
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


5199
5200
5201
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5199

def name
  @name
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


5204
5205
5206
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5204

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


5209
5210
5211
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5209

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


5214
5215
5216
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5214

def project
  @project
end

#project_display_nameString

The project id that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


5219
5220
5221
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5219

def project_display_name
  @project_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5226
5227
5228
5229
5230
5231
5232
5233
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5226

def update!(**args)
  @folders = args[:folders] if args.key?(:folders)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
end