Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AgentDataAccessEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Details about a data access attempt made by an agent principal not authorized under applicable data security policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AgentDataAccessEvent

Returns a new instance of GoogleCloudSecuritycenterV2AgentDataAccessEvent.



5609
5610
5611
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

Unique identifier for data access event. Corresponds to the JSON property eventId

Returns:

  • (String)


5592
5593
5594
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5592

def event_id
  @event_id
end

#event_timeString

Timestamp of data access event. Corresponds to the JSON property eventTime

Returns:

  • (String)


5597
5598
5599
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5597

def event_time
  @event_time
end

#operationString

The operation performed by the principal to access the data. Corresponds to the JSON property operation

Returns:

  • (String)


5602
5603
5604
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5602

def operation
  @operation
end

#principal_subjectString

The agent principal that accessed the data. Corresponds to the JSON property principalSubject

Returns:

  • (String)


5607
5608
5609
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5607

def principal_subject
  @principal_subject
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5614
5615
5616
5617
5618
5619
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5614

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_time = args[:event_time] if args.key?(:event_time)
  @operation = args[:operation] if args.key?(:operation)
  @principal_subject = args[:principal_subject] if args.key?(:principal_subject)
end