Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AiModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Contains information about the AI model associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel

Returns a new instance of GoogleCloudSecuritycenterV2AiModel.



5666
5667
5668
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_platformString

The platform on which the model is deployed. Corresponds to the JSON property deploymentPlatform

Returns:

  • (String)


5629
5630
5631
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5629

def deployment_platform
  @deployment_platform
end

#display_nameString

The user defined display name of model. Ex. baseline-classification-model Corresponds to the JSON property displayName

Returns:

  • (String)


5634
5635
5636
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5634

def display_name
  @display_name
end

#domainString

The domain of the model, for example, “image-classification”. Corresponds to the JSON property domain

Returns:

  • (String)


5639
5640
5641
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5639

def domain
  @domain
end

#libraryString

The name of the model library, for example, “transformers”. Corresponds to the JSON property library

Returns:

  • (String)


5644
5645
5646
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5644

def library
  @library
end

#locationString

The region in which the model is used, for example, “us-central1”. Corresponds to the JSON property location

Returns:

  • (String)


5649
5650
5651
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5649

def location
  @location
end

#nameString

The name of the AI model, for example, "gemini:1.0.0". Corresponds to the JSON property name

Returns:

  • (String)


5654
5655
5656
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5654

def name
  @name
end

#publisherString

The publisher of the model, for example, “google” or “nvidia”. Corresponds to the JSON property publisher

Returns:

  • (String)


5659
5660
5661
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5659

def publisher
  @publisher
end

#usage_categoryString

The purpose of the model, for example, "Inteference" or "Training". Corresponds to the JSON property usageCategory

Returns:

  • (String)


5664
5665
5666
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5664

def usage_category
  @usage_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5671

def update!(**args)
  @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
  @library = args[:library] if args.key?(:library)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @publisher = args[:publisher] if args.key?(:publisher)
  @usage_category = args[:usage_category] if args.key?(:usage_category)
end