Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AttackExposure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

An attack exposure contains the results of an attack path simulation run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AttackExposure

Returns a new instance of GoogleCloudSecuritycenterV2AttackExposure.



5879
5880
5881
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_exposure_resultString

The resource name of the attack path simulation result that contains the details regarding this attack exposure score. Example: organizations/123/ simulations/456/attackExposureResults/789 Corresponds to the JSON property attackExposureResult

Returns:

  • (String)


5841
5842
5843
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5841

def attack_exposure_result
  @attack_exposure_result
end

#exposed_high_value_resources_countFixnum

The number of high value resources that are exposed as a result of this finding. Corresponds to the JSON property exposedHighValueResourcesCount

Returns:

  • (Fixnum)


5847
5848
5849
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5847

def exposed_high_value_resources_count
  @exposed_high_value_resources_count
end

#exposed_low_value_resources_countFixnum

The number of high value resources that are exposed as a result of this finding. Corresponds to the JSON property exposedLowValueResourcesCount

Returns:

  • (Fixnum)


5853
5854
5855
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5853

def exposed_low_value_resources_count
  @exposed_low_value_resources_count
end

#exposed_medium_value_resources_countFixnum

The number of medium value resources that are exposed as a result of this finding. Corresponds to the JSON property exposedMediumValueResourcesCount

Returns:

  • (Fixnum)


5859
5860
5861
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5859

def exposed_medium_value_resources_count
  @exposed_medium_value_resources_count
end

#latest_calculation_timeString

The most recent time the attack exposure was updated on this finding. Corresponds to the JSON property latestCalculationTime

Returns:

  • (String)


5864
5865
5866
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5864

def latest_calculation_time
  @latest_calculation_time
end

#scoreFloat

A number between 0 (inclusive) and infinity that represents how important this finding is to remediate. The higher the score, the more important it is to remediate. Corresponds to the JSON property score

Returns:

  • (Float)


5871
5872
5873
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5871

def score
  @score
end

#stateString

Output only. What state this AttackExposure is in. This captures whether or not an attack exposure has been calculated or not. Corresponds to the JSON property state

Returns:

  • (String)


5877
5878
5879
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5877

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5884

def update!(**args)
  @attack_exposure_result = args[:attack_exposure_result] if args.key?(:attack_exposure_result)
  @exposed_high_value_resources_count = args[:exposed_high_value_resources_count] if args.key?(:exposed_high_value_resources_count)
  @exposed_low_value_resources_count = args[:exposed_low_value_resources_count] if args.key?(:exposed_low_value_resources_count)
  @exposed_medium_value_resources_count = args[:exposed_medium_value_resources_count] if args.key?(:exposed_medium_value_resources_count)
  @latest_calculation_time = args[:latest_calculation_time] if args.key?(:latest_calculation_time)
  @score = args[:score] if args.key?(:score)
  @state = args[:state] if args.key?(:state)
end