Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AwsOrganization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

An organization is a collection of accounts that are centrally managed together using consolidated billing, organized hierarchically with organizational units (OUs), and controlled with policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AwsOrganization

Returns a new instance of GoogleCloudSecuritycenterV2AwsOrganization.



5968
5969
5970
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier (ID) for the organization. The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits. Corresponds to the JSON property id

Returns:

  • (String)


5966
5967
5968
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5966

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5973
5974
5975
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5973

def update!(**args)
  @id = args[:id] if args.key?(:id)
end