Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
Instance Attribute Summary collapse
-
#management_groups ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureManagementGroup>
A list of Azure management groups associated with the resource, ordered from lowest level (closest to the subscription) to highest level.
-
#resource_group ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureResourceGroup
Represents an Azure resource group.
-
#subscription ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureSubscription
Represents an Azure subscription.
-
#tenant ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureTenant
Represents a Microsoft Entra tenant.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AzureMetadata
constructor
A new instance of GoogleCloudSecuritycenterV2AzureMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AzureMetadata
Returns a new instance of GoogleCloudSecuritycenterV2AzureMetadata.
6002 6003 6004 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#management_groups ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureManagementGroup>
A list of Azure management groups associated with the resource, ordered from
lowest level (closest to the subscription) to highest level.
Corresponds to the JSON property managementGroups
5985 5986 5987 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5985 def management_groups @management_groups end |
#resource_group ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureResourceGroup
Represents an Azure resource group.
Corresponds to the JSON property resourceGroup
5990 5991 5992 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5990 def resource_group @resource_group end |
#subscription ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureSubscription
Represents an Azure subscription.
Corresponds to the JSON property subscription
5995 5996 5997 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5995 def subscription @subscription end |
#tenant ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureTenant
Represents a Microsoft Entra tenant.
Corresponds to the JSON property tenant
6000 6001 6002 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6000 def tenant @tenant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6007 6008 6009 6010 6011 6012 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6007 def update!(**args) @management_groups = args[:management_groups] if args.key?(:management_groups) @resource_group = args[:resource_group] if args.key?(:resource_group) @subscription = args[:subscription] if args.key?(:subscription) @tenant = args[:tenant] if args.key?(:tenant) end |