Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Binding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Binding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents a Kubernetes RoleBinding or ClusterRoleBinding.
Instance Attribute Summary collapse
-
#name ⇒ String
Name for the binding.
-
#ns ⇒ String
Namespace for the binding.
-
#role ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Role
Kubernetes Role or ClusterRole.
-
#subjects ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Subject>
Represents one or more subjects that are bound to the role.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Binding
constructor
A new instance of GoogleCloudSecuritycenterV2Binding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Binding
Returns a new instance of GoogleCloudSecuritycenterV2Binding.
6365 6366 6367 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name for the binding.
Corresponds to the JSON property name
6347 6348 6349 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6347 def name @name end |
#ns ⇒ String
Namespace for the binding.
Corresponds to the JSON property ns
6352 6353 6354 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6352 def ns @ns end |
#role ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Role
Kubernetes Role or ClusterRole.
Corresponds to the JSON property role
6357 6358 6359 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6357 def role @role end |
#subjects ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Subject>
Represents one or more subjects that are bound to the role. Not always
available for PATCH requests.
Corresponds to the JSON property subjects
6363 6364 6365 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6363 def subjects @subjects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6370 6371 6372 6373 6374 6375 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6370 def update!(**args) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) @role = args[:role] if args.key?(:role) @subjects = args[:subjects] if args.key?(:subjects) end |