Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudDlpDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

The data profile associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudDlpDataProfile

Returns a new instance of GoogleCloudSecuritycenterV2CloudDlpDataProfile.



6470
6471
6472
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profileString

Name of the data profile, for example, projects/123/locations/europe/ tableProfiles/8383929. Corresponds to the JSON property dataProfile

Returns:

  • (String)


6457
6458
6459
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6457

def data_profile
  @data_profile
end

#info_typesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2InfoType>

Type of information detected by SDP. Info type includes name, version and sensitivity of the detected information type. Corresponds to the JSON property infoTypes



6463
6464
6465
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6463

def info_types
  @info_types
end

#parent_typeString

The resource hierarchy level at which the data profile was generated. Corresponds to the JSON property parentType

Returns:

  • (String)


6468
6469
6470
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6468

def parent_type
  @parent_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6475
6476
6477
6478
6479
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6475

def update!(**args)
  @data_profile = args[:data_profile] if args.key?(:data_profile)
  @info_types = args[:info_types] if args.key?(:info_types)
  @parent_type = args[:parent_type] if args.key?(:parent_type)
end