Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudLoggingEntry
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudLoggingEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Metadata taken from a Cloud Logging LogEntry
Instance Attribute Summary collapse
-
#insert_id ⇒ String
A unique identifier for the log entry.
-
#log_id ⇒ String
The type of the log (part of
log_name.log_nameis the resource name of the log to which this log entry belongs). -
#resource_container ⇒ String
The organization, folder, or project of the monitored resource that produced this log entry.
-
#timestamp ⇒ String
The time the event described by the log entry occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudLoggingEntry
constructor
A new instance of GoogleCloudSecuritycenterV2CloudLoggingEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudLoggingEntry
Returns a new instance of GoogleCloudSecuritycenterV2CloudLoggingEntry.
6141 6142 6143 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insert_id ⇒ String
A unique identifier for the log entry.
Corresponds to the JSON property insertId
6120 6121 6122 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6120 def insert_id @insert_id end |
#log_id ⇒ String
The type of the log (part of log_name. log_name is the resource name of
the log to which this log entry belongs). For example: cloudresourcemanager.
googleapis.com/activity Note that this field is not URL-encoded, unlike in
LogEntry.
Corresponds to the JSON property logId
6128 6129 6130 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6128 def log_id @log_id end |
#resource_container ⇒ String
The organization, folder, or project of the monitored resource that produced
this log entry.
Corresponds to the JSON property resourceContainer
6134 6135 6136 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6134 def resource_container @resource_container end |
#timestamp ⇒ String
The time the event described by the log entry occurred.
Corresponds to the JSON property timestamp
6139 6140 6141 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6139 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6146 6147 6148 6149 6150 6151 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6146 def update!(**args) @insert_id = args[:insert_id] if args.key?(:insert_id) @log_id = args[:log_id] if args.key?(:log_id) @resource_container = args[:resource_container] if args.key?(:resource_container) @timestamp = args[:timestamp] if args.key?(:timestamp) end |