Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Compliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Contains compliance information about a security standard indicating unmet recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Compliance

Returns a new instance of GoogleCloudSecuritycenterV2Compliance.



6645
6646
6647
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idsArray<String>

Policies within the standard or benchmark, for example, A.12.4.1 Corresponds to the JSON property ids

Returns:

  • (Array<String>)


6633
6634
6635
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6633

def ids
  @ids
end

#standardString

Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


6638
6639
6640
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6638

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property version

Returns:

  • (String)


6643
6644
6645
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6643

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6650
6651
6652
6653
6654
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6650

def update!(**args)
  @ids = args[:ids] if args.key?(:ids)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end