Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Connection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Contains information about the IP connection associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Connection

Returns a new instance of GoogleCloudSecuritycenterV2Connection.



6720
6721
6722
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationIp

Returns:

  • (String)


6698
6699
6700
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6698

def destination_ip
  @destination_ip
end

#destination_portFixnum

Destination port. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


6703
6704
6705
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6703

def destination_port
  @destination_port
end

#protocolString

IANA Internet Protocol Number such as TCP(6) and UDP(17). Corresponds to the JSON property protocol

Returns:

  • (String)


6708
6709
6710
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6708

def protocol
  @protocol
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


6713
6714
6715
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6713

def source_ip
  @source_ip
end

#source_portFixnum

Source port. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


6718
6719
6720
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6718

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6725
6726
6727
6728
6729
6730
6731
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6725

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_port = args[:source_port] if args.key?(:source_port)
end