Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Container

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Container associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Container

Returns a new instance of GoogleCloudSecuritycenterV2Container.



6744
6745
6746
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time that the container was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6720
6721
6722
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6720

def create_time
  @create_time
end

#image_idString

Optional container image ID, if provided by the container runtime. Uniquely identifies the container image launched using a container image digest. Corresponds to the JSON property imageId

Returns:

  • (String)


6726
6727
6728
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6726

def image_id
  @image_id
end

#labelsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Label>

Container labels, as provided by the container runtime. Corresponds to the JSON property labels



6731
6732
6733
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6731

def labels
  @labels
end

#nameString

Name of the container. Corresponds to the JSON property name

Returns:

  • (String)


6736
6737
6738
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6736

def name
  @name
end

#uriString

Container image URI provided when configuring a pod or container. This string can identify a container image version using mutable tags. Corresponds to the JSON property uri

Returns:

  • (String)


6742
6743
6744
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6742

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6749
6750
6751
6752
6753
6754
6755
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6749

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @image_id = args[:image_id] if args.key?(:image_id)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uri = args[:uri] if args.key?(:uri)
end