Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Cve

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

CVE stands for Common Vulnerabilities and Exposures. Information from the CVE record that describes this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Cve

Returns a new instance of GoogleCloudSecuritycenterV2Cve.



6902
6903
6904
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvssv3Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Cvssv3

Common Vulnerability Scoring System version 3. Corresponds to the JSON property cvssv3



6851
6852
6853
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6851

def cvssv3
  @cvssv3
end

#exploit_release_dateString

Date the first publicly available exploit or PoC was released. Corresponds to the JSON property exploitReleaseDate

Returns:

  • (String)


6856
6857
6858
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6856

def exploit_release_date
  @exploit_release_date
end

#exploitation_activityString

The exploitation activity of the vulnerability in the wild. Corresponds to the JSON property exploitationActivity

Returns:

  • (String)


6861
6862
6863
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6861

def exploitation_activity
  @exploitation_activity
end

#first_exploitation_dateString

Date of the earliest known exploitation. Corresponds to the JSON property firstExploitationDate

Returns:

  • (String)


6866
6867
6868
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6866

def first_exploitation_date
  @first_exploitation_date
end

#idString

The unique identifier for the vulnerability. e.g. CVE-2021-34527 Corresponds to the JSON property id

Returns:

  • (String)


6871
6872
6873
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6871

def id
  @id
end

#impactString

The potential impact of the vulnerability if it was to be exploited. Corresponds to the JSON property impact

Returns:

  • (String)


6876
6877
6878
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6876

def impact
  @impact
end

#observed_in_the_wildBoolean Also known as: observed_in_the_wild?

Whether or not the vulnerability has been observed in the wild. Corresponds to the JSON property observedInTheWild

Returns:

  • (Boolean)


6881
6882
6883
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6881

def observed_in_the_wild
  @observed_in_the_wild
end

#referencesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Reference>

Additional information about the CVE. e.g. https://cve.mitre.org/cgi-bin/ cvename.cgi?name=CVE-2021-34527 Corresponds to the JSON property references



6888
6889
6890
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6888

def references
  @references
end

#upstream_fix_availableBoolean Also known as: upstream_fix_available?

Whether upstream fix is available for the CVE. Corresponds to the JSON property upstreamFixAvailable

Returns:

  • (Boolean)


6893
6894
6895
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6893

def upstream_fix_available
  @upstream_fix_available
end

#zero_dayBoolean Also known as: zero_day?

Whether or not the vulnerability was zero day when the finding was published. Corresponds to the JSON property zeroDay

Returns:

  • (Boolean)


6899
6900
6901
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6899

def zero_day
  @zero_day
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6907

def update!(**args)
  @cvssv3 = args[:cvssv3] if args.key?(:cvssv3)
  @exploit_release_date = args[:exploit_release_date] if args.key?(:exploit_release_date)
  @exploitation_activity = args[:exploitation_activity] if args.key?(:exploitation_activity)
  @first_exploitation_date = args[:first_exploitation_date] if args.key?(:first_exploitation_date)
  @id = args[:id] if args.key?(:id)
  @impact = args[:impact] if args.key?(:impact)
  @observed_in_the_wild = args[:observed_in_the_wild] if args.key?(:observed_in_the_wild)
  @references = args[:references] if args.key?(:references)
  @upstream_fix_available = args[:upstream_fix_available] if args.key?(:upstream_fix_available)
  @zero_day = args[:zero_day] if args.key?(:zero_day)
end