Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Details about data retention deletion violations, in which the data is non- compliant based on their retention or deletion time, as defined in the applicable data security policy. The Data Retention Deletion (DRD) control is a control of the DSPM (Data Security Posture Management) suite that enables organizations to manage data retention and deletion policies in compliance with regulations, such as GDPR and CRPA. DRD supports two primary policy types: maximum storage length (max TTL) and minimum storage length (min TTL). Both are aimed at helping organizations meet regulatory and data management commitments.
Instance Attribute Summary collapse
-
#data_object_count ⇒ Fixnum
Number of objects that violated the policy for this resource.
-
#event_detection_time ⇒ String
Timestamp indicating when the event was detected.
-
#event_type ⇒ String
Type of the DRD event.
-
#max_retention_allowed ⇒ String
Maximum duration of retention allowed from the DRD control.
-
#min_retention_allowed ⇒ String
Min duration of retention allowed from the DSPM retention control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataRetentionDeletionEvent
constructor
A new instance of GoogleCloudSecuritycenterV2DataRetentionDeletionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataRetentionDeletionEvent
Returns a new instance of GoogleCloudSecuritycenterV2DataRetentionDeletionEvent.
7156 7157 7158 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_object_count ⇒ Fixnum
Number of objects that violated the policy for this resource. If the number is
less than 1,000, then the value of this field is the exact number. If the
number of objects that violated the policy is greater than or equal to 1,000,
then the value of this field is 1000.
Corresponds to the JSON property dataObjectCount
7128 7129 7130 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7128 def data_object_count @data_object_count end |
#event_detection_time ⇒ String
Timestamp indicating when the event was detected.
Corresponds to the JSON property eventDetectionTime
7133 7134 7135 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7133 def event_detection_time @event_detection_time end |
#event_type ⇒ String
Type of the DRD event.
Corresponds to the JSON property eventType
7138 7139 7140 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7138 def event_type @event_type end |
#max_retention_allowed ⇒ String
Maximum duration of retention allowed from the DRD control. This comes from
the DRD control where users set a max TTL for their data. For example, suppose
that a user sets the max TTL for a Cloud Storage bucket to 90 days. However,
an object in that bucket is 100 days old. In this case, a
DataRetentionDeletionEvent will be generated for that Cloud Storage bucket,
and the max_retention_allowed is 90 days.
Corresponds to the JSON property maxRetentionAllowed
7148 7149 7150 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7148 def max_retention_allowed @max_retention_allowed end |
#min_retention_allowed ⇒ String
Min duration of retention allowed from the DSPM retention control. This field
is only populated when event type is set to EVENT_TYPE_MIN_TTL_FROM_CREATION.
Corresponds to the JSON property minRetentionAllowed
7154 7155 7156 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7154 def min_retention_allowed @min_retention_allowed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7161 7162 7163 7164 7165 7166 7167 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7161 def update!(**args) @data_object_count = args[:data_object_count] if args.key?(:data_object_count) @event_detection_time = args[:event_detection_time] if args.key?(:event_detection_time) @event_type = args[:event_type] if args.key?(:event_type) @max_retention_allowed = args[:max_retention_allowed] if args.key?(:max_retention_allowed) @min_retention_allowed = args[:min_retention_allowed] if args.key?(:min_retention_allowed) end |