Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Detection
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Detection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Memory hash detection contributing to the binary family match.
Instance Attribute Summary collapse
-
#binary ⇒ String
The name of the binary associated with the memory hash signature detection.
-
#percent_pages_matched ⇒ Float
The percentage of memory page hashes in the signature that were matched.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Detection
constructor
A new instance of GoogleCloudSecuritycenterV2Detection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Detection
Returns a new instance of GoogleCloudSecuritycenterV2Detection.
7299 7300 7301 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#binary ⇒ String
The name of the binary associated with the memory hash signature detection.
Corresponds to the JSON property binary
7292 7293 7294 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7292 def binary @binary end |
#percent_pages_matched ⇒ Float
The percentage of memory page hashes in the signature that were matched.
Corresponds to the JSON property percentPagesMatched
7297 7298 7299 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7297 def percent_pages_matched @percent_pages_matched end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7304 7305 7306 7307 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7304 def update!(**args) @binary = args[:binary] if args.key?(:binary) @percent_pages_matched = args[:percent_pages_matched] if args.key?(:percent_pages_matched) end |