Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalExposure
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalExposure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Details about the externally exposed resource associated with the finding.
Instance Attribute Summary collapse
-
#backend_bucket ⇒ String
The full resource name of the load balancer backend bucket, for example, "// compute.googleapis.com/projects/
project-id/global/backendBuckets/name" Corresponds to the JSON propertybackendBucket. -
#backend_service ⇒ String
The full resource name of load balancer backend service, for example, "// compute.googleapis.com/projects/
project-id/global/backendServices/name". -
#exposed_application ⇒ String
The name and version of the exposed web application, for example, "Jenkins 2.
-
#exposed_endpoint ⇒ String
The resource which is running the exposed service, for example, "//compute.
-
#exposed_service ⇒ String
The name and version of the service, for example, "Jupyter Notebook 6.14.0".
-
#forwarding_rule ⇒ String
The full resource name of the forwarding rule, for example, "//compute.
-
#hostname_uri ⇒ String
Hostname of the exposed application, for example, "https://test-app.a.run.app/" Corresponds to the JSON property
hostnameUri. -
#http_response ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2HttpResponse>
The http response returned by the web application.
-
#instance_group ⇒ String
The full resource name of the instance group, for example, "//compute.
-
#internal_backend_service ⇒ String
The full resource name of load balancer backend service in the internal project having resource exposed via PSC, for example, "//compute.googleapis.
-
#load_balancer_firewall_policy ⇒ String
The full resource name of the load balancer firewall policy, for example, "// compute.googleapis.com/projects/
project-id/global/firewallPolicies/policy- name". -
#network_endpoint_group ⇒ String
The full resource name of the network endpoint group, for example, "//compute.
-
#network_ingress_firewall_policy ⇒ String
The full resource name of the network ingress firewall policy, for example, "// compute.googleapis.com/projects/
project-id/global/firewallPolicies/name". -
#private_ip_address ⇒ String
Private IP address of the exposed endpoint.
-
#private_port ⇒ String
Port number associated with private IP address.
-
#psc_network_attachment ⇒ String
The full resource name of the PSC (Private Service Connect) network attachment that network interface controller is attached to, for example, "//compute.
-
#psc_service_attachment ⇒ String
The full resource name of the PSC (Private Service Connect) service attachment that the load balancer network endpoint group targets, for example, "//compute.
-
#public_ip_address ⇒ String
Public IP address of the exposed endpoint.
-
#public_port ⇒ String
Public port number of the exposed endpoint.
-
#service_firewall_policy ⇒ String
The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/
project-id/global/ firewallPolicies/policy-name".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalExposure
constructor
A new instance of GoogleCloudSecuritycenterV2ExternalExposure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalExposure
Returns a new instance of GoogleCloudSecuritycenterV2ExternalExposure.
7651 7652 7653 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_bucket ⇒ String
The full resource name of the load balancer backend bucket, for example, "//
compute.googleapis.com/projects/project-id/global/backendBuckets/name"
Corresponds to the JSON property backendBucket
7534 7535 7536 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7534 def backend_bucket @backend_bucket end |
#backend_service ⇒ String
The full resource name of load balancer backend service, for example, "//
compute.googleapis.com/projects/project-id/global/backendServices/name".
Corresponds to the JSON property backendService
7540 7541 7542 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7540 def backend_service @backend_service end |
#exposed_application ⇒ String
The name and version of the exposed web application, for example, "Jenkins 2.
184".
Corresponds to the JSON property exposedApplication
7546 7547 7548 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7546 def exposed_application @exposed_application end |
#exposed_endpoint ⇒ String
The resource which is running the exposed service, for example, "//compute.
googleapis.com/projects/project-id/zones/zone/instances/instance.”
Corresponds to the JSON property exposedEndpoint
7552 7553 7554 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7552 def exposed_endpoint @exposed_endpoint end |
#exposed_service ⇒ String
The name and version of the service, for example, "Jupyter Notebook 6.14.0".
Corresponds to the JSON property exposedService
7557 7558 7559 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7557 def exposed_service @exposed_service end |
#forwarding_rule ⇒ String
The full resource name of the forwarding rule, for example, "//compute.
googleapis.com/projects/project-id/global/forwardingRules/forwarding-rule-
name".
Corresponds to the JSON property forwardingRule
7564 7565 7566 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7564 def forwarding_rule @forwarding_rule end |
#hostname_uri ⇒ String
Hostname of the exposed application, for example, "https://test-app.a.run.app/"
Corresponds to the JSON property hostnameUri
7569 7570 7571 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7569 def hostname_uri @hostname_uri end |
#http_response ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2HttpResponse>
The http response returned by the web application.
Corresponds to the JSON property httpResponse
7574 7575 7576 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7574 def http_response @http_response end |
#instance_group ⇒ String
The full resource name of the instance group, for example, "//compute.
googleapis.com/projects/project-id/global/instanceGroups/name".
Corresponds to the JSON property instanceGroup
7580 7581 7582 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7580 def instance_group @instance_group end |
#internal_backend_service ⇒ String
The full resource name of load balancer backend service in the internal
project having resource exposed via PSC, for example, "//compute.googleapis.
com/projects/project-id/global/backendServices/name".
Corresponds to the JSON property internalBackendService
7587 7588 7589 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7587 def internal_backend_service @internal_backend_service end |
#load_balancer_firewall_policy ⇒ String
The full resource name of the load balancer firewall policy, for example, "//
compute.googleapis.com/projects/project-id/global/firewallPolicies/policy-
name".
Corresponds to the JSON property loadBalancerFirewallPolicy
7594 7595 7596 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7594 def load_balancer_firewall_policy @load_balancer_firewall_policy end |
#network_endpoint_group ⇒ String
The full resource name of the network endpoint group, for example, "//compute.
googleapis.com/projects/project-id/global/networkEndpointGroups/name".
Corresponds to the JSON property networkEndpointGroup
7600 7601 7602 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7600 def network_endpoint_group @network_endpoint_group end |
#network_ingress_firewall_policy ⇒ String
The full resource name of the network ingress firewall policy, for example, "//
compute.googleapis.com/projects/project-id/global/firewallPolicies/name".
Corresponds to the JSON property networkIngressFirewallPolicy
7606 7607 7608 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7606 def network_ingress_firewall_policy @network_ingress_firewall_policy end |
#private_ip_address ⇒ String
Private IP address of the exposed endpoint.
Corresponds to the JSON property privateIpAddress
7611 7612 7613 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7611 def private_ip_address @private_ip_address end |
#private_port ⇒ String
Port number associated with private IP address.
Corresponds to the JSON property privatePort
7616 7617 7618 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7616 def private_port @private_port end |
#psc_network_attachment ⇒ String
The full resource name of the PSC (Private Service Connect) network attachment
that network interface controller is attached to, for example, "//compute.
googleapis.com/projects/project-id/regions/region/networkAttachments/name
"
Corresponds to the JSON property pscNetworkAttachment
7624 7625 7626 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7624 def @psc_network_attachment end |
#psc_service_attachment ⇒ String
The full resource name of the PSC (Private Service Connect) service attachment
that the load balancer network endpoint group targets, for example, "//compute.
googleapis.com/projects/project-id/regions/region/serviceAttachments/name
"
Corresponds to the JSON property pscServiceAttachment
7632 7633 7634 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7632 def @psc_service_attachment end |
#public_ip_address ⇒ String
Public IP address of the exposed endpoint.
Corresponds to the JSON property publicIpAddress
7637 7638 7639 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7637 def public_ip_address @public_ip_address end |
#public_port ⇒ String
Public port number of the exposed endpoint.
Corresponds to the JSON property publicPort
7642 7643 7644 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7642 def public_port @public_port end |
#service_firewall_policy ⇒ String
The full resource name of the firewall policy of the exposed service, for
example, "//compute.googleapis.com/projects/project-id/global/
firewallPolicies/policy-name".
Corresponds to the JSON property serviceFirewallPolicy
7649 7650 7651 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7649 def service_firewall_policy @service_firewall_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 7676 7677 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7656 def update!(**args) @backend_bucket = args[:backend_bucket] if args.key?(:backend_bucket) @backend_service = args[:backend_service] if args.key?(:backend_service) @exposed_application = args[:exposed_application] if args.key?(:exposed_application) @exposed_endpoint = args[:exposed_endpoint] if args.key?(:exposed_endpoint) @exposed_service = args[:exposed_service] if args.key?(:exposed_service) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @hostname_uri = args[:hostname_uri] if args.key?(:hostname_uri) @http_response = args[:http_response] if args.key?(:http_response) @instance_group = args[:instance_group] if args.key?(:instance_group) @internal_backend_service = args[:internal_backend_service] if args.key?(:internal_backend_service) @load_balancer_firewall_policy = args[:load_balancer_firewall_policy] if args.key?(:load_balancer_firewall_policy) @network_endpoint_group = args[:network_endpoint_group] if args.key?(:network_endpoint_group) @network_ingress_firewall_policy = args[:network_ingress_firewall_policy] if args.key?(:network_ingress_firewall_policy) @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address) @private_port = args[:private_port] if args.key?(:private_port) @psc_network_attachment = args[:psc_network_attachment] if args.key?(:psc_network_attachment) @psc_service_attachment = args[:psc_service_attachment] if args.key?(:psc_service_attachment) @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address) @public_port = args[:public_port] if args.key?(:public_port) @service_firewall_policy = args[:service_firewall_policy] if args.key?(:service_firewall_policy) end |