Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Representation of third party SIEM/SOAR fields within SCC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalSystem

Returns a new instance of GoogleCloudSecuritycenterV2ExternalSystem.



7749
7750
7751
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneesArray<String>

References primary/secondary etc assignees in the external system. Corresponds to the JSON property assignees

Returns:

  • (Array<String>)


7687
7688
7689
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7687

def assignees
  @assignees
end

#case_close_timeString

The time when the case was closed, as reported by the external system. Corresponds to the JSON property caseCloseTime

Returns:

  • (String)


7692
7693
7694
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7692

def case_close_time
  @case_close_time
end

#case_create_timeString

The time when the case was created, as reported by the external system. Corresponds to the JSON property caseCreateTime

Returns:

  • (String)


7697
7698
7699
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7697

def case_create_time
  @case_create_time
end

#case_priorityString

The priority of the finding's corresponding case in the external system. Corresponds to the JSON property casePriority

Returns:

  • (String)


7702
7703
7704
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7702

def case_priority
  @case_priority
end

#case_slaString

The SLA of the finding's corresponding case in the external system. Corresponds to the JSON property caseSla

Returns:

  • (String)


7707
7708
7709
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7707

def case_sla
  @case_sla
end

#case_uriString

The link to the finding's corresponding case in the external system. Corresponds to the JSON property caseUri

Returns:

  • (String)


7712
7713
7714
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7712

def case_uri
  @case_uri
end

#external_system_update_timeString

The time when the case was last updated, as reported by the external system. Corresponds to the JSON property externalSystemUpdateTime

Returns:

  • (String)


7717
7718
7719
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7717

def external_system_update_time
  @external_system_update_time
end

#external_uidString

The identifier that's used to track the finding's corresponding case in the external system. Corresponds to the JSON property externalUid

Returns:

  • (String)


7723
7724
7725
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7723

def external_uid
  @external_uid
end

#nameString

Full resource name of the external system. The following list shows some examples: + organizations/1234/sources/5678/findings/123456/externalSystems/ jira + organizations/1234/sources/5678/locations/us/findings/123456/ externalSystems/jira + folders/1234/sources/5678/findings/123456/ externalSystems/jira + folders/1234/sources/5678/locations/us/findings/ 123456/externalSystems/jira + projects/1234/sources/5678/findings/123456/ externalSystems/jira + projects/1234/sources/5678/locations/us/findings/ 123456/externalSystems/jira Corresponds to the JSON property name

Returns:

  • (String)


7735
7736
7737
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7735

def name
  @name
end

#statusString

The most recent status of the finding's corresponding case, as reported by the external system. Corresponds to the JSON property status

Returns:

  • (String)


7741
7742
7743
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7741

def status
  @status
end

#ticket_infoGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2TicketInfo

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding. Corresponds to the JSON property ticketInfo



7747
7748
7749
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7747

def ticket_info
  @ticket_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7754
7755
7756
7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7754

def update!(**args)
  @assignees = args[:assignees] if args.key?(:assignees)
  @case_close_time = args[:case_close_time] if args.key?(:case_close_time)
  @case_create_time = args[:case_create_time] if args.key?(:case_create_time)
  @case_priority = args[:case_priority] if args.key?(:case_priority)
  @case_sla = args[:case_sla] if args.key?(:case_sla)
  @case_uri = args[:case_uri] if args.key?(:case_uri)
  @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time)
  @external_uid = args[:external_uid] if args.key?(:external_uid)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @ticket_info = args[:ticket_info] if args.key?(:ticket_info)
end