Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Framework
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Framework
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Compliance framework associated with the finding.
Instance Attribute Summary collapse
-
#category ⇒ Array<String>
Category of the framework associated with the finding.
-
#controls ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Control>
The controls associated with the framework.
-
#display_name ⇒ String
Display name of the framework.
-
#name ⇒ String
Name of the framework associated with the finding Corresponds to the JSON property
name. -
#type ⇒ String
Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Framework
constructor
A new instance of GoogleCloudSecuritycenterV2Framework.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Framework
Returns a new instance of GoogleCloudSecuritycenterV2Framework.
8442 8443 8444 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Array<String>
Category of the framework associated with the finding. E.g. Security Benchmark,
or Assured Workloads
Corresponds to the JSON property category
8416 8417 8418 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8416 def category @category end |
#controls ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Control>
The controls associated with the framework.
Corresponds to the JSON property controls
8421 8422 8423 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8421 def controls @controls end |
#display_name ⇒ String
Display name of the framework. For a standard framework, this will look like e.
g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined
string like MyFramework
Corresponds to the JSON property displayName
8428 8429 8430 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8428 def display_name @display_name end |
#name ⇒ String
Name of the framework associated with the finding
Corresponds to the JSON property name
8433 8434 8435 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8433 def name @name end |
#type ⇒ String
Type of the framework associated with the finding, to specify whether the
framework is built-in (pre-defined and immutable) or a custom framework
defined by the customer (equivalent to security posture)
Corresponds to the JSON property type
8440 8441 8442 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8440 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8447 8448 8449 8450 8451 8452 8453 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8447 def update!(**args) @category = args[:category] if args.key?(:category) @controls = args[:controls] if args.key?(:controls) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |