Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IamBinding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IamBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents a particular IAM binding, which captures a member's role addition, removal, or state.
Instance Attribute Summary collapse
-
#action ⇒ String
The action that was performed on a Binding.
-
#member ⇒ String
A single identity requesting access for a Cloud Platform resource, for example, "foo@google.com".
-
#role ⇒ String
Role that is assigned to "members".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IamBinding
constructor
A new instance of GoogleCloudSecuritycenterV2IamBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IamBinding
Returns a new instance of GoogleCloudSecuritycenterV2IamBinding.
8549 8550 8551 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The action that was performed on a Binding.
Corresponds to the JSON property action
8535 8536 8537 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8535 def action @action end |
#member ⇒ String
A single identity requesting access for a Cloud Platform resource, for example,
"foo@google.com".
Corresponds to the JSON property member
8541 8542 8543 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8541 def member @member end |
#role ⇒ String
Role that is assigned to "members". For example, "roles/viewer", "roles/editor"
, or "roles/owner".
Corresponds to the JSON property role
8547 8548 8549 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8547 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8554 8555 8556 8557 8558 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8554 def update!(**args) @action = args[:action] if args.key?(:action) @member = args[:member] if args.key?(:member) @role = args[:role] if args.key?(:role) end |