Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2InfoType
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2InfoType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Type of information detected by the API.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the information type.
-
#sensitivity_score ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#version ⇒ String
Optional version name for this InfoType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2InfoType
constructor
A new instance of GoogleCloudSecuritycenterV2InfoType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2InfoType
Returns a new instance of GoogleCloudSecuritycenterV2InfoType.
8627 8628 8629 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the information type. Either a name of your choosing when creating a
CustomInfoType, or one of the names listed at https://cloud.google.com/
sensitive-data-protection/docs/infotypes-reference when specifying a built-in
type. When sending Cloud DLP results to Data Catalog, infoType names should
conform to the pattern [A-Za-z0-9$_-]1,64`.
Corresponds to the JSON propertyname`
8614 8615 8616 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8614 def name @name end |
#sensitivity_score ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
8620 8621 8622 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8620 def sensitivity_score @sensitivity_score end |
#version ⇒ String
Optional version name for this InfoType.
Corresponds to the JSON property version
8625 8626 8627 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8625 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8632 8633 8634 8635 8636 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8632 def update!(**args) @name = args[:name] if args.key?(:name) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @version = args[:version] if args.key?(:version) end |