Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Issue
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Security Command Center Issue.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
The description of the issue in Markdown format.
-
#detection ⇒ String
The finding category or rule name that generated the issue.
-
#domains ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueDomain>
The domains of the issue.
-
#exposure_score ⇒ Float
The exposure score of the issue.
-
#issue_type ⇒ String
The type of the issue.
-
#last_observation_time ⇒ String
The time the issue was last observed.
-
#mute ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueMute
The mute information of the issue.
-
#name ⇒ String
Identifier.
-
#primary_resource ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResource
A resource associated with the an issue.
-
#related_findings ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueFinding>
The findings related to the issue.
-
#remediations ⇒ Array<String>
Approaches to remediate the issue in Markdown format.
-
#secondary_resources ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResource>
Additional resources associated with the issue.
-
#security_contexts ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueSecurityContext>
The security context of the issue.
-
#severity ⇒ String
The severity of the issue.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Issue
constructor
A new instance of GoogleCloudSecuritycenterV2Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Issue
Returns a new instance of GoogleCloudSecuritycenterV2Issue.
8813 8814 8815 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the issue was created.
Corresponds to the JSON property createTime
8730 8731 8732 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8730 def create_time @create_time end |
#description ⇒ String
The description of the issue in Markdown format.
Corresponds to the JSON property description
8735 8736 8737 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8735 def description @description end |
#detection ⇒ String
The finding category or rule name that generated the issue.
Corresponds to the JSON property detection
8740 8741 8742 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8740 def detection @detection end |
#domains ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueDomain>
The domains of the issue.
Corresponds to the JSON property domains
8745 8746 8747 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8745 def domains @domains end |
#exposure_score ⇒ Float
The exposure score of the issue.
Corresponds to the JSON property exposureScore
8750 8751 8752 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8750 def exposure_score @exposure_score end |
#issue_type ⇒ String
The type of the issue.
Corresponds to the JSON property issueType
8755 8756 8757 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8755 def issue_type @issue_type end |
#last_observation_time ⇒ String
The time the issue was last observed.
Corresponds to the JSON property lastObservationTime
8760 8761 8762 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8760 def last_observation_time @last_observation_time end |
#mute ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueMute
The mute information of the issue.
Corresponds to the JSON property mute
8765 8766 8767 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8765 def mute @mute end |
#name ⇒ String
Identifier. The name of the issue. Format: organizations/organization/
locations/location/issues/issue
Corresponds to the JSON property name
8771 8772 8773 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8771 def name @name end |
#primary_resource ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResource
A resource associated with the an issue.
Corresponds to the JSON property primaryResource
8776 8777 8778 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8776 def primary_resource @primary_resource end |
#related_findings ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueFinding>
The findings related to the issue.
Corresponds to the JSON property relatedFindings
8781 8782 8783 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8781 def @related_findings end |
#remediations ⇒ Array<String>
Approaches to remediate the issue in Markdown format.
Corresponds to the JSON property remediations
8786 8787 8788 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8786 def remediations @remediations end |
#secondary_resources ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResource>
Additional resources associated with the issue.
Corresponds to the JSON property secondaryResources
8791 8792 8793 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8791 def secondary_resources @secondary_resources end |
#security_contexts ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueSecurityContext>
The security context of the issue.
Corresponds to the JSON property securityContexts
8796 8797 8798 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8796 def security_contexts @security_contexts end |
#severity ⇒ String
The severity of the issue.
Corresponds to the JSON property severity
8801 8802 8803 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8801 def severity @severity end |
#state ⇒ String
Output only. The state of the issue.
Corresponds to the JSON property state
8806 8807 8808 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8806 def state @state end |
#update_time ⇒ String
Output only. The time the issue was last updated.
Corresponds to the JSON property updateTime
8811 8812 8813 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8811 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8818 8819 8820 8821 8822 8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8818 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @detection = args[:detection] if args.key?(:detection) @domains = args[:domains] if args.key?(:domains) @exposure_score = args[:exposure_score] if args.key?(:exposure_score) @issue_type = args[:issue_type] if args.key?(:issue_type) @last_observation_time = args[:last_observation_time] if args.key?(:last_observation_time) @mute = args[:mute] if args.key?(:mute) @name = args[:name] if args.key?(:name) @primary_resource = args[:primary_resource] if args.key?(:primary_resource) @related_findings = args[:related_findings] if args.key?(:related_findings) @remediations = args[:remediations] if args.key?(:remediations) @secondary_resources = args[:secondary_resources] if args.key?(:secondary_resources) @security_contexts = args[:security_contexts] if args.key?(:security_contexts) @severity = args[:severity] if args.key?(:severity) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |