Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueMute
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueMute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
The mute information of the issue.
Instance Attribute Summary collapse
-
#mute_initiator ⇒ String
The email address of the user who last changed the mute state of the issue.
-
#mute_reason ⇒ String
The user-provided reason for muting the issue.
-
#mute_state ⇒ String
Output only.
-
#mute_update_time ⇒ String
The time the issue was muted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueMute
constructor
A new instance of GoogleCloudSecuritycenterV2IssueMute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueMute
Returns a new instance of GoogleCloudSecuritycenterV2IssueMute.
8213 8214 8215 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mute_initiator ⇒ String
The email address of the user who last changed the mute state of the issue.
Corresponds to the JSON property muteInitiator
8196 8197 8198 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8196 def mute_initiator @mute_initiator end |
#mute_reason ⇒ String
The user-provided reason for muting the issue.
Corresponds to the JSON property muteReason
8201 8202 8203 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8201 def mute_reason @mute_reason end |
#mute_state ⇒ String
Output only. The mute state of the issue.
Corresponds to the JSON property muteState
8206 8207 8208 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8206 def mute_state @mute_state end |
#mute_update_time ⇒ String
The time the issue was muted.
Corresponds to the JSON property muteUpdateTime
8211 8212 8213 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8211 def mute_update_time @mute_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8218 8219 8220 8221 8222 8223 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8218 def update!(**args) @mute_initiator = args[:mute_initiator] if args.key?(:mute_initiator) @mute_reason = args[:mute_reason] if args.key?(:mute_reason) @mute_state = args[:mute_state] if args.key?(:mute_state) @mute_update_time = args[:mute_update_time] if args.key?(:mute_update_time) end |