Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
A resource associated with the an issue.
Instance Attribute Summary collapse
-
#adc_application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcApplication
Represents an ADC application associated with the finding.
-
#adc_application_template ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
-
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplication
The AppHub application associated with the resource, if any.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata
The AWS metadata of a resource associated with an issue.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata
The Azure metadata of a resource associated with an issue.
-
#cloud_provider ⇒ String
The cloud provider of the resource associated with the issue.
-
#display_name ⇒ String
The resource-type specific display name of the resource associated with the issue.
-
#google_cloud_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata
Google Cloud metadata of a resource associated with an issue.
-
#name ⇒ String
The full resource name of the resource associated with the issue.
-
#type ⇒ String
The type of the resource associated with the issue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource
constructor
A new instance of GoogleCloudSecuritycenterV2IssueResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource
Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.
9024 9025 9026 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adc_application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcApplication
Represents an ADC application associated with the finding.
Corresponds to the JSON property adcApplication
8971 8972 8973 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8971 def adc_application @adc_application end |
#adc_application_template ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
Corresponds to the JSON property adcApplicationTemplate
8976 8977 8978 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8976 def adc_application_template @adc_application_template end |
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
Corresponds to the JSON property adcSharedTemplate
8981 8982 8983 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8981 def adc_shared_template @adc_shared_template end |
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplication
The AppHub application associated with the resource, if any.
Corresponds to the JSON property application
8986 8987 8988 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8986 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata
The AWS metadata of a resource associated with an issue.
Corresponds to the JSON property awsMetadata
8991 8992 8993 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8991 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata
The Azure metadata of a resource associated with an issue.
Corresponds to the JSON property azureMetadata
8996 8997 8998 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8996 def @azure_metadata end |
#cloud_provider ⇒ String
The cloud provider of the resource associated with the issue.
Corresponds to the JSON property cloudProvider
9001 9002 9003 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9001 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The resource-type specific display name of the resource associated with the
issue.
Corresponds to the JSON property displayName
9007 9008 9009 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9007 def display_name @display_name end |
#google_cloud_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata
Google Cloud metadata of a resource associated with an issue.
Corresponds to the JSON property googleCloudMetadata
9012 9013 9014 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9012 def @google_cloud_metadata end |
#name ⇒ String
The full resource name of the resource associated with the issue.
Corresponds to the JSON property name
9017 9018 9019 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9017 def name @name end |
#type ⇒ String
The type of the resource associated with the issue.
Corresponds to the JSON property type
9022 9023 9024 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9022 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9029 def update!(**args) @adc_application = args[:adc_application] if args.key?(:adc_application) @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template) @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |