Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

The AWS metadata of a resource associated with an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAwsMetadata.



8423
8424
8425
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

The AWS account of the resource associated with the issue. Corresponds to the JSON property account



8421
8422
8423
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8421

def 
  @account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8428
8429
8430
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8428

def update!(**args)
  @account = args[:account] if args.key?(:account)
end