Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
The AWS account of the resource associated with the issue.
Instance Attribute Summary collapse
-
#id ⇒ String
The AWS account ID of the resource associated with the issue.
-
#name ⇒ String
The AWS account name of the resource associated with the issue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount
constructor
A new instance of GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount
Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount.
8447 8448 8449 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The AWS account ID of the resource associated with the issue.
Corresponds to the JSON property id
8440 8441 8442 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8440 def id @id end |
#name ⇒ String
The AWS account name of the resource associated with the issue.
Corresponds to the JSON property name
8445 8446 8447 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8445 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8452 8453 8454 8455 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8452 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) end |