Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

The Azure metadata of a resource associated with an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAzureMetadata

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAzureMetadata.



8467
8468
8469
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#subscriptionGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

The Azure subscription of the resource associated with the issue. Corresponds to the JSON property subscription



8465
8466
8467
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8465

def subscription
  @subscription
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8472
8473
8474
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8472

def update!(**args)
  @subscription = args[:subscription] if args.key?(:subscription)
end