Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

The Azure subscription of the resource associated with the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription.



9315
9316
9317
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The Azure subscription display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


9308
9309
9310
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9308

def display_name
  @display_name
end

#idString

The Azure subscription ID of the resource associated with the issue. Corresponds to the JSON property id

Returns:

  • (String)


9313
9314
9315
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9313

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9320
9321
9322
9323
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9320

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
end