Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job

Returns a new instance of GoogleCloudSecuritycenterV2Job.



9444
9445
9446
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


9427
9428
9429
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9427

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


9432
9433
9434
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9432

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


9437
9438
9439
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9437

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


9442
9443
9444
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9442

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9449
9450
9451
9452
9453
9454
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9449

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end