Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Kubernetes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Kubernetes-related attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes

Returns a new instance of GoogleCloudSecuritycenterV2Kubernetes.



9587
9588
9589
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reviewsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview>

Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding. Corresponds to the JSON property accessReviews



9546
9547
9548
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9546

def access_reviews
  @access_reviews
end

#bindingsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Binding>

Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings. Corresponds to the JSON property bindings



9553
9554
9555
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9553

def bindings
  @bindings
end

#node_poolsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2NodePool>

GKE node pools associated with the finding. This field contains node pool information for each node, when it is available. Corresponds to the JSON property nodePools



9560
9561
9562
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9560

def node_pools
  @node_pools
end

#nodesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Node>

Provides Kubernetes node information. Corresponds to the JSON property nodes



9566
9567
9568
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9566

def nodes
  @nodes
end

#objectsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Object>

Kubernetes objects related to the finding. Corresponds to the JSON property objects



9571
9572
9573
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9571

def objects
  @objects
end

#podsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Pod>

Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod. Corresponds to the JSON property pods



9578
9579
9580
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9578

def pods
  @pods
end

#rolesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Role>

Provides Kubernetes role information for findings that involve Roles or ClusterRoles. Corresponds to the JSON property roles



9585
9586
9587
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9585

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9592
9593
9594
9595
9596
9597
9598
9599
9600
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9592

def update!(**args)
  @access_reviews = args[:access_reviews] if args.key?(:access_reviews)
  @bindings = args[:bindings] if args.key?(:bindings)
  @node_pools = args[:node_pools] if args.key?(:node_pools)
  @nodes = args[:nodes] if args.key?(:nodes)
  @objects = args[:objects] if args.key?(:objects)
  @pods = args[:pods] if args.key?(:pods)
  @roles = args[:roles] if args.key?(:roles)
end