Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2MitreAttack

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

MITRE ATT&CK tactics and techniques related to this finding. See: https:// attack.mitre.org

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MitreAttack

Returns a new instance of GoogleCloudSecuritycenterV2MitreAttack.



8908
8909
8910
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_tacticsArray<String>

Additional MITRE ATT&CK tactics related to this finding, if any. Corresponds to the JSON property additionalTactics

Returns:

  • (Array<String>)


8880
8881
8882
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8880

def additional_tactics
  @additional_tactics
end

#additional_techniquesArray<String>

Additional MITRE ATT&CK techniques related to this finding, if any, along with any of their respective parent techniques. Corresponds to the JSON property additionalTechniques

Returns:

  • (Array<String>)


8886
8887
8888
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8886

def additional_techniques
  @additional_techniques
end

#primary_tacticString

The MITRE ATT&CK tactic most closely represented by this finding, if any. Corresponds to the JSON property primaryTactic

Returns:

  • (String)


8891
8892
8893
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8891

def primary_tactic
  @primary_tactic
end

#primary_techniquesArray<String>

The MITRE ATT&CK technique most closely represented by this finding, if any. primary_techniques is a repeated field because there are multiple levels of MITRE ATT&CK techniques. If the technique most closely represented by this finding is a sub-technique (e.g. SCANNING_IP_BLOCKS), both the sub-technique and its parent technique(s) will be listed (e.g. SCANNING_IP_BLOCKS, ACTIVE_SCANNING). Corresponds to the JSON property primaryTechniques

Returns:

  • (Array<String>)


8901
8902
8903
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8901

def primary_techniques
  @primary_techniques
end

#versionString

The MITRE ATT&CK version referenced by the above fields. E.g. "8". Corresponds to the JSON property version

Returns:

  • (String)


8906
8907
8908
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8906

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8913
8914
8915
8916
8917
8918
8919
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8913

def update!(**args)
  @additional_tactics = args[:additional_tactics] if args.key?(:additional_tactics)
  @additional_techniques = args[:additional_techniques] if args.key?(:additional_techniques)
  @primary_tactic = args[:primary_tactic] if args.key?(:primary_tactic)
  @primary_techniques = args[:primary_techniques] if args.key?(:primary_techniques)
  @version = args[:version] if args.key?(:version)
end