Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Notebook
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
Instance Attribute Summary collapse
-
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
-
#name ⇒ String
The name of the notebook.
-
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
-
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook
constructor
A new instance of GoogleCloudSecuritycenterV2Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook
Returns a new instance of GoogleCloudSecuritycenterV2Notebook.
9957 9958 9959 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
Corresponds to the JSON property lastAuthor
9940 9941 9942 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9940 def @last_author end |
#name ⇒ String
The name of the notebook.
Corresponds to the JSON property name
9945 9946 9947 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9945 def name @name end |
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
Corresponds to the JSON property notebookUpdateTime
9950 9951 9952 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9950 def notebook_update_time @notebook_update_time end |
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Corresponds to the JSON property service
9955 9956 9957 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9955 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9962 9963 9964 9965 9966 9967 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9962 def update!(**args) @last_author = args[:last_author] if args.key?(:last_author) @name = args[:name] if args.key?(:name) @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time) @service = args[:service] if args.key?(:service) end |