Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Object
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Object
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Container>
Pod containers associated with this finding, if any.
-
#group ⇒ String
Kubernetes object group, such as "policy.k8s.io/v1".
-
#kind ⇒ String
Kubernetes object kind, such as "Namespace".
-
#name ⇒ String
Kubernetes object name.
-
#ns ⇒ String
Kubernetes object namespace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object
constructor
A new instance of GoogleCloudSecuritycenterV2Object.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object
Returns a new instance of GoogleCloudSecuritycenterV2Object.
10038 10039 10040 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Container>
Pod containers associated with this finding, if any.
Corresponds to the JSON property containers
10013 10014 10015 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10013 def containers @containers end |
#group ⇒ String
Kubernetes object group, such as "policy.k8s.io/v1".
Corresponds to the JSON property group
10018 10019 10020 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10018 def group @group end |
#kind ⇒ String
Kubernetes object kind, such as "Namespace".
Corresponds to the JSON property kind
10023 10024 10025 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10023 def kind @kind end |
#name ⇒ String
Kubernetes object name. For details see https://kubernetes.io/docs/concepts/
overview/working-with-objects/names/.
Corresponds to the JSON property name
10029 10030 10031 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10029 def name @name end |
#ns ⇒ String
Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid
collision with C++ namespace keyword. For details see https://kubernetes.io/
docs/tasks/administer-cluster/namespaces/.
Corresponds to the JSON property ns
10036 10037 10038 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10036 def ns @ns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10043 10044 10045 10046 10047 10048 10049 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10043 def update!(**args) @containers = args[:containers] if args.key?(:containers) @group = args[:group] if args.key?(:group) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) end |