Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PortRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A port range which is inclusive of the min and max values. Values are between 0 and 2^16-1. The max can be equal / must be not smaller than the min value. If min and max are equal this indicates that it is a single port.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PortRange

Returns a new instance of GoogleCloudSecuritycenterV2PortRange.



10122
10123
10124
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maxFixnum

Maximum port value. Corresponds to the JSON property max

Returns:

  • (Fixnum)


10115
10116
10117
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10115

def max
  @max
end

#minFixnum

Minimum port value. Corresponds to the JSON property min

Returns:

  • (Fixnum)


10120
10121
10122
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10120

def min
  @min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10127
10128
10129
10130
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10127

def update!(**args)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
end