Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ProcessSignature
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ProcessSignature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Indicates what signature matched this process.
Instance Attribute Summary collapse
-
#memory_hash_signature ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2MemoryHashSignature
A signature corresponding to memory page hashes.
-
#signature_type ⇒ String
Describes the type of resource associated with the signature.
-
#yara_rule_signature ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2YaraRuleSignature
A signature corresponding to a YARA rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ProcessSignature
constructor
A new instance of GoogleCloudSecuritycenterV2ProcessSignature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ProcessSignature
Returns a new instance of GoogleCloudSecuritycenterV2ProcessSignature.
9514 9515 9516 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memory_hash_signature ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2MemoryHashSignature
A signature corresponding to memory page hashes.
Corresponds to the JSON property memoryHashSignature
9502 9503 9504 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9502 def memory_hash_signature @memory_hash_signature end |
#signature_type ⇒ String
Describes the type of resource associated with the signature.
Corresponds to the JSON property signatureType
9507 9508 9509 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9507 def signature_type @signature_type end |
#yara_rule_signature ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2YaraRuleSignature
A signature corresponding to a YARA rule.
Corresponds to the JSON property yaraRuleSignature
9512 9513 9514 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9512 def yara_rule_signature @yara_rule_signature end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9519 9520 9521 9522 9523 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9519 def update!(**args) @memory_hash_signature = args[:memory_hash_signature] if args.key?(:memory_hash_signature) @signature_type = args[:signature_type] if args.key?(:signature_type) @yara_rule_signature = args[:yara_rule_signature] if args.key?(:yara_rule_signature) end |