Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Requests

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information about the requests relevant to the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Requests

Returns a new instance of GoogleCloudSecuritycenterV2Requests.



10445
10446
10447
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#long_term_allowedFixnum

Allowed RPS (requests per second) over the long term. Corresponds to the JSON property longTermAllowed

Returns:

  • (Fixnum)


10426
10427
10428
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10426

def long_term_allowed
  @long_term_allowed
end

#long_term_deniedFixnum

Denied RPS (requests per second) over the long term. Corresponds to the JSON property longTermDenied

Returns:

  • (Fixnum)


10431
10432
10433
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10431

def long_term_denied
  @long_term_denied
end

#ratioFloat

For 'Increasing deny ratio', the ratio is the denied traffic divided by the allowed traffic. For 'Allowed traffic spike', the ratio is the allowed traffic in the short term divided by allowed traffic in the long term. Corresponds to the JSON property ratio

Returns:

  • (Float)


10438
10439
10440
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10438

def ratio
  @ratio
end

#short_term_allowedFixnum

Allowed RPS (requests per second) in the short term. Corresponds to the JSON property shortTermAllowed

Returns:

  • (Fixnum)


10443
10444
10445
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10443

def short_term_allowed
  @short_term_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10450
10451
10452
10453
10454
10455
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10450

def update!(**args)
  @long_term_allowed = args[:long_term_allowed] if args.key?(:long_term_allowed)
  @long_term_denied = args[:long_term_denied] if args.key?(:long_term_denied)
  @ratio = args[:ratio] if args.key?(:ratio)
  @short_term_allowed = args[:short_term_allowed] if args.key?(:short_term_allowed)
end