Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource

Returns a new instance of GoogleCloudSecuritycenterV2Resource.



10550
10551
10552
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



10465
10466
10467
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10465

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



10470
10471
10472
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10470

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



10475
10476
10477
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10475

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



10480
10481
10482
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10480

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



10486
10487
10488
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10486

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



10492
10493
10494
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10492

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the finding is from. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


10497
10498
10499
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10497

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


10502
10503
10504
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10502

def display_name
  @display_name
end

#gcp_metadataGoogle::Apis::SecuritycenterV1::GcpMetadata

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud. Corresponds to the JSON property gcpMetadata



10508
10509
10510
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10508

def 
  @gcp_metadata
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


10513
10514
10515
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10513

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


10519
10520
10521
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10519

def name
  @name
end

#resource_pathGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



10525
10526
10527
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10525

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


10538
10539
10540
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10538

def resource_path_string
  @resource_path_string
end

#serviceString

The service or resource provider associated with the resource. Corresponds to the JSON property service

Returns:

  • (String)


10543
10544
10545
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10543

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


10548
10549
10550
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10548

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
10569
10570
10571
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10555

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end