Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.



10629
10630
10631
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



10607
10608
10609
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10607

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



10612
10613
10614
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10612

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



10617
10618
10619
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10617

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



10622
10623
10624
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10622

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



10627
10628
10629
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10627

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10634
10635
10636
10637
10638
10639
10640
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10634

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end