Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourcePathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A node within the resource path. Each node represents a resource within the resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourcePathNode

Returns a new instance of GoogleCloudSecuritycenterV2ResourcePathNode.



10597
10598
10599
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The display name of the resource this node represents. Corresponds to the JSON property displayName

Returns:

  • (String)


10585
10586
10587
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10585

def display_name
  @display_name
end

#idString

The ID of the resource this node represents. Corresponds to the JSON property id

Returns:

  • (String)


10590
10591
10592
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10590

def id
  @id
end

#node_typeString

The type of resource this node represents. Corresponds to the JSON property nodeType

Returns:

  • (String)


10595
10596
10597
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10595

def node_type
  @node_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10602
10603
10604
10605
10606
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10602

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @node_type = args[:node_type] if args.key?(:node_type)
end