Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecretEnvironmentVariable

Returns a new instance of GoogleCloudSecuritycenterV2SecretEnvironmentVariable.



10041
10042
10043
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


10039
10040
10041
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10039

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10046
10047
10048
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10046

def update!(**args)
  @key = args[:key] if args.key?(:key)
end