Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SecurityPosture

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecurityPosture

Returns a new instance of GoogleCloudSecuritycenterV2SecurityPosture.



10268
10269
10270
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#changed_policyString

The name of the updated policy, for example, projects/project_id/policies/ constraint_name`. Corresponds to the JSON propertychangedPolicy`

Returns:

  • (String)


10228
10229
10230
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10228

def changed_policy
  @changed_policy
end

#nameString

Name of the posture, for example, CIS-Posture. Corresponds to the JSON property name

Returns:

  • (String)


10233
10234
10235
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10233

def name
  @name
end

#policyString

The ID of the updated policy, for example, compute-policy-1. Corresponds to the JSON property policy

Returns:

  • (String)


10238
10239
10240
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10238

def policy
  @policy
end

#policy_drift_detailsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PolicyDriftDetails>

The details about a change in an updated policy that violates the deployed posture. Corresponds to the JSON property policyDriftDetails



10244
10245
10246
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10244

def policy_drift_details
  @policy_drift_details
end

#policy_setString

The name of the updated policy set, for example, cis-policyset. Corresponds to the JSON property policySet

Returns:

  • (String)


10249
10250
10251
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10249

def policy_set
  @policy_set
end

#posture_deploymentString

The name of the posture deployment, for example, organizations/org_id/ posturedeployments/posture_deployment_id`. Corresponds to the JSON propertypostureDeployment`

Returns:

  • (String)


10255
10256
10257
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10255

def posture_deployment
  @posture_deployment
end

#posture_deployment_resourceString

The project, folder, or organization on which the posture is deployed, for example, projects/project_number`. Corresponds to the JSON propertypostureDeploymentResource`

Returns:

  • (String)


10261
10262
10263
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10261

def posture_deployment_resource
  @posture_deployment_resource
end

#revision_idString

The version of the posture, for example, c7cfa2a8. Corresponds to the JSON property revisionId

Returns:

  • (String)


10266
10267
10268
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10266

def revision_id
  @revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10273
10274
10275
10276
10277
10278
10279
10280
10281
10282
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10273

def update!(**args)
  @changed_policy = args[:changed_policy] if args.key?(:changed_policy)
  @name = args[:name] if args.key?(:name)
  @policy = args[:policy] if args.key?(:policy)
  @policy_drift_details = args[:policy_drift_details] if args.key?(:policy_drift_details)
  @policy_set = args[:policy_set] if args.key?(:policy_set)
  @posture_deployment = args[:posture_deployment] if args.key?(:posture_deployment)
  @posture_deployment_resource = args[:posture_deployment_resource] if args.key?(:posture_deployment_resource)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
end