Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Resource value mapping for Sensitive Data Protection findings If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping

Returns a new instance of GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping.



10302
10303
10304
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#high_sensitivity_mappingString

Resource value mapping for high-sensitivity Sensitive Data Protection findings Corresponds to the JSON property highSensitivityMapping

Returns:

  • (String)


10294
10295
10296
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10294

def high_sensitivity_mapping
  @high_sensitivity_mapping
end

#medium_sensitivity_mappingString

Resource value mapping for medium-sensitivity Sensitive Data Protection findings Corresponds to the JSON property mediumSensitivityMapping

Returns:

  • (String)


10300
10301
10302
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10300

def medium_sensitivity_mapping
  @medium_sensitivity_mapping
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10307
10308
10309
10310
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10307

def update!(**args)
  @high_sensitivity_mapping = args[:high_sensitivity_mapping] if args.key?(:high_sensitivity_mapping)
  @medium_sensitivity_mapping = args[:medium_sensitivity_mapping] if args.key?(:medium_sensitivity_mapping)
end