Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



11343
11344
11345
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


11316
11317
11318
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11316

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


11321
11322
11323
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11321

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


11326
11327
11328
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11326

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


11331
11332
11333
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11331

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


11336
11337
11338
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11336

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


11341
11342
11343
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11341

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11348
11349
11350
11351
11352
11353
11354
11355
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11348

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end