Class: Google::Apis::SecuritycenterV1::GroupFindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Response message for group by findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GroupFindingsResponse

Returns a new instance of GroupFindingsResponse.



10886
10887
10888
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10886

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#group_by_resultsArray<Google::Apis::SecuritycenterV1::GroupResult>

Group results. There exists an element for each existing unique combination of property/values. The element contains a count for the number of times those specific property/values appear. Corresponds to the JSON property groupByResults



10868
10869
10870
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10868

def group_by_results
  @group_by_results
end

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10874
10875
10876
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10874

def next_page_token
  @next_page_token
end

#read_timeString

Time used for executing the groupBy request. Corresponds to the JSON property readTime

Returns:

  • (String)


10879
10880
10881
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10879

def read_time
  @read_time
end

#total_sizeFixnum

The total number of results matching the query. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


10884
10885
10886
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10884

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10891
10892
10893
10894
10895
10896
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10891

def update!(**args)
  @group_by_results = args[:group_by_results] if args.key?(:group_by_results)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @read_time = args[:read_time] if args.key?(:read_time)
  @total_size = args[:total_size] if args.key?(:total_size)
end