Class: Google::Apis::SecuritycenterV1::InfoType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Type of information detected by the API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InfoType

Returns a new instance of InfoType.



11813
11814
11815
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11813

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the information type. Either a name of your choosing when creating a CustomInfoType, or one of the names listed at https://cloud.google.com/ sensitive-data-protection/docs/infotypes-reference when specifying a built-in type. When sending Cloud DLP results to Data Catalog, infoType names should conform to the pattern [A-Za-z0-9$_-]1,64`. Corresponds to the JSON propertyname`

Returns:

  • (String)


11800
11801
11802
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11800

def name
  @name
end

#sensitivity_scoreGoogle::Apis::SecuritycenterV1::SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



11806
11807
11808
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11806

def sensitivity_score
  @sensitivity_score
end

#versionString

Optional version name for this InfoType. Corresponds to the JSON property version

Returns:

  • (String)


11811
11812
11813
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11811

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11818
11819
11820
11821
11822
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11818

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @version = args[:version] if args.key?(:version)
end