Class: Google::Apis::SecuritycenterV1::IpRule
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::IpRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
IP rule information.
Instance Attribute Summary collapse
-
#port_ranges ⇒ Array<Google::Apis::SecuritycenterV1::PortRange>
Optional.
-
#protocol ⇒ String
The IP protocol this rule applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpRule
constructor
A new instance of IpRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpRule
Returns a new instance of IpRule.
11102 11103 11104 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port_ranges ⇒ Array<Google::Apis::SecuritycenterV1::PortRange>
Optional. An optional list of ports to which this rule applies. This field is
only applicable for the UDP or (S)TCP protocols. Each entry must be either an
integer or a range including a min and max port number.
Corresponds to the JSON property portRanges
11093 11094 11095 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11093 def port_ranges @port_ranges end |
#protocol ⇒ String
The IP protocol this rule applies to. This value can either be one of the
following well known protocol strings (TCP, UDP, ICMP, ESP, AH, IPIP, SCTP) or
a string representation of the integer value.
Corresponds to the JSON property protocol
11100 11101 11102 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11100 def protocol @protocol end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11107 11108 11109 11110 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11107 def update!(**args) @port_ranges = args[:port_ranges] if args.key?(:port_ranges) @protocol = args[:protocol] if args.key?(:protocol) end |