Class: Google::Apis::SecuritycenterV1::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



12103
12104
12105
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


12086
12087
12088
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12086

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


12091
12092
12093
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12091

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


12096
12097
12098
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12096

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


12101
12102
12103
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12101

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12108
12109
12110
12111
12112
12113
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12108

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end