Class: Google::Apis::SecuritycenterV1::Kubernetes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::Kubernetes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Kubernetes-related attributes.
Instance Attribute Summary collapse
-
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1::AccessReview>
Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding.
-
#bindings ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Binding>
Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings.
-
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1::NodePool>
GKE node pools associated with the finding.
-
#nodes ⇒ Array<Google::Apis::SecuritycenterV1::Node>
Provides Kubernetes node information.
-
#objects ⇒ Array<Google::Apis::SecuritycenterV1::Object>
Kubernetes objects related to the finding.
-
#pods ⇒ Array<Google::Apis::SecuritycenterV1::Pod>
Kubernetes Pods associated with the finding.
-
#roles ⇒ Array<Google::Apis::SecuritycenterV1::Role>
Provides Kubernetes role information for findings that involve Roles or ClusterRoles.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Kubernetes
constructor
A new instance of Kubernetes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Kubernetes
Returns a new instance of Kubernetes.
12076 12077 12078 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1::AccessReview>
Provides information on any Kubernetes access reviews (privilege checks)
relevant to the finding.
Corresponds to the JSON property accessReviews
12035 12036 12037 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12035 def access_reviews @access_reviews end |
#bindings ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Binding>
Provides Kubernetes role binding information for findings that involve
RoleBindings or ClusterRoleBindings.
Corresponds to the JSON property bindings
12042 12043 12044 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12042 def bindings @bindings end |
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1::NodePool>
GKE node pools associated with the finding. This field contains node pool information
for each node, when it is available.
Corresponds to the JSON property nodePools
12049 12050 12051 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12049 def node_pools @node_pools end |
#nodes ⇒ Array<Google::Apis::SecuritycenterV1::Node>
Provides Kubernetes node information.
Corresponds to the JSON property nodes
12055 12056 12057 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12055 def nodes @nodes end |
#objects ⇒ Array<Google::Apis::SecuritycenterV1::Object>
Kubernetes objects related to the finding.
Corresponds to the JSON property objects
12060 12061 12062 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12060 def objects @objects end |
#pods ⇒ Array<Google::Apis::SecuritycenterV1::Pod>
Kubernetes Pods
associated with the finding. This field contains Pod records for each
container that is owned by a Pod.
Corresponds to the JSON property pods
12067 12068 12069 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12067 def pods @pods end |
#roles ⇒ Array<Google::Apis::SecuritycenterV1::Role>
Provides Kubernetes role information for findings that involve Roles or
ClusterRoles.
Corresponds to the JSON property roles
12074 12075 12076 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12074 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12081 12082 12083 12084 12085 12086 12087 12088 12089 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12081 def update!(**args) @access_reviews = args[:access_reviews] if args.key?(:access_reviews) @bindings = args[:bindings] if args.key?(:bindings) @node_pools = args[:node_pools] if args.key?(:node_pools) @nodes = args[:nodes] if args.key?(:nodes) @objects = args[:objects] if args.key?(:objects) @pods = args[:pods] if args.key?(:pods) @roles = args[:roles] if args.key?(:roles) end |