Class: Google::Apis::SecuritycenterV1::ListDescendantEventThreatDetectionCustomModulesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Response for listing current and descendant resident Event Threat Detection custom modules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDescendantEventThreatDetectionCustomModulesResponse

Returns a new instance of ListDescendantEventThreatDetectionCustomModulesResponse.



11516
11517
11518
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11516

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_threat_detection_custom_modulesArray<Google::Apis::SecuritycenterV1::EventThreatDetectionCustomModule>

Custom modules belonging to the requested parent. Corresponds to the JSON property eventThreatDetectionCustomModules



11508
11509
11510
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11508

def event_threat_detection_custom_modules
  @event_threat_detection_custom_modules
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11514
11515
11516
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11514

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11521
11522
11523
11524
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11521

def update!(**args)
  @event_threat_detection_custom_modules = args[:event_threat_detection_custom_modules] if args.key?(:event_threat_detection_custom_modules)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end