Class: Google::Apis::SecuritycenterV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



12691
12692
12693
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12676
12677
12678
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12676

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::SecuritycenterV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



12681
12682
12683
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12681

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


12689
12690
12691
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12689

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12696
12697
12698
12699
12700
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12696

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end