Class: Google::Apis::SecuritycenterV1::ListSourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::ListSourcesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Response message for listing sources.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results.
-
#sources ⇒ Array<Google::Apis::SecuritycenterV1::Source>
Sources belonging to the requested parent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSourcesResponse
constructor
A new instance of ListSourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSourcesResponse
Returns a new instance of ListSourcesResponse.
11858 11859 11860 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results.
Corresponds to the JSON property nextPageToken
11851 11852 11853 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11851 def next_page_token @next_page_token end |
#sources ⇒ Array<Google::Apis::SecuritycenterV1::Source>
Sources belonging to the requested parent.
Corresponds to the JSON property sources
11856 11857 11858 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11856 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11863 11864 11865 11866 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11863 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @sources = args[:sources] if args.key?(:sources) end |