Class: Google::Apis::SecuritycenterV1::ListValuedResourcesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Response message for listing the valued resources for a given simulation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListValuedResourcesResponse

Returns a new instance of ListValuedResourcesResponse.



11889
11890
11891
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to retrieve the next page of results, or empty if there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11877
11878
11879
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11877

def next_page_token
  @next_page_token
end

#total_sizeFixnum

The estimated total number of results matching the query. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


11882
11883
11884
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11882

def total_size
  @total_size
end

#valued_resourcesArray<Google::Apis::SecuritycenterV1::ValuedResource>

The valued resources that the attack path simulation identified. Corresponds to the JSON property valuedResources



11887
11888
11889
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11887

def valued_resources
  @valued_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11894
11895
11896
11897
11898
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11894

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
  @valued_resources = args[:valued_resources] if args.key?(:valued_resources)
end