Class: Google::Apis::SecuritycenterV1::LoadBalancer
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::LoadBalancer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Contains information related to the load balancer associated with the finding.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the load balancer associated with the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancer
constructor
A new instance of LoadBalancer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancer
Returns a new instance of LoadBalancer.
11910 11911 11912 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the load balancer associated with the finding.
Corresponds to the JSON property name
11908 11909 11910 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11908 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11915 11916 11917 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11915 def update!(**args) @name = args[:name] if args.key?(:name) end |