Class: Google::Apis::SecuritycenterV1::MemoryHashSignature
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::MemoryHashSignature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
A signature corresponding to memory page hashes.
Instance Attribute Summary collapse
-
#binary_family ⇒ String
The binary family.
-
#detections ⇒ Array<Google::Apis::SecuritycenterV1::Detection>
The list of memory hash detections contributing to the binary family match.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MemoryHashSignature
constructor
A new instance of MemoryHashSignature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MemoryHashSignature
Returns a new instance of MemoryHashSignature.
12695 12696 12697 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12695 def initialize(**args) update!(**args) end |
Instance Attribute Details
#binary_family ⇒ String
The binary family.
Corresponds to the JSON property binaryFamily
12688 12689 12690 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12688 def binary_family @binary_family end |
#detections ⇒ Array<Google::Apis::SecuritycenterV1::Detection>
The list of memory hash detections contributing to the binary family match.
Corresponds to the JSON property detections
12693 12694 12695 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12693 def detections @detections end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12700 12701 12702 12703 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12700 def update!(**args) @binary_family = args[:binary_family] if args.key?(:binary_family) @detections = args[:detections] if args.key?(:detections) end |