Class: Google::Apis::SecuritycenterV1::Notebook

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Notebook

Returns a new instance of Notebook.



13045
13046
13047
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_authorString

The user ID of the latest author to modify the notebook. Corresponds to the JSON property lastAuthor

Returns:

  • (String)


13028
13029
13030
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13028

def last_author
  @last_author
end

#nameString

The name of the notebook. Corresponds to the JSON property name

Returns:

  • (String)


13033
13034
13035
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13033

def name
  @name
end

#notebook_update_timeString

The most recent time the notebook was updated. Corresponds to the JSON property notebookUpdateTime

Returns:

  • (String)


13038
13039
13040
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13038

def notebook_update_time
  @notebook_update_time
end

#serviceString

The source notebook service, for example, "Colab Enterprise". Corresponds to the JSON property service

Returns:

  • (String)


13043
13044
13045
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13043

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13050
13051
13052
13053
13054
13055
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13050

def update!(**args)
  @last_author = args[:last_author] if args.key?(:last_author)
  @name = args[:name] if args.key?(:name)
  @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time)
  @service = args[:service] if args.key?(:service)
end