Class: Google::Apis::SecuritycenterV1::NotificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::NotificationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Cloud Security Command Center (Cloud SCC) notification configs. A notification config is a Cloud SCC resource that contains the configuration to send notifications for create/update events of findings, assets and etc.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the notification config (max of 1024 characters).
-
#name ⇒ String
The relative resource name of this notification config.
-
#pubsub_topic ⇒ String
The Pub/Sub topic to send notifications to.
-
#service_account ⇒ String
Output only.
-
#streaming_config ⇒ Google::Apis::SecuritycenterV1::StreamingConfig
The config for streaming-based notifications, which send each event as soon as it is detected.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationConfig
constructor
A new instance of NotificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationConfig
Returns a new instance of NotificationConfig.
13096 13097 13098 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13096 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the notification config (max of 1024 characters).
Corresponds to the JSON property description
13067 13068 13069 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13067 def description @description end |
#name ⇒ String
The relative resource name of this notification config. See: https://cloud.
google.com/apis/design/resource_names#relative_resource_name Example: "
organizations/organization_id/notificationConfigs/notify_public_bucket", "
folders/folder_id/notificationConfigs/notify_public_bucket", or "projects/
project_id/notificationConfigs/notify_public_bucket".
Corresponds to the JSON property name
13076 13077 13078 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13076 def name @name end |
#pubsub_topic ⇒ String
The Pub/Sub topic to send notifications to. Its format is "projects/[
project_id]/topics/[topic]".
Corresponds to the JSON property pubsubTopic
13082 13083 13084 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13082 def pubsub_topic @pubsub_topic end |
#service_account ⇒ String
Output only. The service account that needs "pubsub.topics.publish" permission
to publish to the Pub/Sub topic.
Corresponds to the JSON property serviceAccount
13088 13089 13090 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13088 def service_account @service_account end |
#streaming_config ⇒ Google::Apis::SecuritycenterV1::StreamingConfig
The config for streaming-based notifications, which send each event as soon as
it is detected.
Corresponds to the JSON property streamingConfig
13094 13095 13096 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13094 def streaming_config @streaming_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13101 13102 13103 13104 13105 13106 13107 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13101 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @service_account = args[:service_account] if args.key?(:service_account) @streaming_config = args[:streaming_config] if args.key?(:streaming_config) end |