Class: Google::Apis::SecuritycenterV1::Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Object

Returns a new instance of Object.



13143
13144
13145
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1::Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



13118
13119
13120
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13118

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


13123
13124
13125
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13123

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


13128
13129
13130
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13128

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


13134
13135
13136
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13134

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


13141
13142
13143
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13141

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13148
13149
13150
13151
13152
13153
13154
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13148

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end