Class: Google::Apis::SecuritycenterV1::Package

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Package is a generic definition of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Package

Returns a new instance of Package.



13130
13131
13132
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpe_uriString

The CPE URI where the vulnerability was detected. Corresponds to the JSON property cpeUri

Returns:

  • (String)


13113
13114
13115
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13113

def cpe_uri
  @cpe_uri
end

#package_nameString

The name of the package where the vulnerability was detected. Corresponds to the JSON property packageName

Returns:

  • (String)


13118
13119
13120
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13118

def package_name
  @package_name
end

#package_typeString

Type of package, for example, os, maven, or go. Corresponds to the JSON property packageType

Returns:

  • (String)


13123
13124
13125
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13123

def package_type
  @package_type
end

#package_versionString

The version of the package. Corresponds to the JSON property packageVersion

Returns:

  • (String)


13128
13129
13130
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13128

def package_version
  @package_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13135
13136
13137
13138
13139
13140
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13135

def update!(**args)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @package_name = args[:package_name] if args.key?(:package_name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @package_version = args[:package_version] if args.key?(:package_version)
end