Class: Google::Apis::SecuritycenterV1::PathNodeAssociatedFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A finding that is associated with this node in the attack path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PathNodeAssociatedFinding

Returns a new instance of PathNodeAssociatedFinding.



13333
13334
13335
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_findingString

Canonical name of the associated findings. Example: organizations/123/sources/ 456/findings/789 Corresponds to the JSON property canonicalFinding

Returns:

  • (String)


13321
13322
13323
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13321

def canonical_finding
  @canonical_finding
end

#finding_categoryString

The additional taxonomy group within findings from a given source. Corresponds to the JSON property findingCategory

Returns:

  • (String)


13326
13327
13328
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13326

def finding_category
  @finding_category
end

#nameString

Full resource name of the finding. Corresponds to the JSON property name

Returns:

  • (String)


13331
13332
13333
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13331

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13338
13339
13340
13341
13342
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13338

def update!(**args)
  @canonical_finding = args[:canonical_finding] if args.key?(:canonical_finding)
  @finding_category = args[:finding_category] if args.key?(:finding_category)
  @name = args[:name] if args.key?(:name)
end