Class: Google::Apis::SecuritycenterV1::PolicyViolationSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Metadata summarizing policy violations of child resources of the affected resource. finding_category and resource determine the exact semantics of the counts. For example, when category= DATA_SECURITY_POSTURE_OBJECT_PUBLIC_ACCESS_VIOLATION and resource='storage. googleapis.com/buckets/my-bucket-name' then this counts the number of Cloud Storage objects in my-bucket-name which violate a Public Access control.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyViolationSummary

Returns a new instance of PolicyViolationSummary.



13398
13399
13400
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conformant_resources_countFixnum

Total number of child resources that conform to the policy. Corresponds to the JSON property conformantResourcesCount

Returns:

  • (Fixnum)


13380
13381
13382
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13380

def conformant_resources_count
  @conformant_resources_count
end

#evaluation_errors_countFixnum

Number of child resources for which errors during evaluation occurred. The evaluation result for these child resources is effectively "unknown". Corresponds to the JSON property evaluationErrorsCount

Returns:

  • (Fixnum)


13386
13387
13388
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13386

def evaluation_errors_count
  @evaluation_errors_count
end

#out_of_scope_resources_countFixnum

Total count of child resources which were not in scope for evaluation. Corresponds to the JSON property outOfScopeResourcesCount

Returns:

  • (Fixnum)


13391
13392
13393
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13391

def out_of_scope_resources_count
  @out_of_scope_resources_count
end

#policy_violations_countFixnum

Count of child resources in violation of the policy. Corresponds to the JSON property policyViolationsCount

Returns:

  • (Fixnum)


13396
13397
13398
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13396

def policy_violations_count
  @policy_violations_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13403
13404
13405
13406
13407
13408
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13403

def update!(**args)
  @conformant_resources_count = args[:conformant_resources_count] if args.key?(:conformant_resources_count)
  @evaluation_errors_count = args[:evaluation_errors_count] if args.key?(:evaluation_errors_count)
  @out_of_scope_resources_count = args[:out_of_scope_resources_count] if args.key?(:out_of_scope_resources_count)
  @policy_violations_count = args[:policy_violations_count] if args.key?(:policy_violations_count)
end