Class: Google::Apis::SecuritycenterV1::PortRange
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::PortRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
A port range which is inclusive of the min and max values. Values are between 0 and 2^16-1. The max can be equal / must be not smaller than the min value. If min and max are equal this indicates that it is a single port.
Instance Attribute Summary collapse
-
#max ⇒ Fixnum
Maximum port value.
-
#min ⇒ Fixnum
Minimum port value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PortRange
constructor
A new instance of PortRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PortRange
Returns a new instance of PortRange.
13427 13428 13429 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max ⇒ Fixnum
Maximum port value.
Corresponds to the JSON property max
13420 13421 13422 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13420 def max @max end |
#min ⇒ Fixnum
Minimum port value.
Corresponds to the JSON property min
13425 13426 13427 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13425 def min @min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13432 13433 13434 13435 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13432 def update!(**args) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) end |