Class: Google::Apis::SecuritycenterV1::ProcessSignature
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::ProcessSignature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Indicates what signature matched this process.
Instance Attribute Summary collapse
-
#memory_hash_signature ⇒ Google::Apis::SecuritycenterV1::MemoryHashSignature
A signature corresponding to memory page hashes.
-
#signature_type ⇒ String
Describes the type of resource associated with the signature.
-
#yara_rule_signature ⇒ Google::Apis::SecuritycenterV1::YaraRuleSignature
A signature corresponding to a YARA rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProcessSignature
constructor
A new instance of ProcessSignature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProcessSignature
Returns a new instance of ProcessSignature.
12783 12784 12785 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memory_hash_signature ⇒ Google::Apis::SecuritycenterV1::MemoryHashSignature
A signature corresponding to memory page hashes.
Corresponds to the JSON property memoryHashSignature
12771 12772 12773 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12771 def memory_hash_signature @memory_hash_signature end |
#signature_type ⇒ String
Describes the type of resource associated with the signature.
Corresponds to the JSON property signatureType
12776 12777 12778 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12776 def signature_type @signature_type end |
#yara_rule_signature ⇒ Google::Apis::SecuritycenterV1::YaraRuleSignature
A signature corresponding to a YARA rule.
Corresponds to the JSON property yaraRuleSignature
12781 12782 12783 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12781 def yara_rule_signature @yara_rule_signature end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12788 12789 12790 12791 12792 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12788 def update!(**args) @memory_hash_signature = args[:memory_hash_signature] if args.key?(:memory_hash_signature) @signature_type = args[:signature_type] if args.key?(:signature_type) @yara_rule_signature = args[:yara_rule_signature] if args.key?(:yara_rule_signature) end |