Class: Google::Apis::SecuritycenterV1::Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information related to the Google Cloud resource that is associated with this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Resource

Returns a new instance of Resource.



13932
13933
13934
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1::AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



13822
13823
13824
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13822

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1::AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



13827
13828
13829
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13827

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1::AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



13832
13833
13834
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13832

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



13837
13838
13839
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13837

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1::AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



13843
13844
13845
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13843

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1::AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



13849
13850
13851
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13849

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the finding is from. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


13854
13855
13856
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13854

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


13859
13860
13861
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13859

def display_name
  @display_name
end

#foldersArray<Google::Apis::SecuritycenterV1::Folder>

Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



13866
13867
13868
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13866

def folders
  @folders
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


13871
13872
13873
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13871

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


13877
13878
13879
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13877

def name
  @name
end

#organizationString

Indicates which organization / tenant the finding is for. Corresponds to the JSON property organization

Returns:

  • (String)


13882
13883
13884
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13882

def organization
  @organization
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


13887
13888
13889
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13887

def parent_display_name
  @parent_display_name
end

#parent_nameString

The full resource name of resource's parent. Corresponds to the JSON property parentName

Returns:

  • (String)


13892
13893
13894
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13892

def parent_name
  @parent_name
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


13897
13898
13899
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13897

def project_display_name
  @project_display_name
end

#project_nameString

The full resource name of project that the resource belongs to. Corresponds to the JSON property projectName

Returns:

  • (String)


13902
13903
13904
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13902

def project_name
  @project_name
end

#resource_pathGoogle::Apis::SecuritycenterV1::ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



13908
13909
13910
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13908

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of org/organization_id/folder/folder_id/folder/folder_id/project/ project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/`organizational_unit_id`/ou/` organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id /mg/management_group_id/subscription/subscription_id/rg/ resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


13920
13921
13922
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13920

def resource_path_string
  @resource_path_string
end

#serviceString

The service or resource provider associated with the resource. Corresponds to the JSON property service

Returns:

  • (String)


13925
13926
13927
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13925

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


13930
13931
13932
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13930

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13937
13938
13939
13940
13941
13942
13943
13944
13945
13946
13947
13948
13949
13950
13951
13952
13953
13954
13955
13956
13957
13958
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13937

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @folders = args[:folders] if args.key?(:folders)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @organization = args[:organization] if args.key?(:organization)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @parent_name = args[:parent_name] if args.key?(:parent_name)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
  @project_name = args[:project_name] if args.key?(:project_name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end