Class: Google::Apis::SecuritycenterV1::ResourcePathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A node within the resource path. Each node represents a resource within the resource hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePathNode

Returns a new instance of ResourcePathNode.



13030
13031
13032
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The display name of the resource this node represents. Corresponds to the JSON property displayName

Returns:

  • (String)


13018
13019
13020
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13018

def display_name
  @display_name
end

#idString

The ID of the resource this node represents. Corresponds to the JSON property id

Returns:

  • (String)


13023
13024
13025
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13023

def id
  @id
end

#node_typeString

The type of resource this node represents. Corresponds to the JSON property nodeType

Returns:

  • (String)


13028
13029
13030
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13028

def node_type
  @node_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13035
13036
13037
13038
13039
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13035

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @node_type = args[:node_type] if args.key?(:node_type)
end