Class: Google::Apis::SecuritycenterV1::SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretEnvironmentVariable

Returns a new instance of SecretEnvironmentVariable.



13955
13956
13957
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


13953
13954
13955
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13953

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13960
13961
13962
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13960

def update!(**args)
  @key = args[:key] if args.key?(:key)
end