Class: Google::Apis::SecuritycenterV1::SecurityBulletin
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::SecurityBulletin
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
SecurityBulletin are notifications of vulnerabilities of Google products.
Instance Attribute Summary collapse
-
#bulletin_id ⇒ String
ID of the bulletin corresponding to the vulnerability.
-
#submission_time ⇒ String
Submission time of this Security Bulletin.
-
#suggested_upgrade_version ⇒ String
This represents a version that the cluster receiving this notification should be upgraded to, based on its current version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityBulletin
constructor
A new instance of SecurityBulletin.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityBulletin
Returns a new instance of SecurityBulletin.
13227 13228 13229 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bulletin_id ⇒ String
ID of the bulletin corresponding to the vulnerability.
Corresponds to the JSON property bulletinId
13214 13215 13216 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13214 def bulletin_id @bulletin_id end |
#submission_time ⇒ String
Submission time of this Security Bulletin.
Corresponds to the JSON property submissionTime
13219 13220 13221 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13219 def submission_time @submission_time end |
#suggested_upgrade_version ⇒ String
This represents a version that the cluster receiving this notification should
be upgraded to, based on its current version. For example, 1.15.0
Corresponds to the JSON property suggestedUpgradeVersion
13225 13226 13227 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13225 def suggested_upgrade_version @suggested_upgrade_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13232 13233 13234 13235 13236 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13232 def update!(**args) @bulletin_id = args[:bulletin_id] if args.key?(:bulletin_id) @submission_time = args[:submission_time] if args.key?(:submission_time) @suggested_upgrade_version = args[:suggested_upgrade_version] if args.key?(:suggested_upgrade_version) end |