Class: Google::Apis::SecuritycenterV1::SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SensitivityScore

Returns a new instance of SensitivityScore.



14278
14279
14280
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


14276
14277
14278
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14276

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14283
14284
14285
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14283

def update!(**args)
  @score = args[:score] if args.key?(:score)
end