Class: Google::Apis::SecuritycenterV1::SimulatedResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Possible test result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SimulatedResult

Returns a new instance of SimulatedResult.



14728
14729
14730
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::SecuritycenterV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



14709
14710
14711
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14709

def error
  @error
end

#findingGoogle::Apis::SecuritycenterV1::Finding

Security Command Center finding. A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding. Corresponds to the JSON property finding



14718
14719
14720
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14718

def finding
  @finding
end

#no_violationGoogle::Apis::SecuritycenterV1::Empty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property noViolation



14726
14727
14728
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14726

def no_violation
  @no_violation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14733
14734
14735
14736
14737
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14733

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @finding = args[:finding] if args.key?(:finding)
  @no_violation = args[:no_violation] if args.key?(:no_violation)
end