Class: Google::Apis::SecuritycenterV1::Simulation
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::Simulation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Attack path simulation
Instance Attribute Summary collapse
-
#cloud_provider ⇒ String
Indicates which cloud provider was used in this simulation.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Full resource name of the Simulation:
organizations/123/simulations/456Corresponds to the JSON propertyname. -
#resource_value_configs_metadata ⇒ Array<Google::Apis::SecuritycenterV1::ResourceValueConfigMetadata>
Resource value configurations' metadata used in this simulation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Simulation
constructor
A new instance of Simulation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Simulation
Returns a new instance of Simulation.
14765 14766 14767 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14765 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_provider ⇒ String
Indicates which cloud provider was used in this simulation.
Corresponds to the JSON property cloudProvider
14747 14748 14749 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14747 def cloud_provider @cloud_provider end |
#create_time ⇒ String
Output only. Time simulation was created
Corresponds to the JSON property createTime
14752 14753 14754 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14752 def create_time @create_time end |
#name ⇒ String
Full resource name of the Simulation: organizations/123/simulations/456
Corresponds to the JSON property name
14757 14758 14759 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14757 def name @name end |
#resource_value_configs_metadata ⇒ Array<Google::Apis::SecuritycenterV1::ResourceValueConfigMetadata>
Resource value configurations' metadata used in this simulation. Maximum of
100.
Corresponds to the JSON property resourceValueConfigsMetadata
14763 14764 14765 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14763 def @resource_value_configs_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14770 14771 14772 14773 14774 14775 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14770 def update!(**args) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @resource_value_configs_metadata = args[:resource_value_configs_metadata] if args.key?(:resource_value_configs_metadata) end |