Class: Google::Apis::SecuritycenterV1::Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Security Command Center finding source. A finding source is an entity or a mechanism that can produce a finding. A source is like a container of findings that come from the same scanner, logger, monitor, and other tools.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Source

Returns a new instance of Source.



14646
14647
14648
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_nameString

The canonical name of the finding source. It's either "organizations/ organization_id/sources/source_id", "folders/folder_id/sources/source_id ", or "projects/project_number/sources/source_id", depending on the closest CRM ancestor of the resource associated with the finding. Corresponds to the JSON property canonicalName

Returns:

  • (String)


14620
14621
14622
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14620

def canonical_name
  @canonical_name
end

#descriptionString

The description of the source (max of 1024 characters). Example: "Web Security Scanner is a web security scanner for common vulnerabilities in App Engine applications. It can automatically scan and detect four common vulnerabilities, including cross-site-scripting (XSS), Flash injection, mixed content (HTTP in HTTPS), and outdated or insecure libraries." Corresponds to the JSON property description

Returns:

  • (String)


14629
14630
14631
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14629

def description
  @description
end

#display_nameString

The source's display name. A source's display name must be unique amongst its siblings, for example, two sources with the same parent can't share the same display name. The display name must have a length between 1 and 64 characters ( inclusive). Corresponds to the JSON property displayName

Returns:

  • (String)


14637
14638
14639
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14637

def display_name
  @display_name
end

#nameString

The relative resource name of this source. See: https://cloud.google.com/apis/ design/resource_names#relative_resource_name Example: "organizations/ organization_id/sources/source_id" Corresponds to the JSON property name

Returns:

  • (String)


14644
14645
14646
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14644

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14651
14652
14653
14654
14655
14656
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14651

def update!(**args)
  @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
end