Class: Google::Apis::SecuritycenterV1::TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketInfo

Returns a new instance of TicketInfo.



15031
15032
15033
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


15004
15005
15006
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15004

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


15009
15010
15011
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15009

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


15014
15015
15016
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15014

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


15019
15020
15021
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15019

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


15024
15025
15026
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15024

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


15029
15030
15031
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15029

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15036
15037
15038
15039
15040
15041
15042
15043
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15036

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end