Class: Google::Apis::SecuritycenterV1::ValuedResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A resource that is determined to have value to a user's system

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValuedResource

Returns a new instance of ValuedResource.



15167
15168
15169
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Human-readable name of the valued resource. Corresponds to the JSON property displayName

Returns:

  • (String)


15130
15131
15132
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15130

def display_name
  @display_name
end

#exposed_scoreFloat

Exposed score for this valued resource. A value of 0 means no exposure was detected exposure. Corresponds to the JSON property exposedScore

Returns:

  • (Float)


15136
15137
15138
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15136

def exposed_score
  @exposed_score
end

#nameString

Valued resource name, for example, e.g.: organizations/123/simulations/456/ valuedResources/789 Corresponds to the JSON property name

Returns:

  • (String)


15142
15143
15144
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15142

def name
  @name
end

#resourceString

The full resource name of the valued resource. Corresponds to the JSON property resource

Returns:

  • (String)


15148
15149
15150
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15148

def resource
  @resource
end

#resource_typeString

The resource type of the valued resource. Corresponds to the JSON property resourceType

Returns:

  • (String)


15154
15155
15156
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15154

def resource_type
  @resource_type
end

#resource_valueString

How valuable this resource is. Corresponds to the JSON property resourceValue

Returns:

  • (String)


15159
15160
15161
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15159

def resource_value
  @resource_value
end

#resource_value_configs_usedArray<Google::Apis::SecuritycenterV1::ResourceValueConfigMetadata>

List of resource value configurations' metadata used to determine the value of this resource. Maximum of 100. Corresponds to the JSON property resourceValueConfigsUsed



15165
15166
15167
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15165

def resource_value_configs_used
  @resource_value_configs_used
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15172
15173
15174
15175
15176
15177
15178
15179
15180
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15172

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exposed_score = args[:exposed_score] if args.key?(:exposed_score)
  @name = args[:name] if args.key?(:name)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @resource_value = args[:resource_value] if args.key?(:resource_value)
  @resource_value_configs_used = args[:resource_value_configs_used] if args.key?(:resource_value_configs_used)
end