Class: Google::Apis::SecuritycenterV1::Asset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Security Command Center representation of a Google Cloud resource. The Asset is a Security Command Center resource that captures information about a single Google Cloud resource. All modifications to an Asset are only within the context of Security Command Center and don't affect the referenced Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Asset

Returns a new instance of Asset.



458
459
460
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_nameString

The canonical name of the resource. It's either "organizations/ organization_id/assets/asset_id", "folders/folder_id/assets/asset_id" or "projects/project_number/assets/asset_id", depending on the closest CRM ancestor of the resource. Corresponds to the JSON property canonicalName

Returns:

  • (String)


412
413
414
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 412

def canonical_name
  @canonical_name
end

#create_timeString

The time at which the asset was created in Security Command Center. Corresponds to the JSON property createTime

Returns:

  • (String)


417
418
419
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 417

def create_time
  @create_time
end

#iam_policyGoogle::Apis::SecuritycenterV1::IamPolicy

Cloud IAM Policy information associated with the Google Cloud resource described by the Security Command Center asset. This information is managed and defined by the Google Cloud resource and cannot be modified by the user. Corresponds to the JSON property iamPolicy



424
425
426
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 424

def iam_policy
  @iam_policy
end

#nameString

The relative resource name of this asset. See: https://cloud.google.com/apis/ design/resource_names#relative_resource_name Example: "organizations/ organization_id/assets/asset_id". Corresponds to the JSON property name

Returns:

  • (String)


431
432
433
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 431

def name
  @name
end

#resource_propertiesHash<String,Object>

Resource managed properties. These properties are managed and defined by the Google Cloud resource and cannot be modified by the user. Corresponds to the JSON property resourceProperties

Returns:



437
438
439
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 437

def resource_properties
  @resource_properties
end

#security_center_propertiesGoogle::Apis::SecuritycenterV1::SecurityCenterProperties

Security Command Center managed properties. These properties are managed by Security Command Center and cannot be modified by the user. Corresponds to the JSON property securityCenterProperties



443
444
445
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 443

def security_center_properties
  @security_center_properties
end

#security_marksGoogle::Apis::SecuritycenterV1::SecurityMarks

User specified security marks that are attached to the parent Security Command Center resource. Security marks are scoped within a Security Command Center organization -- they can be modified and viewed by all users who have proper permissions on the organization. Corresponds to the JSON property securityMarks



451
452
453
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 451

def security_marks
  @security_marks
end

#update_timeString

The time at which the asset was last updated or added in Cloud SCC. Corresponds to the JSON property updateTime

Returns:

  • (String)


456
457
458
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 456

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



463
464
465
466
467
468
469
470
471
472
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 463

def update!(**args)
  @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
  @create_time = args[:create_time] if args.key?(:create_time)
  @iam_policy = args[:iam_policy] if args.key?(:iam_policy)
  @name = args[:name] if args.key?(:name)
  @resource_properties = args[:resource_properties] if args.key?(:resource_properties)
  @security_center_properties = args[:security_center_properties] if args.key?(:security_center_properties)
  @security_marks = args[:security_marks] if args.key?(:security_marks)
  @update_time = args[:update_time] if args.key?(:update_time)
end