Class: Google::Apis::SecuritycenterV1::AttackPathNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Represents one point that an attacker passes through in this attack path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttackPathNode

Returns a new instance of AttackPathNode.



710
711
712
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associated_findingsArray<Google::Apis::SecuritycenterV1::PathNodeAssociatedFinding>

The findings associated with this node in the attack path. Corresponds to the JSON property associatedFindings



680
681
682
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 680

def associated_findings
  @associated_findings
end

#attack_stepsArray<Google::Apis::SecuritycenterV1::AttackStepNode>

A list of attack step nodes that exist in this attack path node. Corresponds to the JSON property attackSteps



685
686
687
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 685

def attack_steps
  @attack_steps
end

#display_nameString

Human-readable name of this resource. Corresponds to the JSON property displayName

Returns:

  • (String)


690
691
692
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 690

def display_name
  @display_name
end

#resourceString

The name of the resource at this point in the attack path. The format of the name follows the Cloud Asset Inventory resource name format Corresponds to the JSON property resource

Returns:

  • (String)


697
698
699
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 697

def resource
  @resource
end

#resource_typeString

The supported resource type Corresponds to the JSON property resourceType

Returns:

  • (String)


703
704
705
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 703

def resource_type
  @resource_type
end

#uuidString

Unique id of the attack path node. Corresponds to the JSON property uuid

Returns:

  • (String)


708
709
710
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 708

def uuid
  @uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



715
716
717
718
719
720
721
722
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 715

def update!(**args)
  @associated_findings = args[:associated_findings] if args.key?(:associated_findings)
  @attack_steps = args[:attack_steps] if args.key?(:attack_steps)
  @display_name = args[:display_name] if args.key?(:display_name)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @uuid = args[:uuid] if args.key?(:uuid)
end