Class: Google::Apis::SecuritycenterV1::BackupDisasterRecovery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information related to Google Cloud Backup and DR Service findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupDisasterRecovery

Returns a new instance of BackupDisasterRecovery.



1173
1174
1175
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applianceString

The name of the Backup and DR appliance that captures, moves, and manages the lifecycle of backup data. For example, backup-server-57137. Corresponds to the JSON property appliance

Returns:

  • (String)


1103
1104
1105
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1103

def appliance
  @appliance
end

#applicationsArray<String>

The names of Backup and DR applications. An application is a VM, database, or file system on a managed host monitored by a backup and recovery appliance. For example, centos7-01-vol00, centos7-01-vol01, centos7-01-vol02. Corresponds to the JSON property applications

Returns:

  • (Array<String>)


1110
1111
1112
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1110

def applications
  @applications
end

#backup_create_timeString

The timestamp at which the Backup and DR backup was created. Corresponds to the JSON property backupCreateTime

Returns:

  • (String)


1115
1116
1117
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1115

def backup_create_time
  @backup_create_time
end

#backup_templateString

The name of a Backup and DR template which comprises one or more backup policies. See the Backup and DR documentation for more information. For example, snap-ov. Corresponds to the JSON property backupTemplate

Returns:

  • (String)


1123
1124
1125
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1123

def backup_template
  @backup_template
end

#backup_typeString

The backup type of the Backup and DR image. For example, Snapshot, Remote Snapshot, OnVault. Corresponds to the JSON property backupType

Returns:

  • (String)


1129
1130
1131
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1129

def backup_type
  @backup_type
end

#hostString

The name of a Backup and DR host, which is managed by the backup and recovery appliance and known to the management console. The host can be of type Generic (for example, Compute Engine, SQL Server, Oracle DB, SMB file system, etc.), vCenter, or an ESX server. See the Backup and DR documentation on hosts for more information. For example, centos7-01. Corresponds to the JSON property host

Returns:

  • (String)


1139
1140
1141
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1139

def host
  @host
end

#policiesArray<String>

The names of Backup and DR policies that are associated with a template and that define when to run a backup, how frequently to run a backup, and how long to retain the backup image. For example, onvaults. Corresponds to the JSON property policies

Returns:

  • (Array<String>)


1146
1147
1148
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1146

def policies
  @policies
end

#policy_optionsArray<String>

The names of Backup and DR advanced policy options of a policy applying to an application. See the Backup and DR documentation on policy options. For example, skipofflineappsincongrp, nounmap. Corresponds to the JSON property policyOptions

Returns:

  • (Array<String>)


1154
1155
1156
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1154

def policy_options
  @policy_options
end

#profileString

The name of the Backup and DR resource profile that specifies the storage media for backups of application and VM data. See the Backup and DR documentation on profiles. For example, GCP. Corresponds to the JSON property profile

Returns:

  • (String)


1162
1163
1164
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1162

def profile
  @profile
end

#storage_poolString

The name of the Backup and DR storage pool that the backup and recovery appliance is storing data in. The storage pool could be of type Cloud, Primary, Snapshot, or OnVault. See the Backup and DR documentation on storage pools. For example, DiskPoolOne. Corresponds to the JSON property storagePool

Returns:

  • (String)


1171
1172
1173
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1171

def storage_pool
  @storage_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1178

def update!(**args)
  @appliance = args[:appliance] if args.key?(:appliance)
  @applications = args[:applications] if args.key?(:applications)
  @backup_create_time = args[:backup_create_time] if args.key?(:backup_create_time)
  @backup_template = args[:backup_template] if args.key?(:backup_template)
  @backup_type = args[:backup_type] if args.key?(:backup_type)
  @host = args[:host] if args.key?(:host)
  @policies = args[:policies] if args.key?(:policies)
  @policy_options = args[:policy_options] if args.key?(:policy_options)
  @profile = args[:profile] if args.key?(:profile)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
end