Class: Google::Apis::SecuritycenterV1::Compliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Contains compliance information about a security standard indicating unmet recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Compliance

Returns a new instance of Compliance.



1649
1650
1651
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idsArray<String>

Policies within the standard or benchmark, for example, A.12.4.1 Corresponds to the JSON property ids

Returns:

  • (Array<String>)


1637
1638
1639
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1637

def ids
  @ids
end

#standardString

Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


1642
1643
1644
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1642

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property version

Returns:

  • (String)


1647
1648
1649
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1647

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1654
1655
1656
1657
1658
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1654

def update!(**args)
  @ids = args[:ids] if args.key?(:ids)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end