Class: Google::Apis::SecuritycenterV1::CustomModuleValidationError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

An error encountered while validating the uploaded configuration of an Event Threat Detection Custom Module.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomModuleValidationError

Returns a new instance of CustomModuleValidationError.



1898
1899
1900
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of the error, suitable for human consumption. Required. Corresponds to the JSON property description

Returns:

  • (String)


1880
1881
1882
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1880

def description
  @description
end

#endGoogle::Apis::SecuritycenterV1::Position

A position in the uploaded text version of a module. Corresponds to the JSON property end



1885
1886
1887
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1885

def end
  @end
end

#field_pathString

The path, in RFC 8901 JSON Pointer format, to the field that failed validation. This may be left empty if no specific field is affected. Corresponds to the JSON property fieldPath

Returns:

  • (String)


1891
1892
1893
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1891

def field_path
  @field_path
end

#startGoogle::Apis::SecuritycenterV1::Position

A position in the uploaded text version of a module. Corresponds to the JSON property start



1896
1897
1898
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1896

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1903
1904
1905
1906
1907
1908
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1903

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @end = args[:end] if args.key?(:end)
  @field_path = args[:field_path] if args.key?(:field_path)
  @start = args[:start] if args.key?(:start)
end