Class: Google::Apis::SecuritycenterV1::Cve

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

CVE stands for Common Vulnerabilities and Exposures. Information from the CVE record that describes this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cve

Returns a new instance of Cve.



1991
1992
1993
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvssv3Google::Apis::SecuritycenterV1::Cvssv3

Common Vulnerability Scoring System version 3. Corresponds to the JSON property cvssv3



1940
1941
1942
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1940

def cvssv3
  @cvssv3
end

#exploit_release_dateString

Date the first publicly available exploit or PoC was released. Corresponds to the JSON property exploitReleaseDate

Returns:

  • (String)


1945
1946
1947
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1945

def exploit_release_date
  @exploit_release_date
end

#exploitation_activityString

The exploitation activity of the vulnerability in the wild. Corresponds to the JSON property exploitationActivity

Returns:

  • (String)


1950
1951
1952
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1950

def exploitation_activity
  @exploitation_activity
end

#first_exploitation_dateString

Date of the earliest known exploitation. Corresponds to the JSON property firstExploitationDate

Returns:

  • (String)


1955
1956
1957
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1955

def first_exploitation_date
  @first_exploitation_date
end

#idString

The unique identifier for the vulnerability. e.g. CVE-2021-34527 Corresponds to the JSON property id

Returns:

  • (String)


1960
1961
1962
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1960

def id
  @id
end

#impactString

The potential impact of the vulnerability if it was to be exploited. Corresponds to the JSON property impact

Returns:

  • (String)


1965
1966
1967
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1965

def impact
  @impact
end

#observed_in_the_wildBoolean Also known as: observed_in_the_wild?

Whether or not the vulnerability has been observed in the wild. Corresponds to the JSON property observedInTheWild

Returns:

  • (Boolean)


1970
1971
1972
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1970

def observed_in_the_wild
  @observed_in_the_wild
end

#referencesArray<Google::Apis::SecuritycenterV1::Reference>

Additional information about the CVE. e.g. https://cve.mitre.org/cgi-bin/ cvename.cgi?name=CVE-2021-34527 Corresponds to the JSON property references



1977
1978
1979
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1977

def references
  @references
end

#upstream_fix_availableBoolean Also known as: upstream_fix_available?

Whether upstream fix is available for the CVE. Corresponds to the JSON property upstreamFixAvailable

Returns:

  • (Boolean)


1982
1983
1984
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1982

def upstream_fix_available
  @upstream_fix_available
end

#zero_dayBoolean Also known as: zero_day?

Whether or not the vulnerability was zero day when the finding was published. Corresponds to the JSON property zeroDay

Returns:

  • (Boolean)


1988
1989
1990
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1988

def zero_day
  @zero_day
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 1996

def update!(**args)
  @cvssv3 = args[:cvssv3] if args.key?(:cvssv3)
  @exploit_release_date = args[:exploit_release_date] if args.key?(:exploit_release_date)
  @exploitation_activity = args[:exploitation_activity] if args.key?(:exploitation_activity)
  @first_exploitation_date = args[:first_exploitation_date] if args.key?(:first_exploitation_date)
  @id = args[:id] if args.key?(:id)
  @impact = args[:impact] if args.key?(:impact)
  @observed_in_the_wild = args[:observed_in_the_wild] if args.key?(:observed_in_the_wild)
  @references = args[:references] if args.key?(:references)
  @upstream_fix_available = args[:upstream_fix_available] if args.key?(:upstream_fix_available)
  @zero_day = args[:zero_day] if args.key?(:zero_day)
end