Class: Google::Apis::SecuritycenterV1::Cvssv3

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Common Vulnerability Scoring System version 3.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cvssv3

Returns a new instance of Cvssv3.



2069
2070
2071
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_complexityString

This metric describes the conditions beyond the attacker's control that must exist in order to exploit the vulnerability. Corresponds to the JSON property attackComplexity

Returns:

  • (String)


2018
2019
2020
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2018

def attack_complexity
  @attack_complexity
end

#attack_vectorString

Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments. This metric reflects the context by which vulnerability exploitation is possible. Corresponds to the JSON property attackVector

Returns:

  • (String)


2025
2026
2027
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2025

def attack_vector
  @attack_vector
end

#availability_impactString

This metric measures the impact to the availability of the impacted component resulting from a successfully exploited vulnerability. Corresponds to the JSON property availabilityImpact

Returns:

  • (String)


2031
2032
2033
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2031

def availability_impact
  @availability_impact
end

#base_scoreFloat

The base score is a function of the base metric scores. Corresponds to the JSON property baseScore

Returns:

  • (Float)


2036
2037
2038
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2036

def base_score
  @base_score
end

#confidentiality_impactString

This metric measures the impact to the confidentiality of the information resources managed by a software component due to a successfully exploited vulnerability. Corresponds to the JSON property confidentialityImpact

Returns:

  • (String)


2043
2044
2045
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2043

def confidentiality_impact
  @confidentiality_impact
end

#integrity_impactString

This metric measures the impact to integrity of a successfully exploited vulnerability. Corresponds to the JSON property integrityImpact

Returns:

  • (String)


2049
2050
2051
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2049

def integrity_impact
  @integrity_impact
end

#privileges_requiredString

This metric describes the level of privileges an attacker must possess before successfully exploiting the vulnerability. Corresponds to the JSON property privilegesRequired

Returns:

  • (String)


2055
2056
2057
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2055

def privileges_required
  @privileges_required
end

#scopeString

The Scope metric captures whether a vulnerability in one vulnerable component impacts resources in components beyond its security scope. Corresponds to the JSON property scope

Returns:

  • (String)


2061
2062
2063
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2061

def scope
  @scope
end

#user_interactionString

This metric captures the requirement for a human user, other than the attacker, to participate in the successful compromise of the vulnerable component. Corresponds to the JSON property userInteraction

Returns:

  • (String)


2067
2068
2069
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2067

def user_interaction
  @user_interaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2074

def update!(**args)
  @attack_complexity = args[:attack_complexity] if args.key?(:attack_complexity)
  @attack_vector = args[:attack_vector] if args.key?(:attack_vector)
  @availability_impact = args[:availability_impact] if args.key?(:availability_impact)
  @base_score = args[:base_score] if args.key?(:base_score)
  @confidentiality_impact = args[:confidentiality_impact] if args.key?(:confidentiality_impact)
  @integrity_impact = args[:integrity_impact] if args.key?(:integrity_impact)
  @privileges_required = args[:privileges_required] if args.key?(:privileges_required)
  @scope = args[:scope] if args.key?(:scope)
  @user_interaction = args[:user_interaction] if args.key?(:user_interaction)
end