Class: Google::Apis::SecuritycenterV1::DataRetentionDeletionEvent
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::DataRetentionDeletionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Details about data retention deletion violations, in which the data is non- compliant based on their retention or deletion time, as defined in the applicable data security policy. The Data Retention Deletion (DRD) control is a control of the DSPM (Data Security Posture Management) suite that enables organizations to manage data retention and deletion policies in compliance with regulations, such as GDPR and CRPA. DRD supports two primary policy types: maximum storage length (max TTL) and minimum storage length (min TTL). Both are aimed at helping organizations meet regulatory and data management commitments.
Instance Attribute Summary collapse
-
#data_object_count ⇒ Fixnum
Number of objects that violated the policy for this resource.
-
#event_detection_time ⇒ String
Timestamp indicating when the event was detected.
-
#event_type ⇒ String
Type of the DRD event.
-
#max_retention_allowed ⇒ String
Maximum duration of retention allowed from the DRD control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataRetentionDeletionEvent
constructor
A new instance of DataRetentionDeletionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataRetentionDeletionEvent
Returns a new instance of DataRetentionDeletionEvent.
2239 2240 2241 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_object_count ⇒ Fixnum
Number of objects that violated the policy for this resource. If the number is
less than 1,000, then the value of this field is the exact number. If the
number of objects that violated the policy is greater than or equal to 1,000,
then the value of this field is 1000.
Corresponds to the JSON property dataObjectCount
2217 2218 2219 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2217 def data_object_count @data_object_count end |
#event_detection_time ⇒ String
Timestamp indicating when the event was detected.
Corresponds to the JSON property eventDetectionTime
2222 2223 2224 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2222 def event_detection_time @event_detection_time end |
#event_type ⇒ String
Type of the DRD event.
Corresponds to the JSON property eventType
2227 2228 2229 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2227 def event_type @event_type end |
#max_retention_allowed ⇒ String
Maximum duration of retention allowed from the DRD control. This comes from
the DRD control where users set a max TTL for their data. For example, suppose
that a user sets the max TTL for a Cloud Storage bucket to 90 days. However,
an object in that bucket is 100 days old. In this case, a
DataRetentionDeletionEvent will be generated for that Cloud Storage bucket,
and the max_retention_allowed is 90 days.
Corresponds to the JSON property maxRetentionAllowed
2237 2238 2239 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2237 def max_retention_allowed @max_retention_allowed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2244 2245 2246 2247 2248 2249 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2244 def update!(**args) @data_object_count = args[:data_object_count] if args.key?(:data_object_count) @event_detection_time = args[:event_detection_time] if args.key?(:event_detection_time) @event_type = args[:event_type] if args.key?(:event_type) @max_retention_allowed = args[:max_retention_allowed] if args.key?(:max_retention_allowed) end |