Class: Google::Apis::SecuritycenterV1::EventThreatDetectionCustomModule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Represents an instance of an Event Threat Detection custom module, including its full module name, display name, enablement state, and last updated time. You can create a custom module at the organization, folder, or project level. Custom modules that you create at the organization or folder level are inherited by child folders and projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventThreatDetectionCustomModule

Returns a new instance of EventThreatDetectionCustomModule.



2642
2643
2644
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ancestor_moduleString

Output only. The closest ancestor module that this module inherits the enablement state from. The format is the same as the EventThreatDetectionCustomModule resource name. Corresponds to the JSON property ancestorModule

Returns:

  • (String)


2589
2590
2591
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2589

def ancestor_module
  @ancestor_module
end

#cloud_providerString

The cloud provider of the custom module. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


2594
2595
2596
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2594

def cloud_provider
  @cloud_provider
end

#configHash<String,Object>

Config for the module. For the resident module, its config value is defined at this level. For the inherited module, its config value is inherited from the ancestor module. Corresponds to the JSON property config

Returns:



2601
2602
2603
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2601

def config
  @config
end

#descriptionString

The description for the module. Corresponds to the JSON property description

Returns:

  • (String)


2606
2607
2608
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2606

def description
  @description
end

#display_nameString

The human readable name to be displayed for the module. Corresponds to the JSON property displayName

Returns:

  • (String)


2611
2612
2613
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2611

def display_name
  @display_name
end

#enablement_stateString

The state of enablement for the module at the given level of the hierarchy. Corresponds to the JSON property enablementState

Returns:

  • (String)


2616
2617
2618
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2616

def enablement_state
  @enablement_state
end

#last_editorString

Output only. The editor the module was last updated by. Corresponds to the JSON property lastEditor

Returns:

  • (String)


2621
2622
2623
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2621

def last_editor
  @last_editor
end

#nameString

Immutable. The resource name of the Event Threat Detection custom module. Its format is: * organizations/organization/eventThreatDetectionSettings/ customModules/module. * `folders/`folder`/eventThreatDetectionSettings/ customModules/`module. * projects/project/eventThreatDetectionSettings/ customModules/module`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2630
2631
2632
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2630

def name
  @name
end

#typeString

Type for the module. e.g. CONFIGURABLE_BAD_IP. Corresponds to the JSON property type

Returns:

  • (String)


2635
2636
2637
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2635

def type
  @type
end

#update_timeString

Output only. The time the module was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2640
2641
2642
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2640

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2647

def update!(**args)
  @ancestor_module = args[:ancestor_module] if args.key?(:ancestor_module)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @config = args[:config] if args.key?(:config)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enablement_state = args[:enablement_state] if args.key?(:enablement_state)
  @last_editor = args[:last_editor] if args.key?(:last_editor)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end