Class: Google::Apis::SecuritycenterV1::ExfilResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Resource where data was exfiltrated from or exfiltrated to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExfilResource

Returns a new instance of ExfilResource.



2679
2680
2681
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#componentsArray<String>

Subcomponents of the asset that was exfiltrated, like URIs used during exfiltration, table names, databases, and filenames. For example, multiple tables might have been exfiltrated from the same Cloud SQL instance, or multiple files might have been exfiltrated from the same Cloud Storage bucket. Corresponds to the JSON property components

Returns:

  • (Array<String>)


2671
2672
2673
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2671

def components
  @components
end

#nameString

The resource's full resource name. Corresponds to the JSON property name

Returns:

  • (String)


2677
2678
2679
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2677

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2684
2685
2686
2687
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2684

def update!(**args)
  @components = args[:components] if args.key?(:components)
  @name = args[:name] if args.key?(:name)
end