Class: Google::Apis::SecuritycenterV1::Exfiltration
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::Exfiltration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Exfiltration represents a data exfiltration attempt from one or more sources
to one or more targets. The sources attribute lists the sources of the
exfiltrated data. The targets attribute lists the destinations the data was
copied to.
Instance Attribute Summary collapse
-
#sources ⇒ Array<Google::Apis::SecuritycenterV1::ExfilResource>
If there are multiple sources, then the data is considered "joined" between them.
-
#targets ⇒ Array<Google::Apis::SecuritycenterV1::ExfilResource>
If there are multiple targets, each target would get a complete copy of the " joined" source data.
-
#total_exfiltrated_bytes ⇒ Fixnum
Total exfiltrated bytes processed for the entire job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Exfiltration
constructor
A new instance of Exfiltration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Exfiltration
Returns a new instance of Exfiltration.
2878 2879 2880 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sources ⇒ Array<Google::Apis::SecuritycenterV1::ExfilResource>
If there are multiple sources, then the data is considered "joined" between
them. For instance, BigQuery can join multiple tables, and each table would be
considered a source.
Corresponds to the JSON property sources
2865 2866 2867 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2865 def sources @sources end |
#targets ⇒ Array<Google::Apis::SecuritycenterV1::ExfilResource>
If there are multiple targets, each target would get a complete copy of the "
joined" source data.
Corresponds to the JSON property targets
2871 2872 2873 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2871 def targets @targets end |
#total_exfiltrated_bytes ⇒ Fixnum
Total exfiltrated bytes processed for the entire job.
Corresponds to the JSON property totalExfiltratedBytes
2876 2877 2878 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2876 def total_exfiltrated_bytes @total_exfiltrated_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2883 2884 2885 2886 2887 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2883 def update!(**args) @sources = args[:sources] if args.key?(:sources) @targets = args[:targets] if args.key?(:targets) @total_exfiltrated_bytes = args[:total_exfiltrated_bytes] if args.key?(:total_exfiltrated_bytes) end |