Class: Google::Apis::SecuritycenterV1::ExternalExposure
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::ExternalExposure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Details about the externally exposed resource associated with the finding.
Instance Attribute Summary collapse
-
#backend_bucket ⇒ String
The full resource name of the load balancer backend bucket, for example, "// compute.googleapis.com/projects/
project-id/global/backendBuckets/name" Corresponds to the JSON propertybackendBucket. -
#backend_service ⇒ String
The full resource name of load balancer backend service, for example, "// compute.googleapis.com/projects/
project-id/global/backendServices/name". -
#exposed_application ⇒ String
The name and version of the exposed web application, for example, "Jenkins 2.
-
#exposed_endpoint ⇒ String
The resource which is running the exposed service, for example, "//compute.
-
#exposed_service ⇒ String
The name and version of the service, for example, "Jupyter Notebook 6.14.0".
-
#forwarding_rule ⇒ String
The full resource name of the forwarding rule, for example, "//compute.
-
#hostname_uri ⇒ String
Hostname of the exposed application, for example, "https://test-app.a.run.app/" Corresponds to the JSON property
hostnameUri. -
#http_response ⇒ Array<Google::Apis::SecuritycenterV1::HttpResponse>
The http response returned by the web application.
-
#instance_group ⇒ String
The full resource name of the instance group, for example, "//compute.
-
#internal_backend_service ⇒ String
The full resource name of load balancer backend service in the internal project having resource exposed via PSC, for example, "//compute.googleapis.
-
#load_balancer_firewall_policy ⇒ String
The full resource name of the load balancer firewall policy, for example, "// compute.googleapis.com/projects/
project-id/global/firewallPolicies/policy- name". -
#network_endpoint_group ⇒ String
The full resource name of the network endpoint group, for example, "//compute.
-
#network_ingress_firewall_policy ⇒ String
The full resource name of the network ingress firewall policy, for example, "// compute.googleapis.com/projects/
project-id/global/firewallPolicies/name". -
#private_ip_address ⇒ String
Private IP address of the exposed endpoint.
-
#private_port ⇒ String
Port number associated with private IP address.
-
#psc_network_attachment ⇒ String
The full resource name of the PSC (Private Service Connect) network attachment that network interface controller is attached to, for example, "//compute.
-
#psc_service_attachment ⇒ String
The full resource name of the PSC (Private Service Connect) service attachment that the load balancer network endpoint group targets, for example, "//compute.
-
#public_ip_address ⇒ String
Public IP address of the exposed endpoint.
-
#public_port ⇒ String
Public port number of the exposed endpoint.
-
#service_firewall_policy ⇒ String
The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/
project-id/global/ firewallPolicies/policy-name".
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalExposure
constructor
A new instance of ExternalExposure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalExposure
Returns a new instance of ExternalExposure.
3107 3108 3109 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_bucket ⇒ String
The full resource name of the load balancer backend bucket, for example, "//
compute.googleapis.com/projects/project-id/global/backendBuckets/name"
Corresponds to the JSON property backendBucket
2990 2991 2992 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2990 def backend_bucket @backend_bucket end |
#backend_service ⇒ String
The full resource name of load balancer backend service, for example, "//
compute.googleapis.com/projects/project-id/global/backendServices/name".
Corresponds to the JSON property backendService
2996 2997 2998 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2996 def backend_service @backend_service end |
#exposed_application ⇒ String
The name and version of the exposed web application, for example, "Jenkins 2.
184".
Corresponds to the JSON property exposedApplication
3002 3003 3004 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3002 def exposed_application @exposed_application end |
#exposed_endpoint ⇒ String
The resource which is running the exposed service, for example, "//compute.
googleapis.com/projects/project-id/zones/zone/instances/instance.”
Corresponds to the JSON property exposedEndpoint
3008 3009 3010 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3008 def exposed_endpoint @exposed_endpoint end |
#exposed_service ⇒ String
The name and version of the service, for example, "Jupyter Notebook 6.14.0".
Corresponds to the JSON property exposedService
3013 3014 3015 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3013 def exposed_service @exposed_service end |
#forwarding_rule ⇒ String
The full resource name of the forwarding rule, for example, "//compute.
googleapis.com/projects/project-id/global/forwardingRules/forwarding-rule-
name".
Corresponds to the JSON property forwardingRule
3020 3021 3022 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3020 def forwarding_rule @forwarding_rule end |
#hostname_uri ⇒ String
Hostname of the exposed application, for example, "https://test-app.a.run.app/"
Corresponds to the JSON property hostnameUri
3025 3026 3027 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3025 def hostname_uri @hostname_uri end |
#http_response ⇒ Array<Google::Apis::SecuritycenterV1::HttpResponse>
The http response returned by the web application.
Corresponds to the JSON property httpResponse
3030 3031 3032 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3030 def http_response @http_response end |
#instance_group ⇒ String
The full resource name of the instance group, for example, "//compute.
googleapis.com/projects/project-id/global/instanceGroups/name".
Corresponds to the JSON property instanceGroup
3036 3037 3038 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3036 def instance_group @instance_group end |
#internal_backend_service ⇒ String
The full resource name of load balancer backend service in the internal
project having resource exposed via PSC, for example, "//compute.googleapis.
com/projects/project-id/global/backendServices/name".
Corresponds to the JSON property internalBackendService
3043 3044 3045 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3043 def internal_backend_service @internal_backend_service end |
#load_balancer_firewall_policy ⇒ String
The full resource name of the load balancer firewall policy, for example, "//
compute.googleapis.com/projects/project-id/global/firewallPolicies/policy-
name".
Corresponds to the JSON property loadBalancerFirewallPolicy
3050 3051 3052 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3050 def load_balancer_firewall_policy @load_balancer_firewall_policy end |
#network_endpoint_group ⇒ String
The full resource name of the network endpoint group, for example, "//compute.
googleapis.com/projects/project-id/global/networkEndpointGroups/name".
Corresponds to the JSON property networkEndpointGroup
3056 3057 3058 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3056 def network_endpoint_group @network_endpoint_group end |
#network_ingress_firewall_policy ⇒ String
The full resource name of the network ingress firewall policy, for example, "//
compute.googleapis.com/projects/project-id/global/firewallPolicies/name".
Corresponds to the JSON property networkIngressFirewallPolicy
3062 3063 3064 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3062 def network_ingress_firewall_policy @network_ingress_firewall_policy end |
#private_ip_address ⇒ String
Private IP address of the exposed endpoint.
Corresponds to the JSON property privateIpAddress
3067 3068 3069 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3067 def private_ip_address @private_ip_address end |
#private_port ⇒ String
Port number associated with private IP address.
Corresponds to the JSON property privatePort
3072 3073 3074 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3072 def private_port @private_port end |
#psc_network_attachment ⇒ String
The full resource name of the PSC (Private Service Connect) network attachment
that network interface controller is attached to, for example, "//compute.
googleapis.com/projects/project-id/regions/region/networkAttachments/name
"
Corresponds to the JSON property pscNetworkAttachment
3080 3081 3082 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3080 def @psc_network_attachment end |
#psc_service_attachment ⇒ String
The full resource name of the PSC (Private Service Connect) service attachment
that the load balancer network endpoint group targets, for example, "//compute.
googleapis.com/projects/project-id/regions/region/serviceAttachments/name
"
Corresponds to the JSON property pscServiceAttachment
3088 3089 3090 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3088 def @psc_service_attachment end |
#public_ip_address ⇒ String
Public IP address of the exposed endpoint.
Corresponds to the JSON property publicIpAddress
3093 3094 3095 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3093 def public_ip_address @public_ip_address end |
#public_port ⇒ String
Public port number of the exposed endpoint.
Corresponds to the JSON property publicPort
3098 3099 3100 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3098 def public_port @public_port end |
#service_firewall_policy ⇒ String
The full resource name of the firewall policy of the exposed service, for
example, "//compute.googleapis.com/projects/project-id/global/
firewallPolicies/policy-name".
Corresponds to the JSON property serviceFirewallPolicy
3105 3106 3107 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3105 def service_firewall_policy @service_firewall_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3112 def update!(**args) @backend_bucket = args[:backend_bucket] if args.key?(:backend_bucket) @backend_service = args[:backend_service] if args.key?(:backend_service) @exposed_application = args[:exposed_application] if args.key?(:exposed_application) @exposed_endpoint = args[:exposed_endpoint] if args.key?(:exposed_endpoint) @exposed_service = args[:exposed_service] if args.key?(:exposed_service) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @hostname_uri = args[:hostname_uri] if args.key?(:hostname_uri) @http_response = args[:http_response] if args.key?(:http_response) @instance_group = args[:instance_group] if args.key?(:instance_group) @internal_backend_service = args[:internal_backend_service] if args.key?(:internal_backend_service) @load_balancer_firewall_policy = args[:load_balancer_firewall_policy] if args.key?(:load_balancer_firewall_policy) @network_endpoint_group = args[:network_endpoint_group] if args.key?(:network_endpoint_group) @network_ingress_firewall_policy = args[:network_ingress_firewall_policy] if args.key?(:network_ingress_firewall_policy) @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address) @private_port = args[:private_port] if args.key?(:private_port) @psc_network_attachment = args[:psc_network_attachment] if args.key?(:psc_network_attachment) @psc_service_attachment = args[:psc_service_attachment] if args.key?(:psc_service_attachment) @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address) @public_port = args[:public_port] if args.key?(:public_port) @service_firewall_policy = args[:service_firewall_policy] if args.key?(:service_firewall_policy) end |