Class: Google::Apis::SecuritycenterV1::ExternalExposure
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::ExternalExposure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Details about the externally exposed resource associated with the finding.
Instance Attribute Summary collapse
-
#backend_service ⇒ String
The full resource name of load balancer backend service, for example, "// compute.googleapis.com/projects/
project-id/global/backendServices/name". -
#exposed_endpoint ⇒ String
The resource which is running the exposed service, for example, "//compute.
-
#exposed_service ⇒ String
The name and version of the service, for example, "Jupyter Notebook 6.14.0".
-
#forwarding_rule ⇒ String
The full resource name of the forwarding rule, for example, "//compute.
-
#instance_group ⇒ String
The full resource name of the instance group, for example, "//compute.
-
#load_balancer_firewall_policy ⇒ String
The full resource name of the load balancer firewall policy, for example, "// compute.googleapis.com/projects/
project-id/global/firewallPolicies/policy- name". -
#network_endpoint_group ⇒ String
The full resource name of the network endpoint group, for example, "//compute.
-
#private_ip_address ⇒ String
Private IP address of the exposed endpoint.
-
#private_port ⇒ String
Port number associated with private IP address.
-
#public_ip_address ⇒ String
Public IP address of the exposed endpoint.
-
#public_port ⇒ String
Public port number of the exposed endpoint.
-
#service_firewall_policy ⇒ String
The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/
project-id/global/ firewallPolicies/policy-name".
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalExposure
constructor
A new instance of ExternalExposure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalExposure
Returns a new instance of ExternalExposure.
3056 3057 3058 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_service ⇒ String
The full resource name of load balancer backend service, for example, "//
compute.googleapis.com/projects/project-id/global/backendServices/name".
Corresponds to the JSON property backendService
2990 2991 2992 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2990 def backend_service @backend_service end |
#exposed_endpoint ⇒ String
The resource which is running the exposed service, for example, "//compute.
googleapis.com/projects/project-id/zones/zone/instances/instance.”
Corresponds to the JSON property exposedEndpoint
2996 2997 2998 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2996 def exposed_endpoint @exposed_endpoint end |
#exposed_service ⇒ String
The name and version of the service, for example, "Jupyter Notebook 6.14.0".
Corresponds to the JSON property exposedService
3001 3002 3003 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3001 def exposed_service @exposed_service end |
#forwarding_rule ⇒ String
The full resource name of the forwarding rule, for example, "//compute.
googleapis.com/projects/project-id/global/forwardingRules/forwarding-rule-
name".
Corresponds to the JSON property forwardingRule
3008 3009 3010 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3008 def forwarding_rule @forwarding_rule end |
#instance_group ⇒ String
The full resource name of the instance group, for example, "//compute.
googleapis.com/projects/project-id/global/instanceGroups/name".
Corresponds to the JSON property instanceGroup
3014 3015 3016 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3014 def instance_group @instance_group end |
#load_balancer_firewall_policy ⇒ String
The full resource name of the load balancer firewall policy, for example, "//
compute.googleapis.com/projects/project-id/global/firewallPolicies/policy-
name".
Corresponds to the JSON property loadBalancerFirewallPolicy
3021 3022 3023 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3021 def load_balancer_firewall_policy @load_balancer_firewall_policy end |
#network_endpoint_group ⇒ String
The full resource name of the network endpoint group, for example, "//compute.
googleapis.com/projects/project-id/global/networkEndpointGroups/name".
Corresponds to the JSON property networkEndpointGroup
3027 3028 3029 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3027 def network_endpoint_group @network_endpoint_group end |
#private_ip_address ⇒ String
Private IP address of the exposed endpoint.
Corresponds to the JSON property privateIpAddress
3032 3033 3034 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3032 def private_ip_address @private_ip_address end |
#private_port ⇒ String
Port number associated with private IP address.
Corresponds to the JSON property privatePort
3037 3038 3039 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3037 def private_port @private_port end |
#public_ip_address ⇒ String
Public IP address of the exposed endpoint.
Corresponds to the JSON property publicIpAddress
3042 3043 3044 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3042 def public_ip_address @public_ip_address end |
#public_port ⇒ String
Public port number of the exposed endpoint.
Corresponds to the JSON property publicPort
3047 3048 3049 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3047 def public_port @public_port end |
#service_firewall_policy ⇒ String
The full resource name of the firewall policy of the exposed service, for
example, "//compute.googleapis.com/projects/project-id/global/
firewallPolicies/policy-name".
Corresponds to the JSON property serviceFirewallPolicy
3054 3055 3056 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3054 def service_firewall_policy @service_firewall_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3061 def update!(**args) @backend_service = args[:backend_service] if args.key?(:backend_service) @exposed_endpoint = args[:exposed_endpoint] if args.key?(:exposed_endpoint) @exposed_service = args[:exposed_service] if args.key?(:exposed_service) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @instance_group = args[:instance_group] if args.key?(:instance_group) @load_balancer_firewall_policy = args[:load_balancer_firewall_policy] if args.key?(:load_balancer_firewall_policy) @network_endpoint_group = args[:network_endpoint_group] if args.key?(:network_endpoint_group) @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address) @private_port = args[:private_port] if args.key?(:private_port) @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address) @public_port = args[:public_port] if args.key?(:public_port) @service_firewall_policy = args[:service_firewall_policy] if args.key?(:service_firewall_policy) end |