Class: Google::Apis::SecuritycenterV1::File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

File information about the related binary/library used by an executable, or the script used by a script interpreter

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ File

Returns a new instance of File.



3130
3131
3132
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Prefix of the file contents as a JSON-encoded string. Corresponds to the JSON property contents

Returns:

  • (String)


3085
3086
3087
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3085

def contents
  @contents
end

#disk_pathGoogle::Apis::SecuritycenterV1::DiskPath

Path of the file in terms of underlying disk/partition identifiers. Corresponds to the JSON property diskPath



3090
3091
3092
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3090

def disk_path
  @disk_path
end

#file_load_stateString

The load state of the file. Corresponds to the JSON property fileLoadState

Returns:

  • (String)


3095
3096
3097
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3095

def file_load_state
  @file_load_state
end

#hashed_sizeFixnum

The length in bytes of the file prefix that was hashed. If hashed_size == size, any hashes reported represent the entire file. Corresponds to the JSON property hashedSize

Returns:

  • (Fixnum)


3101
3102
3103
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3101

def hashed_size
  @hashed_size
end

#operationsArray<Google::Apis::SecuritycenterV1::FileOperation>

Operation(s) performed on a file. Corresponds to the JSON property operations



3106
3107
3108
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3106

def operations
  @operations
end

#partially_hashedBoolean Also known as: partially_hashed?

True when the hash covers only a prefix of the file. Corresponds to the JSON property partiallyHashed

Returns:

  • (Boolean)


3111
3112
3113
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3111

def partially_hashed
  @partially_hashed
end

#pathString

Absolute path of the file as a JSON encoded string. Corresponds to the JSON property path

Returns:

  • (String)


3117
3118
3119
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3117

def path
  @path
end

#sha256String

SHA256 hash of the first hashed_size bytes of the file encoded as a hex string. If hashed_size == size, sha256 represents the SHA256 hash of the entire file. Corresponds to the JSON property sha256

Returns:

  • (String)


3123
3124
3125
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3123

def sha256
  @sha256
end

#sizeFixnum

Size of the file in bytes. Corresponds to the JSON property size

Returns:

  • (Fixnum)


3128
3129
3130
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3128

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3135

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @disk_path = args[:disk_path] if args.key?(:disk_path)
  @file_load_state = args[:file_load_state] if args.key?(:file_load_state)
  @hashed_size = args[:hashed_size] if args.key?(:hashed_size)
  @operations = args[:operations] if args.key?(:operations)
  @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed)
  @path = args[:path] if args.key?(:path)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @size = args[:size] if args.key?(:size)
end