Class: Google::Apis::SecuritycenterV1::File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

File information about the related binary/library used by an executable, or the script used by a script interpreter

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ File

Returns a new instance of File.



2872
2873
2874
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Prefix of the file contents as a JSON-encoded string. Corresponds to the JSON property contents

Returns:

  • (String)


2827
2828
2829
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2827

def contents
  @contents
end

#disk_pathGoogle::Apis::SecuritycenterV1::DiskPath

Path of the file in terms of underlying disk/partition identifiers. Corresponds to the JSON property diskPath



2832
2833
2834
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2832

def disk_path
  @disk_path
end

#file_load_stateString

The load state of the file. Corresponds to the JSON property fileLoadState

Returns:

  • (String)


2837
2838
2839
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2837

def file_load_state
  @file_load_state
end

#hashed_sizeFixnum

The length in bytes of the file prefix that was hashed. If hashed_size == size, any hashes reported represent the entire file. Corresponds to the JSON property hashedSize

Returns:

  • (Fixnum)


2843
2844
2845
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2843

def hashed_size
  @hashed_size
end

#operationsArray<Google::Apis::SecuritycenterV1::FileOperation>

Operation(s) performed on a file. Corresponds to the JSON property operations



2848
2849
2850
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2848

def operations
  @operations
end

#partially_hashedBoolean Also known as: partially_hashed?

True when the hash covers only a prefix of the file. Corresponds to the JSON property partiallyHashed

Returns:

  • (Boolean)


2853
2854
2855
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2853

def partially_hashed
  @partially_hashed
end

#pathString

Absolute path of the file as a JSON encoded string. Corresponds to the JSON property path

Returns:

  • (String)


2859
2860
2861
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2859

def path
  @path
end

#sha256String

SHA256 hash of the first hashed_size bytes of the file encoded as a hex string. If hashed_size == size, sha256 represents the SHA256 hash of the entire file. Corresponds to the JSON property sha256

Returns:

  • (String)


2865
2866
2867
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2865

def sha256
  @sha256
end

#sizeFixnum

Size of the file in bytes. Corresponds to the JSON property size

Returns:

  • (Fixnum)


2870
2871
2872
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2870

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 2877

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @disk_path = args[:disk_path] if args.key?(:disk_path)
  @file_load_state = args[:file_load_state] if args.key?(:file_load_state)
  @hashed_size = args[:hashed_size] if args.key?(:hashed_size)
  @operations = args[:operations] if args.key?(:operations)
  @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed)
  @path = args[:path] if args.key?(:path)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @size = args[:size] if args.key?(:size)
end