Class: Google::Apis::SecuritycenterV1::Finding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::Finding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Security Command Center finding. A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding.
Instance Attribute Summary collapse
-
#access ⇒ Google::Apis::SecuritycenterV1::Access
Represents an access event.
-
#affected_resources ⇒ Google::Apis::SecuritycenterV1::AffectedResources
Details about resources affected by this finding.
-
#agent_data_access_events ⇒ Array<Google::Apis::SecuritycenterV1::AgentDataAccessEvent>
Agent data access events associated with the finding.
-
#ai_model ⇒ Google::Apis::SecuritycenterV1::AiModel
Contains information about the AI model associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1::Application
Represents an application associated with a finding.
-
#artifact_guard_policies ⇒ Google::Apis::SecuritycenterV1::ArtifactGuardPolicies
Represents the result of evaluating artifact guard policies.
-
#attack_exposure ⇒ Google::Apis::SecuritycenterV1::AttackExposure
An attack exposure contains the results of an attack path simulation run.
-
#backup_disaster_recovery ⇒ Google::Apis::SecuritycenterV1::BackupDisasterRecovery
Information related to Google Cloud Backup and DR Service findings.
-
#canonical_name ⇒ String
The canonical name of the finding.
-
#category ⇒ String
The additional taxonomy group within findings from a given source.
-
#chokepoint ⇒ Google::Apis::SecuritycenterV1::Chokepoint
Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations.
-
#cloud_armor ⇒ Google::Apis::SecuritycenterV1::CloudArmor
Fields related to Google Cloud Armor findings.
-
#cloud_dlp_data_profile ⇒ Google::Apis::SecuritycenterV1::CloudDlpDataProfile
The data profile associated with the finding.
-
#cloud_dlp_inspection ⇒ Google::Apis::SecuritycenterV1::CloudDlpInspection
Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the finding.
-
#compliance_details ⇒ Google::Apis::SecuritycenterV1::ComplianceDetails
Compliance Details associated with the finding.
-
#compliances ⇒ Array<Google::Apis::SecuritycenterV1::Compliance>
Contains compliance information for security standards associated to the finding.
-
#connections ⇒ Array<Google::Apis::SecuritycenterV1::Connection>
Contains information about the IP connection associated with the finding.
-
#contacts ⇒ Hash<String,Google::Apis::SecuritycenterV1::ContactDetails>
Output only.
-
#containers ⇒ Array<Google::Apis::SecuritycenterV1::Container>
Containers associated with the finding.
-
#create_time ⇒ String
The time at which the finding was created in Security Command Center.
-
#data_access_events ⇒ Array<Google::Apis::SecuritycenterV1::DataAccessEvent>
Data access events associated with the finding.
-
#data_flow_events ⇒ Array<Google::Apis::SecuritycenterV1::DataFlowEvent>
Data flow events associated with the finding.
-
#data_retention_deletion_events ⇒ Array<Google::Apis::SecuritycenterV1::DataRetentionDeletionEvent>
Data retention deletion events associated with the finding.
-
#database ⇒ Google::Apis::SecuritycenterV1::Database
Represents database access information, such as queries.
-
#description ⇒ String
Contains more details about the finding.
-
#discovered_workload ⇒ Google::Apis::SecuritycenterV1::DiscoveredWorkload
Represents discovered, customer managed workload that is not registered with the respective GCP service.
-
#disk ⇒ Google::Apis::SecuritycenterV1::Disk
Contains information about the disk associated with the finding.
-
#event_time ⇒ String
The time the finding was first detected.
-
#exfiltration ⇒ Google::Apis::SecuritycenterV1::Exfiltration
Exfiltration represents a data exfiltration attempt from one or more sources to one or more targets.
-
#external_exposure ⇒ Google::Apis::SecuritycenterV1::ExternalExposure
Details about the externally exposed resource associated with the finding.
-
#external_systems ⇒ Hash<String,Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ExternalSystem>
Output only.
-
#external_uri ⇒ String
The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found.
-
#files ⇒ Array<Google::Apis::SecuritycenterV1::File>
File associated with the finding.
-
#finding_class ⇒ String
The class of the finding.
-
#group_memberships ⇒ Array<Google::Apis::SecuritycenterV1::GroupMembership>
Contains details about groups of which this finding is a member.
-
#iam_bindings ⇒ Array<Google::Apis::SecuritycenterV1::IamBinding>
Represents IAM bindings associated with the finding.
-
#indicator ⇒ Google::Apis::SecuritycenterV1::Indicator
Represents what's commonly known as an indicator of compromise (IoC) in computer forensics.
-
#ip_rules ⇒ Google::Apis::SecuritycenterV1::IpRules
IP rules associated with the finding.
-
#job ⇒ Google::Apis::SecuritycenterV1::Job
Describes a job Corresponds to the JSON property
job. -
#kernel_rootkit ⇒ Google::Apis::SecuritycenterV1::KernelRootkit
Kernel mode rootkit signatures.
-
#kubernetes ⇒ Google::Apis::SecuritycenterV1::Kubernetes
Kubernetes-related attributes.
-
#load_balancers ⇒ Array<Google::Apis::SecuritycenterV1::LoadBalancer>
The load balancers associated with the finding.
-
#log_entries ⇒ Array<Google::Apis::SecuritycenterV1::LogEntry>
Log entries that are relevant to the finding.
-
#mitre_attack ⇒ Google::Apis::SecuritycenterV1::MitreAttack
MITRE ATT&CK tactics and techniques related to this finding.
-
#module_name ⇒ String
Unique identifier of the module which generated the finding.
-
#mute ⇒ String
Indicates the mute state of a finding (either muted, unmuted or undefined).
-
#mute_info ⇒ Google::Apis::SecuritycenterV1::MuteInfo
Mute information about the finding, including whether the finding has a static mute or any matching dynamic mute rules.
-
#mute_initiator ⇒ String
Records additional information about the mute operation, for example, the mute configuration that muted the finding and the user who muted the finding.
-
#mute_update_time ⇒ String
Output only.
-
#name ⇒ String
The relative resource name of the finding.
-
#networks ⇒ Array<Google::Apis::SecuritycenterV1::Network>
Represents the VPC networks that the resource is attached to.
-
#next_steps ⇒ String
Steps to address the finding.
-
#notebook ⇒ Google::Apis::SecuritycenterV1::Notebook
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
-
#org_policies ⇒ Array<Google::Apis::SecuritycenterV1::OrgPolicy>
Contains information about the org policies associated with the finding.
-
#parent ⇒ String
The relative resource name of the source the finding belongs to.
-
#parent_display_name ⇒ String
Output only.
-
#policy_violation_summary ⇒ Google::Apis::SecuritycenterV1::PolicyViolationSummary
Metadata summarizing policy violations of child resources of the affected resource.
-
#processes ⇒ Array<Google::Apis::SecuritycenterV1::Process>
Represents operating system processes associated with the Finding.
-
#resource_name ⇒ String
For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for.
-
#secret ⇒ Google::Apis::SecuritycenterV1::Secret
Details about a secret or credential associated with the finding.
-
#security_marks ⇒ Google::Apis::SecuritycenterV1::SecurityMarks
User specified security marks that are attached to the parent Security Command Center resource.
-
#security_posture ⇒ Google::Apis::SecuritycenterV1::SecurityPosture
Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service.
-
#severity ⇒ String
The severity of the finding.
-
#source_properties ⇒ Hash<String,Object>
Source specific properties.
-
#state ⇒ String
The state of the finding.
-
#toxic_combination ⇒ Google::Apis::SecuritycenterV1::ToxicCombination
Contains details about a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently.
-
#vertex_ai ⇒ Google::Apis::SecuritycenterV1::VertexAi
Vertex AI-related information associated with the finding.
-
#vulnerability ⇒ Google::Apis::SecuritycenterV1::Vulnerability
Refers to common vulnerability fields e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Finding
constructor
A new instance of Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Finding
Returns a new instance of Finding.
3595 3596 3597 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access ⇒ Google::Apis::SecuritycenterV1::Access
Represents an access event.
Corresponds to the JSON property access
3178 3179 3180 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3178 def access @access end |
#affected_resources ⇒ Google::Apis::SecuritycenterV1::AffectedResources
Details about resources affected by this finding.
Corresponds to the JSON property affectedResources
3183 3184 3185 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3183 def affected_resources @affected_resources end |
#agent_data_access_events ⇒ Array<Google::Apis::SecuritycenterV1::AgentDataAccessEvent>
Agent data access events associated with the finding.
Corresponds to the JSON property agentDataAccessEvents
3188 3189 3190 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3188 def agent_data_access_events @agent_data_access_events end |
#ai_model ⇒ Google::Apis::SecuritycenterV1::AiModel
Contains information about the AI model associated with the finding.
Corresponds to the JSON property aiModel
3193 3194 3195 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3193 def ai_model @ai_model end |
#application ⇒ Google::Apis::SecuritycenterV1::Application
Represents an application associated with a finding.
Corresponds to the JSON property application
3198 3199 3200 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3198 def application @application end |
#artifact_guard_policies ⇒ Google::Apis::SecuritycenterV1::ArtifactGuardPolicies
Represents the result of evaluating artifact guard policies.
Corresponds to the JSON property artifactGuardPolicies
3203 3204 3205 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3203 def artifact_guard_policies @artifact_guard_policies end |
#attack_exposure ⇒ Google::Apis::SecuritycenterV1::AttackExposure
An attack exposure contains the results of an attack path simulation run.
Corresponds to the JSON property attackExposure
3208 3209 3210 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3208 def attack_exposure @attack_exposure end |
#backup_disaster_recovery ⇒ Google::Apis::SecuritycenterV1::BackupDisasterRecovery
Information related to Google Cloud Backup and DR Service findings.
Corresponds to the JSON property backupDisasterRecovery
3213 3214 3215 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3213 def backup_disaster_recovery @backup_disaster_recovery end |
#canonical_name ⇒ String
The canonical name of the finding. It's either "organizations/organization_id
/sources/source_id/findings/finding_id", "folders/folder_id/sources/
source_id/findings/finding_id" or "projects/project_number/sources/
source_id/findings/finding_id", depending on the closest CRM ancestor of
the resource associated with the finding.
Corresponds to the JSON property canonicalName
3222 3223 3224 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3222 def canonical_name @canonical_name end |
#category ⇒ String
The additional taxonomy group within findings from a given source. This field
is immutable after creation time. Example: "XSS_FLASH_INJECTION"
Corresponds to the JSON property category
3228 3229 3230 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3228 def category @category end |
#chokepoint ⇒ Google::Apis::SecuritycenterV1::Chokepoint
Contains details about a chokepoint, which is a resource or resource group
where high-risk attack paths converge, based on attack path simulations.
Corresponds to the JSON property chokepoint
3236 3237 3238 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3236 def chokepoint @chokepoint end |
#cloud_armor ⇒ Google::Apis::SecuritycenterV1::CloudArmor
Fields related to Google Cloud Armor findings.
Corresponds to the JSON property cloudArmor
3241 3242 3243 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3241 def cloud_armor @cloud_armor end |
#cloud_dlp_data_profile ⇒ Google::Apis::SecuritycenterV1::CloudDlpDataProfile
The data profile associated
with the finding.
Corresponds to the JSON property cloudDlpDataProfile
3247 3248 3249 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3247 def cloud_dlp_data_profile @cloud_dlp_data_profile end |
#cloud_dlp_inspection ⇒ Google::Apis::SecuritycenterV1::CloudDlpInspection
Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the
finding.
Corresponds to the JSON property cloudDlpInspection
3254 3255 3256 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3254 def cloud_dlp_inspection @cloud_dlp_inspection end |
#compliance_details ⇒ Google::Apis::SecuritycenterV1::ComplianceDetails
Compliance Details associated with the finding.
Corresponds to the JSON property complianceDetails
3259 3260 3261 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3259 def compliance_details @compliance_details end |
#compliances ⇒ Array<Google::Apis::SecuritycenterV1::Compliance>
Contains compliance information for security standards associated to the
finding.
Corresponds to the JSON property compliances
3265 3266 3267 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3265 def compliances @compliances end |
#connections ⇒ Array<Google::Apis::SecuritycenterV1::Connection>
Contains information about the IP connection associated with the finding.
Corresponds to the JSON property connections
3270 3271 3272 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3270 def connections @connections end |
#contacts ⇒ Hash<String,Google::Apis::SecuritycenterV1::ContactDetails>
Output only. Map containing the points of contact for the given finding. The
key represents the type of contact, while the value contains a list of all the
contacts that pertain. Please refer to: https://cloud.google.com/resource-
manager/docs/managing-notification-contacts#notification-categories "
security": "contacts": [ "email": "person1@company.com", "email": "
person2@company.com" ]
Corresponds to the JSON property contacts
3280 3281 3282 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3280 def contacts @contacts end |
#containers ⇒ Array<Google::Apis::SecuritycenterV1::Container>
Containers associated with the finding. This field provides information for
both Kubernetes and non-Kubernetes containers.
Corresponds to the JSON property containers
3286 3287 3288 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3286 def containers @containers end |
#create_time ⇒ String
The time at which the finding was created in Security Command Center.
Corresponds to the JSON property createTime
3291 3292 3293 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3291 def create_time @create_time end |
#data_access_events ⇒ Array<Google::Apis::SecuritycenterV1::DataAccessEvent>
Data access events associated with the finding.
Corresponds to the JSON property dataAccessEvents
3296 3297 3298 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3296 def data_access_events @data_access_events end |
#data_flow_events ⇒ Array<Google::Apis::SecuritycenterV1::DataFlowEvent>
Data flow events associated with the finding.
Corresponds to the JSON property dataFlowEvents
3301 3302 3303 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3301 def data_flow_events @data_flow_events end |
#data_retention_deletion_events ⇒ Array<Google::Apis::SecuritycenterV1::DataRetentionDeletionEvent>
Data retention deletion events associated with the finding.
Corresponds to the JSON property dataRetentionDeletionEvents
3306 3307 3308 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3306 def data_retention_deletion_events @data_retention_deletion_events end |
#database ⇒ Google::Apis::SecuritycenterV1::Database
Represents database access information, such as queries. A database may be a
sub-resource of an instance (as in the case of Cloud SQL instances or Cloud
Spanner instances), or the database instance itself. Some database resources
might not have the full resource name populated because these resource types, such as Cloud SQL
databases, are not yet supported by Cloud Asset Inventory. In these cases only
the display name is provided.
Corresponds to the JSON property database
3317 3318 3319 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3317 def database @database end |
#description ⇒ String
Contains more details about the finding.
Corresponds to the JSON property description
3322 3323 3324 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3322 def description @description end |
#discovered_workload ⇒ Google::Apis::SecuritycenterV1::DiscoveredWorkload
Represents discovered, customer managed workload that is not registered with
the respective GCP service.
Corresponds to the JSON property discoveredWorkload
3328 3329 3330 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3328 def discovered_workload @discovered_workload end |
#disk ⇒ Google::Apis::SecuritycenterV1::Disk
Contains information about the disk associated with the finding.
Corresponds to the JSON property disk
3333 3334 3335 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3333 def disk @disk end |
#event_time ⇒ String
The time the finding was first detected. If an existing finding is updated,
then this is the time the update occurred. For example, if the finding
represents an open firewall, this property captures the time the detector
believes the firewall became open. The accuracy is determined by the detector.
If the finding is later resolved, then this time reflects when the finding was
resolved. This must not be set to a value greater than the current timestamp.
Corresponds to the JSON property eventTime
3343 3344 3345 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3343 def event_time @event_time end |
#exfiltration ⇒ Google::Apis::SecuritycenterV1::Exfiltration
Exfiltration represents a data exfiltration attempt from one or more sources
to one or more targets. The sources attribute lists the sources of the
exfiltrated data. The targets attribute lists the destinations the data was
copied to.
Corresponds to the JSON property exfiltration
3351 3352 3353 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3351 def exfiltration @exfiltration end |
#external_exposure ⇒ Google::Apis::SecuritycenterV1::ExternalExposure
Details about the externally exposed resource associated with the finding.
Corresponds to the JSON property externalExposure
3356 3357 3358 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3356 def external_exposure @external_exposure end |
#external_systems ⇒ Hash<String,Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ExternalSystem>
Output only. Third party SIEM/SOAR fields within SCC, contains external system
information and external system finding fields.
Corresponds to the JSON property externalSystems
3362 3363 3364 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3362 def external_systems @external_systems end |
#external_uri ⇒ String
The URI that, if available, points to a web page outside of Security Command
Center where additional information about the finding can be found. This field
is guaranteed to be either empty or a well formed URL.
Corresponds to the JSON property externalUri
3369 3370 3371 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3369 def external_uri @external_uri end |
#files ⇒ Array<Google::Apis::SecuritycenterV1::File>
File associated with the finding.
Corresponds to the JSON property files
3374 3375 3376 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3374 def files @files end |
#finding_class ⇒ String
The class of the finding.
Corresponds to the JSON property findingClass
3379 3380 3381 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3379 def finding_class @finding_class end |
#group_memberships ⇒ Array<Google::Apis::SecuritycenterV1::GroupMembership>
Contains details about groups of which this finding is a member. A group is a
collection of findings that are related in some way. This field cannot be
updated. Its value is ignored in all update requests.
Corresponds to the JSON property groupMemberships
3386 3387 3388 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3386 def group_memberships @group_memberships end |
#iam_bindings ⇒ Array<Google::Apis::SecuritycenterV1::IamBinding>
Represents IAM bindings associated with the finding.
Corresponds to the JSON property iamBindings
3391 3392 3393 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3391 def iam_bindings @iam_bindings end |
#indicator ⇒ Google::Apis::SecuritycenterV1::Indicator
Represents what's commonly known as an indicator of compromise (IoC) in
computer forensics. This is an artifact observed on a network or in an
operating system that, with high confidence, indicates a computer intrusion.
For more information, see Indicator of compromise.
Corresponds to the JSON property indicator
3400 3401 3402 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3400 def indicator @indicator end |
#ip_rules ⇒ Google::Apis::SecuritycenterV1::IpRules
IP rules associated with the finding.
Corresponds to the JSON property ipRules
3405 3406 3407 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3405 def ip_rules @ip_rules end |
#job ⇒ Google::Apis::SecuritycenterV1::Job
Describes a job
Corresponds to the JSON property job
3410 3411 3412 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3410 def job @job end |
#kernel_rootkit ⇒ Google::Apis::SecuritycenterV1::KernelRootkit
Kernel mode rootkit signatures.
Corresponds to the JSON property kernelRootkit
3415 3416 3417 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3415 def kernel_rootkit @kernel_rootkit end |
#kubernetes ⇒ Google::Apis::SecuritycenterV1::Kubernetes
Kubernetes-related attributes.
Corresponds to the JSON property kubernetes
3420 3421 3422 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3420 def kubernetes @kubernetes end |
#load_balancers ⇒ Array<Google::Apis::SecuritycenterV1::LoadBalancer>
The load balancers associated with the finding.
Corresponds to the JSON property loadBalancers
3425 3426 3427 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3425 def load_balancers @load_balancers end |
#log_entries ⇒ Array<Google::Apis::SecuritycenterV1::LogEntry>
Log entries that are relevant to the finding.
Corresponds to the JSON property logEntries
3430 3431 3432 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3430 def log_entries @log_entries end |
#mitre_attack ⇒ Google::Apis::SecuritycenterV1::MitreAttack
MITRE ATT&CK tactics and techniques related to this finding. See: https://
attack.mitre.org
Corresponds to the JSON property mitreAttack
3436 3437 3438 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3436 def mitre_attack @mitre_attack end |
#module_name ⇒ String
Unique identifier of the module which generated the finding. Example: folders/
598186756061/securityHealthAnalyticsSettings/customModules/56799441161885
Corresponds to the JSON property moduleName
3442 3443 3444 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3442 def module_name @module_name end |
#mute ⇒ String
Indicates the mute state of a finding (either muted, unmuted or undefined).
Unlike other attributes of a finding, a finding provider shouldn't set the
value of mute.
Corresponds to the JSON property mute
3449 3450 3451 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3449 def mute @mute end |
#mute_info ⇒ Google::Apis::SecuritycenterV1::MuteInfo
Mute information about the finding, including whether the finding has a static
mute or any matching dynamic mute rules.
Corresponds to the JSON property muteInfo
3455 3456 3457 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3455 def mute_info @mute_info end |
#mute_initiator ⇒ String
Records additional information about the mute operation, for example, the
mute configuration that
muted the finding and the user who muted the finding.
Corresponds to the JSON property muteInitiator
3462 3463 3464 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3462 def mute_initiator @mute_initiator end |
#mute_update_time ⇒ String
Output only. The most recent time this finding was muted or unmuted.
Corresponds to the JSON property muteUpdateTime
3467 3468 3469 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3467 def mute_update_time @mute_update_time end |
#name ⇒ String
The relative resource name of the finding. Example: "organizations/
organization_id/sources/source_id/findings/finding_id", "folders/
folder_id/sources/source_id/findings/finding_id", "projects/project_id/
sources/source_id/findings/finding_id".
Corresponds to the JSON property name
3476 3477 3478 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3476 def name @name end |
#networks ⇒ Array<Google::Apis::SecuritycenterV1::Network>
Represents the VPC networks that the resource is attached to.
Corresponds to the JSON property networks
3481 3482 3483 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3481 def networks @networks end |
#next_steps ⇒ String
Steps to address the finding.
Corresponds to the JSON property nextSteps
3486 3487 3488 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3486 def next_steps @next_steps end |
#notebook ⇒ Google::Apis::SecuritycenterV1::Notebook
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated
with a finding.
Corresponds to the JSON property notebook
3493 3494 3495 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3493 def notebook @notebook end |
#org_policies ⇒ Array<Google::Apis::SecuritycenterV1::OrgPolicy>
Contains information about the org policies associated with the finding.
Corresponds to the JSON property orgPolicies
3498 3499 3500 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3498 def org_policies @org_policies end |
#parent ⇒ String
The relative resource name of the source the finding belongs to. See: https://
cloud.google.com/apis/design/resource_names#relative_resource_name This field
is immutable after creation time. For example: "organizations/organization_id
/sources/source_id"
Corresponds to the JSON property parent
3506 3507 3508 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3506 def parent @parent end |
#parent_display_name ⇒ String
Output only. The human readable display name of the finding source such as "
Event Threat Detection" or "Security Health Analytics".
Corresponds to the JSON property parentDisplayName
3512 3513 3514 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3512 def parent_display_name @parent_display_name end |
#policy_violation_summary ⇒ Google::Apis::SecuritycenterV1::PolicyViolationSummary
Metadata summarizing policy violations of child resources of the affected
resource. finding_category and resource determine the exact semantics of
the counts. For example, when category=
DATA_SECURITY_POSTURE_OBJECT_PUBLIC_ACCESS_VIOLATION and resource='storage.
googleapis.com/buckets/my-bucket-name' then this counts the number of Cloud
Storage objects in my-bucket-name which violate a Public Access control.
Corresponds to the JSON property policyViolationSummary
3522 3523 3524 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3522 def policy_violation_summary @policy_violation_summary end |
#processes ⇒ Array<Google::Apis::SecuritycenterV1::Process>
Represents operating system processes associated with the Finding.
Corresponds to the JSON property processes
3527 3528 3529 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3527 def processes @processes end |
#resource_name ⇒ String
For findings on Google Cloud resources, the full resource name of the Google
Cloud resource this finding is for. See: https://cloud.google.com/apis/design/
resource_names#full_resource_name When the finding is for a non-Google Cloud
resource, the resourceName can be a customer or partner defined string. This
field is immutable after creation time.
Corresponds to the JSON property resourceName
3536 3537 3538 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3536 def resource_name @resource_name end |
#secret ⇒ Google::Apis::SecuritycenterV1::Secret
Details about a secret or credential associated with the finding.
Corresponds to the JSON property secret
3541 3542 3543 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3541 def secret @secret end |
#security_marks ⇒ Google::Apis::SecuritycenterV1::SecurityMarks
User specified security marks that are attached to the parent Security Command
Center resource. Security marks are scoped within a Security Command Center
organization -- they can be modified and viewed by all users who have proper
permissions on the organization.
Corresponds to the JSON property securityMarks
3549 3550 3551 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3549 def security_marks @security_marks end |
#security_posture ⇒ Google::Apis::SecuritycenterV1::SecurityPosture
Represents a posture that is deployed on Google Cloud by the Security Command
Center Posture Management service. A posture contains one or more policy sets.
A policy set is a group of policies that enforce a set of security rules on
Google Cloud.
Corresponds to the JSON property securityPosture
3557 3558 3559 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3557 def security_posture @security_posture end |
#severity ⇒ String
The severity of the finding. This field is managed by the source that writes
the finding.
Corresponds to the JSON property severity
3563 3564 3565 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3563 def severity @severity end |
#source_properties ⇒ Hash<String,Object>
Source specific properties. These properties are managed by the source that
writes the finding. The key names in the source_properties map must be between
1 and 255 characters, and must start with a letter and contain alphanumeric
characters or underscores only.
Corresponds to the JSON property sourceProperties
3571 3572 3573 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3571 def source_properties @source_properties end |
#state ⇒ String
The state of the finding.
Corresponds to the JSON property state
3576 3577 3578 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3576 def state @state end |
#toxic_combination ⇒ Google::Apis::SecuritycenterV1::ToxicCombination
Contains details about a group of security issues that, when the issues occur
together, represent a greater risk than when the issues occur independently. A
group of such issues is referred to as a toxic combination.
Corresponds to the JSON property toxicCombination
3583 3584 3585 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3583 def toxic_combination @toxic_combination end |
#vertex_ai ⇒ Google::Apis::SecuritycenterV1::VertexAi
Vertex AI-related information associated with the finding.
Corresponds to the JSON property vertexAi
3588 3589 3590 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3588 def vertex_ai @vertex_ai end |
#vulnerability ⇒ Google::Apis::SecuritycenterV1::Vulnerability
Refers to common vulnerability fields e.g. cve, cvss, cwe etc.
Corresponds to the JSON property vulnerability
3593 3594 3595 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3593 def vulnerability @vulnerability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 3666 3667 3668 3669 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3600 def update!(**args) @access = args[:access] if args.key?(:access) @affected_resources = args[:affected_resources] if args.key?(:affected_resources) @agent_data_access_events = args[:agent_data_access_events] if args.key?(:agent_data_access_events) @ai_model = args[:ai_model] if args.key?(:ai_model) @application = args[:application] if args.key?(:application) @artifact_guard_policies = args[:artifact_guard_policies] if args.key?(:artifact_guard_policies) @attack_exposure = args[:attack_exposure] if args.key?(:attack_exposure) @backup_disaster_recovery = args[:backup_disaster_recovery] if args.key?(:backup_disaster_recovery) @canonical_name = args[:canonical_name] if args.key?(:canonical_name) @category = args[:category] if args.key?(:category) @chokepoint = args[:chokepoint] if args.key?(:chokepoint) @cloud_armor = args[:cloud_armor] if args.key?(:cloud_armor) @cloud_dlp_data_profile = args[:cloud_dlp_data_profile] if args.key?(:cloud_dlp_data_profile) @cloud_dlp_inspection = args[:cloud_dlp_inspection] if args.key?(:cloud_dlp_inspection) @compliance_details = args[:compliance_details] if args.key?(:compliance_details) @compliances = args[:compliances] if args.key?(:compliances) @connections = args[:connections] if args.key?(:connections) @contacts = args[:contacts] if args.key?(:contacts) @containers = args[:containers] if args.key?(:containers) @create_time = args[:create_time] if args.key?(:create_time) @data_access_events = args[:data_access_events] if args.key?(:data_access_events) @data_flow_events = args[:data_flow_events] if args.key?(:data_flow_events) @data_retention_deletion_events = args[:data_retention_deletion_events] if args.key?(:data_retention_deletion_events) @database = args[:database] if args.key?(:database) @description = args[:description] if args.key?(:description) @discovered_workload = args[:discovered_workload] if args.key?(:discovered_workload) @disk = args[:disk] if args.key?(:disk) @event_time = args[:event_time] if args.key?(:event_time) @exfiltration = args[:exfiltration] if args.key?(:exfiltration) @external_exposure = args[:external_exposure] if args.key?(:external_exposure) @external_systems = args[:external_systems] if args.key?(:external_systems) @external_uri = args[:external_uri] if args.key?(:external_uri) @files = args[:files] if args.key?(:files) @finding_class = args[:finding_class] if args.key?(:finding_class) @group_memberships = args[:group_memberships] if args.key?(:group_memberships) @iam_bindings = args[:iam_bindings] if args.key?(:iam_bindings) @indicator = args[:indicator] if args.key?(:indicator) @ip_rules = args[:ip_rules] if args.key?(:ip_rules) @job = args[:job] if args.key?(:job) @kernel_rootkit = args[:kernel_rootkit] if args.key?(:kernel_rootkit) @kubernetes = args[:kubernetes] if args.key?(:kubernetes) @load_balancers = args[:load_balancers] if args.key?(:load_balancers) @log_entries = args[:log_entries] if args.key?(:log_entries) @mitre_attack = args[:mitre_attack] if args.key?(:mitre_attack) @module_name = args[:module_name] if args.key?(:module_name) @mute = args[:mute] if args.key?(:mute) @mute_info = args[:mute_info] if args.key?(:mute_info) @mute_initiator = args[:mute_initiator] if args.key?(:mute_initiator) @mute_update_time = args[:mute_update_time] if args.key?(:mute_update_time) @name = args[:name] if args.key?(:name) @networks = args[:networks] if args.key?(:networks) @next_steps = args[:next_steps] if args.key?(:next_steps) @notebook = args[:notebook] if args.key?(:notebook) @org_policies = args[:org_policies] if args.key?(:org_policies) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @policy_violation_summary = args[:policy_violation_summary] if args.key?(:policy_violation_summary) @processes = args[:processes] if args.key?(:processes) @resource_name = args[:resource_name] if args.key?(:resource_name) @secret = args[:secret] if args.key?(:secret) @security_marks = args[:security_marks] if args.key?(:security_marks) @security_posture = args[:security_posture] if args.key?(:security_posture) @severity = args[:severity] if args.key?(:severity) @source_properties = args[:source_properties] if args.key?(:source_properties) @state = args[:state] if args.key?(:state) @toxic_combination = args[:toxic_combination] if args.key?(:toxic_combination) @vertex_ai = args[:vertex_ai] if args.key?(:vertex_ai) @vulnerability = args[:vulnerability] if args.key?(:vulnerability) end |