Class: Google::Apis::SecuritycenterV1::Framework
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::Framework
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Compliance framework associated with the finding.
Instance Attribute Summary collapse
-
#category ⇒ Array<String>
Category of the framework associated with the finding.
-
#controls ⇒ Array<Google::Apis::SecuritycenterV1::Control>
The controls associated with the framework.
-
#display_name ⇒ String
Display name of the framework.
-
#name ⇒ String
Name of the framework associated with the finding Corresponds to the JSON property
name. -
#type ⇒ String
Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Framework
constructor
A new instance of Framework.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Framework
Returns a new instance of Framework.
3732 3733 3734 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Array<String>
Category of the framework associated with the finding. E.g. Security Benchmark,
or Assured Workloads
Corresponds to the JSON property category
3706 3707 3708 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3706 def category @category end |
#controls ⇒ Array<Google::Apis::SecuritycenterV1::Control>
The controls associated with the framework.
Corresponds to the JSON property controls
3711 3712 3713 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3711 def controls @controls end |
#display_name ⇒ String
Display name of the framework. For a standard framework, this will look like e.
g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined
string like MyFramework
Corresponds to the JSON property displayName
3718 3719 3720 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3718 def display_name @display_name end |
#name ⇒ String
Name of the framework associated with the finding
Corresponds to the JSON property name
3723 3724 3725 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3723 def name @name end |
#type ⇒ String
Type of the framework associated with the finding, to specify whether the
framework is built-in (pre-defined and immutable) or a custom framework
defined by the customer (equivalent to security posture)
Corresponds to the JSON property type
3730 3731 3732 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3730 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3737 3738 3739 3740 3741 3742 3743 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3737 def update!(**args) @category = args[:category] if args.key?(:category) @controls = args[:controls] if args.key?(:controls) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |