Class: Google::Apis::SecuritycenterV1::Framework

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Compliance framework associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Framework

Returns a new instance of Framework.



3444
3445
3446
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryArray<String>

Category of the framework associated with the finding. E.g. Security Benchmark, or Assured Workloads Corresponds to the JSON property category

Returns:

  • (Array<String>)


3418
3419
3420
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3418

def category
  @category
end

#controlsArray<Google::Apis::SecuritycenterV1::Control>

The controls associated with the framework. Corresponds to the JSON property controls



3423
3424
3425
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3423

def controls
  @controls
end

#display_nameString

Display name of the framework. For a standard framework, this will look like e. g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined string like MyFramework Corresponds to the JSON property displayName

Returns:

  • (String)


3430
3431
3432
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3430

def display_name
  @display_name
end

#nameString

Name of the framework associated with the finding Corresponds to the JSON property name

Returns:

  • (String)


3435
3436
3437
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3435

def name
  @name
end

#typeString

Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property type

Returns:

  • (String)


3442
3443
3444
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3442

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3449
3450
3451
3452
3453
3454
3455
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3449

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @controls = args[:controls] if args.key?(:controls)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end