Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1BigQueryExport
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1BigQueryExport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Configures how to deliver Findings to BigQuery Instance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dataset ⇒ String
The dataset to write findings' updates to.
-
#description ⇒ String
The description of the export (max of 1024 characters).
-
#filter ⇒ String
Expression that defines the filter to apply across create/update events of findings.
-
#most_recent_editor ⇒ String
Output only.
-
#name ⇒ String
The relative resource name of this export.
-
#principal ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1BigQueryExport
constructor
A new instance of GoogleCloudSecuritycenterV1BigQueryExport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1BigQueryExport
Returns a new instance of GoogleCloudSecuritycenterV1BigQueryExport.
3930 3931 3932 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the BigQuery export was created. This field is
set by the server and will be ignored if provided on export on creation.
Corresponds to the JSON property createTime
3872 3873 3874 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3872 def create_time @create_time end |
#dataset ⇒ String
The dataset to write findings' updates to. Its format is "projects/[project_id]
/datasets/[bigquery_dataset_id]". BigQuery Dataset unique ID must contain only
letters (a-z, A-Z), numbers (0-9), or underscores (_).
Corresponds to the JSON property dataset
3879 3880 3881 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3879 def dataset @dataset end |
#description ⇒ String
The description of the export (max of 1024 characters).
Corresponds to the JSON property description
3884 3885 3886 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3884 def description @description end |
#filter ⇒ String
Expression that defines the filter to apply across create/update events of
findings. The expression is a list of zero or more restrictions combined via
logical operators AND and OR. Parentheses are supported, and OR has
higher precedence than AND. Restrictions have the form and may have a -
character in front of them to indicate negation. The fields map to those
defined in the corresponding resource. The supported operators are: * = for
all value types. * >, <, >=, <= for integer values. * :, meaning
substring matching, for strings. The supported value types are: * string
literals in quotes. * integer literals without quotes. * boolean literals
true and false without quotes.
Corresponds to the JSON property filter
3898 3899 3900 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3898 def filter @filter end |
#most_recent_editor ⇒ String
Output only. Email address of the user who last edited the BigQuery export.
This field is set by the server and will be ignored if provided on export
creation or update.
Corresponds to the JSON property mostRecentEditor
3905 3906 3907 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3905 def most_recent_editor @most_recent_editor end |
#name ⇒ String
The relative resource name of this export. See: https://cloud.google.com/apis/
design/resource_names#relative_resource_name. Example format: "organizations/
organization_id/bigQueryExports/export_id" Example format: "folders/
folder_id/bigQueryExports/export_id" Example format: "projects/project_id/
bigQueryExports/export_id" This field is provided in responses, and is
ignored when provided in create requests.
Corresponds to the JSON property name
3915 3916 3917 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3915 def name @name end |
#principal ⇒ String
Output only. The service account that needs permission to create table and
upload data to the BigQuery dataset.
Corresponds to the JSON property principal
3921 3922 3923 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3921 def principal @principal end |
#update_time ⇒ String
Output only. The most recent time at which the BigQuery export was updated.
This field is set by the server and will be ignored if provided on export
creation or update.
Corresponds to the JSON property updateTime
3928 3929 3930 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3928 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3935 3936 3937 3938 3939 3940 3941 3942 3943 3944 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3935 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dataset = args[:dataset] if args.key?(:dataset) @description = args[:description] if args.key?(:description) @filter = args[:filter] if args.key?(:filter) @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor) @name = args[:name] if args.key?(:name) @principal = args[:principal] if args.key?(:principal) @update_time = args[:update_time] if args.key?(:update_time) end |