Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1BigQueryExport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Configures how to deliver Findings to BigQuery Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1BigQueryExport

Returns a new instance of GoogleCloudSecuritycenterV1BigQueryExport.



3642
3643
3644
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the BigQuery export was created. This field is set by the server and will be ignored if provided on export on creation. Corresponds to the JSON property createTime

Returns:

  • (String)


3584
3585
3586
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3584

def create_time
  @create_time
end

#datasetString

The dataset to write findings' updates to. Its format is "projects/[project_id] /datasets/[bigquery_dataset_id]". BigQuery Dataset unique ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_). Corresponds to the JSON property dataset

Returns:

  • (String)


3591
3592
3593
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3591

def dataset
  @dataset
end

#descriptionString

The description of the export (max of 1024 characters). Corresponds to the JSON property description

Returns:

  • (String)


3596
3597
3598
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3596

def description
  @description
end

#filterString

Expression that defines the filter to apply across create/update events of findings. The expression is a list of zero or more restrictions combined via logical operators AND and OR. Parentheses are supported, and OR has higher precedence than AND. Restrictions have the form and may have a - character in front of them to indicate negation. The fields map to those defined in the corresponding resource. The supported operators are: * = for all value types. * >, <, >=, <= for integer values. * :, meaning substring matching, for strings. The supported value types are: * string literals in quotes. * integer literals without quotes. * boolean literals true and false without quotes. Corresponds to the JSON property filter

Returns:

  • (String)


3610
3611
3612
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3610

def filter
  @filter
end

#most_recent_editorString

Output only. Email address of the user who last edited the BigQuery export. This field is set by the server and will be ignored if provided on export creation or update. Corresponds to the JSON property mostRecentEditor

Returns:

  • (String)


3617
3618
3619
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3617

def most_recent_editor
  @most_recent_editor
end

#nameString

The relative resource name of this export. See: https://cloud.google.com/apis/ design/resource_names#relative_resource_name. Example format: "organizations/ organization_id/bigQueryExports/export_id" Example format: "folders/ folder_id/bigQueryExports/export_id" Example format: "projects/project_id/ bigQueryExports/export_id" This field is provided in responses, and is ignored when provided in create requests. Corresponds to the JSON property name

Returns:

  • (String)


3627
3628
3629
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3627

def name
  @name
end

#principalString

Output only. The service account that needs permission to create table and upload data to the BigQuery dataset. Corresponds to the JSON property principal

Returns:

  • (String)


3633
3634
3635
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3633

def principal
  @principal
end

#update_timeString

Output only. The most recent time at which the BigQuery export was updated. This field is set by the server and will be ignored if provided on export creation or update. Corresponds to the JSON property updateTime

Returns:

  • (String)


3640
3641
3642
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3640

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3647

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataset = args[:dataset] if args.key?(:dataset)
  @description = args[:description] if args.key?(:description)
  @filter = args[:filter] if args.key?(:filter)
  @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor)
  @name = args[:name] if args.key?(:name)
  @principal = args[:principal] if args.key?(:principal)
  @update_time = args[:update_time] if args.key?(:update_time)
end