Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1CustomOutputSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A set of optional name-value pairs that define custom source properties to return with each finding that is generated by the custom module. The custom source properties that are defined here are included in the finding JSON under sourceProperties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1CustomOutputSpec

Returns a new instance of GoogleCloudSecuritycenterV1CustomOutputSpec.



3795
3796
3797
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#propertiesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Property>

A list of custom output properties to add to the finding. Corresponds to the JSON property properties



3793
3794
3795
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3793

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3800
3801
3802
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3800

def update!(**args)
  @properties = args[:properties] if args.key?(:properties)
end