Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ExternalSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Representation of third party SIEM/SOAR fields within SCC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem

Returns a new instance of GoogleCloudSecuritycenterV1ExternalSystem.



3931
3932
3933
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneesArray<String>

References primary/secondary etc assignees in the external system. Corresponds to the JSON property assignees

Returns:

  • (Array<String>)


3873
3874
3875
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3873

def assignees
  @assignees
end

#case_close_timeString

The time when the case was closed, as reported by the external system. Corresponds to the JSON property caseCloseTime

Returns:

  • (String)


3878
3879
3880
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3878

def case_close_time
  @case_close_time
end

#case_create_timeString

The time when the case was created, as reported by the external system. Corresponds to the JSON property caseCreateTime

Returns:

  • (String)


3883
3884
3885
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3883

def case_create_time
  @case_create_time
end

#case_priorityString

The priority of the finding's corresponding case in the external system. Corresponds to the JSON property casePriority

Returns:

  • (String)


3888
3889
3890
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3888

def case_priority
  @case_priority
end

#case_slaString

The SLA of the finding's corresponding case in the external system. Corresponds to the JSON property caseSla

Returns:

  • (String)


3893
3894
3895
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3893

def case_sla
  @case_sla
end

#case_uriString

The link to the finding's corresponding case in the external system. Corresponds to the JSON property caseUri

Returns:

  • (String)


3898
3899
3900
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3898

def case_uri
  @case_uri
end

#external_system_update_timeString

The time when the case was last updated, as reported by the external system. Corresponds to the JSON property externalSystemUpdateTime

Returns:

  • (String)


3903
3904
3905
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3903

def external_system_update_time
  @external_system_update_time
end

#external_uidString

The identifier that's used to track the finding's corresponding case in the external system. Corresponds to the JSON property externalUid

Returns:

  • (String)


3909
3910
3911
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3909

def external_uid
  @external_uid
end

#nameString

Full resource name of the external system, for example: "organizations/1234/ sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/ findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/ 123456/externalSystems/jira" Corresponds to the JSON property name

Returns:

  • (String)


3917
3918
3919
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3917

def name
  @name
end

#statusString

The most recent status of the finding's corresponding case, as reported by the external system. Corresponds to the JSON property status

Returns:

  • (String)


3923
3924
3925
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3923

def status
  @status
end

#ticket_infoGoogle::Apis::SecuritycenterV1::TicketInfo

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding. Corresponds to the JSON property ticketInfo



3929
3930
3931
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3929

def ticket_info
  @ticket_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3936

def update!(**args)
  @assignees = args[:assignees] if args.key?(:assignees)
  @case_close_time = args[:case_close_time] if args.key?(:case_close_time)
  @case_create_time = args[:case_create_time] if args.key?(:case_create_time)
  @case_priority = args[:case_priority] if args.key?(:case_priority)
  @case_sla = args[:case_sla] if args.key?(:case_sla)
  @case_uri = args[:case_uri] if args.key?(:case_uri)
  @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time)
  @external_uid = args[:external_uid] if args.key?(:external_uid)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @ticket_info = args[:ticket_info] if args.key?(:ticket_info)
end