Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1MuteConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1MuteConfig

Returns a new instance of GoogleCloudSecuritycenterV1MuteConfig.



4312
4313
4314
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the mute config was created. This field is set by the server and will be ignored if provided on config creation. Corresponds to the JSON property createTime

Returns:

  • (String)


4248
4249
4250
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4248

def create_time
  @create_time
end

#descriptionString

A description of the mute config. Corresponds to the JSON property description

Returns:

  • (String)


4253
4254
4255
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4253

def description
  @description
end

#display_nameString

The human readable name to be displayed for the mute config. Corresponds to the JSON property displayName

Returns:

  • (String)


4258
4259
4260
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4258

def display_name
  @display_name
end

#expiry_timeString

Optional. The expiry of the mute config. Only applicable for dynamic configs. If the expiry is set, when the config expires, it is removed from all findings. Corresponds to the JSON property expiryTime

Returns:

  • (String)


4264
4265
4266
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4264

def expiry_time
  @expiry_time
end

#filterString

Required. An expression that defines the filter to apply across create/update events of findings. While creating a filter string, be mindful of the scope in which the mute configuration is being created. E.g., If a filter contains project = X but is created under the project = Y scope, it might not match any findings. The following field and operator combinations are supported: * severity: =, : * category: =, : * resource.name: =, : * resource. project_name: =, : * resource.project_display_name: =, : * resource. folders.resource_folder: =, : * resource.parent_name: =, : * resource. parent_display_name: =, : * resource.type: =, : * finding_class: =, : * indicator.ip_addresses: =, : * indicator.domains: =, : Corresponds to the JSON property filter

Returns:

  • (String)


4278
4279
4280
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4278

def filter
  @filter
end

#most_recent_editorString

Output only. Email address of the user who last edited the mute config. This field is set by the server and will be ignored if provided on config creation or update. Corresponds to the JSON property mostRecentEditor

Returns:

  • (String)


4285
4286
4287
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4285

def most_recent_editor
  @most_recent_editor
end

#nameString

This field will be ignored if provided on config creation. Format organizations/organization/muteConfigs/mute_config`folders/`folder`/ muteConfigs/`mute_config projects/project/muteConfigs/mute_config` organizations/`organization`/locations/global/muteConfigs/`mute_config folders/folder/locations/global/muteConfigs/mute_config`projects/` project`/locations/global/muteConfigs/`mute_config Corresponds to the JSON property name

Returns:

  • (String)


4295
4296
4297
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4295

def name
  @name
end

#typeString

Optional. The type of the mute config, which determines what type of mute state the config affects. The static mute state takes precedence over the dynamic mute state. Immutable after creation. STATIC by default if not set during creation. Corresponds to the JSON property type

Returns:

  • (String)


4303
4304
4305
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4303

def type
  @type
end

#update_timeString

Output only. The most recent time at which the mute config was updated. This field is set by the server and will be ignored if provided on config creation or update. Corresponds to the JSON property updateTime

Returns:

  • (String)


4310
4311
4312
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4310

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4317
4318
4319
4320
4321
4322
4323
4324
4325
4326
4327
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4317

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expiry_time = args[:expiry_time] if args.key?(:expiry_time)
  @filter = args[:filter] if args.key?(:filter)
  @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end