Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1MuteConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1MuteConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of the mute config.
-
#display_name ⇒ String
The human readable name to be displayed for the mute config.
-
#expiry_time ⇒ String
Optional.
-
#filter ⇒ String
Required.
-
#most_recent_editor ⇒ String
Output only.
-
#name ⇒ String
This field will be ignored if provided on config creation.
-
#type ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1MuteConfig
constructor
A new instance of GoogleCloudSecuritycenterV1MuteConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1MuteConfig
Returns a new instance of GoogleCloudSecuritycenterV1MuteConfig.
4024 4025 4026 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the mute config was created. This field is set
by the server and will be ignored if provided on config creation.
Corresponds to the JSON property createTime
3960 3961 3962 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3960 def create_time @create_time end |
#description ⇒ String
A description of the mute config.
Corresponds to the JSON property description
3965 3966 3967 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3965 def description @description end |
#display_name ⇒ String
The human readable name to be displayed for the mute config.
Corresponds to the JSON property displayName
3970 3971 3972 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3970 def display_name @display_name end |
#expiry_time ⇒ String
Optional. The expiry of the mute config. Only applicable for dynamic configs.
If the expiry is set, when the config expires, it is removed from all findings.
Corresponds to the JSON property expiryTime
3976 3977 3978 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3976 def expiry_time @expiry_time end |
#filter ⇒ String
Required. An expression that defines the filter to apply across create/update
events of findings. While creating a filter string, be mindful of the scope in
which the mute configuration is being created. E.g., If a filter contains
project = X but is created under the project = Y scope, it might not match any
findings. The following field and operator combinations are supported: *
severity: =, : * category: =, : * resource.name: =, : * resource.
project_name: =, : * resource.project_display_name: =, : * resource.
folders.resource_folder: =, : * resource.parent_name: =, : * resource.
parent_display_name: =, : * resource.type: =, : * finding_class: =,
: * indicator.ip_addresses: =, : * indicator.domains: =, :
Corresponds to the JSON property filter
3990 3991 3992 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3990 def filter @filter end |
#most_recent_editor ⇒ String
Output only. Email address of the user who last edited the mute config. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property mostRecentEditor
3997 3998 3999 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 3997 def most_recent_editor @most_recent_editor end |
#name ⇒ String
This field will be ignored if provided on config creation. Format
organizations/organization/muteConfigs/mute_config`folders/`folder`/
muteConfigs/`mute_config projects/project/muteConfigs/mute_config`
organizations/`organization`/locations/global/muteConfigs/`mute_config
folders/folder/locations/global/muteConfigs/mute_config`projects/`
project`/locations/global/muteConfigs/`mute_config
Corresponds to the JSON property name
4007 4008 4009 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4007 def name @name end |
#type ⇒ String
Optional. The type of the mute config, which determines what type of mute
state the config affects. The static mute state takes precedence over the
dynamic mute state. Immutable after creation. STATIC by default if not set
during creation.
Corresponds to the JSON property type
4015 4016 4017 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4015 def type @type end |
#update_time ⇒ String
Output only. The most recent time at which the mute config was updated. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property updateTime
4022 4023 4024 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4022 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4029 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @filter = args[:filter] if args.key?(:filter) @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |