Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#adc_application ⇒ Google::Apis::SecuritycenterV1::AdcApplication
Represents an ADC application associated with the finding.
-
#adc_application_template ⇒ Google::Apis::SecuritycenterV1::AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
-
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1::AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the resource resides in.
-
#display_name ⇒ String
The human readable name of the resource.
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Output only.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#organization ⇒ String
Indicates which organization or tenant in the cloud provider the finding applies to.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project ID that the resource belongs to.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1::ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The parent service or product from which the resource is provided, for example, GKE or SNS.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource
constructor
A new instance of GoogleCloudSecuritycenterV1Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource
Returns a new instance of GoogleCloudSecuritycenterV1Resource.
4583 4584 4585 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adc_application ⇒ Google::Apis::SecuritycenterV1::AdcApplication
Represents an ADC application associated with the finding.
Corresponds to the JSON property adcApplication
4470 4471 4472 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4470 def adc_application @adc_application end |
#adc_application_template ⇒ Google::Apis::SecuritycenterV1::AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
Corresponds to the JSON property adcApplicationTemplate
4475 4476 4477 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4475 def adc_application_template @adc_application_template end |
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1::AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
Corresponds to the JSON property adcSharedTemplate
4480 4481 4482 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4480 def adc_shared_template @adc_shared_template end |
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
4485 4486 4487 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4485 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
4491 4492 4493 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4491 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
4497 4498 4499 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4497 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the resource resides in.
Corresponds to the JSON property cloudProvider
4502 4503 4504 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4502 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
4507 4508 4509 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4507 def display_name @display_name end |
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
4514 4515 4516 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4514 def folders @folders end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
4519 4520 4521 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4519 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
4525 4526 4527 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4525 def name @name end |
#organization ⇒ String
Indicates which organization or tenant in the cloud provider the finding
applies to.
Corresponds to the JSON property organization
4531 4532 4533 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4531 def organization @organization end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
4536 4537 4538 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4536 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
4541 4542 4543 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4541 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
4546 4547 4548 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4546 def project @project end |
#project_display_name ⇒ String
The project ID that the resource belongs to.
Corresponds to the JSON property projectDisplayName
4551 4552 4553 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4551 def project_display_name @project_display_name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1::ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
4557 4558 4559 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4557 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of organizations/organization_id/folders/folder_id/folders/
folder_id/projects/project_idwhere there can be any number of folders.
For AWS, it has the format of `org/`organization_id`/ou/`
organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id
where there can be any number of organizational units. For Azure, it has the
format of mg/management_group_id/mg/management_group_id/subscription/
subscription_id/rg/resource_group_name`where there can be any number of
management groups.
Corresponds to the JSON propertyresourcePathString`
4570 4571 4572 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4570 def resource_path_string @resource_path_string end |
#service ⇒ String
The parent service or product from which the resource is provided, for example,
GKE or SNS.
Corresponds to the JSON property service
4576 4577 4578 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4576 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
4581 4582 4583 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4581 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4588 def update!(**args) @adc_application = args[:adc_application] if args.key?(:adc_application) @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template) @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @folders = args[:folders] if args.key?(:folders) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @organization = args[:organization] if args.key?(:organization) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |