Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource

Returns a new instance of GoogleCloudSecuritycenterV1Resource.



4524
4525
4526
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1::AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



4411
4412
4413
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4411

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1::AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



4416
4417
4418
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4416

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1::AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



4421
4422
4423
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4421

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



4426
4427
4428
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4426

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1::AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



4432
4433
4434
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4432

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1::AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



4438
4439
4440
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4438

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the resource resides in. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


4443
4444
4445
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4443

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


4448
4449
4450
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4448

def display_name
  @display_name
end

#foldersArray<Google::Apis::SecuritycenterV1::Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



4455
4456
4457
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4455

def folders
  @folders
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


4460
4461
4462
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4460

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


4466
4467
4468
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4466

def name
  @name
end

#organizationString

Indicates which organization or tenant in the cloud provider the finding applies to. Corresponds to the JSON property organization

Returns:

  • (String)


4472
4473
4474
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4472

def organization
  @organization
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


4477
4478
4479
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4477

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


4482
4483
4484
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4482

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


4487
4488
4489
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4487

def project
  @project
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


4492
4493
4494
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4492

def project_display_name
  @project_display_name
end

#resource_pathGoogle::Apis::SecuritycenterV1::ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



4498
4499
4500
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4498

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


4511
4512
4513
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4511

def resource_path_string
  @resource_path_string
end

#serviceString

The parent service or product from which the resource is provided, for example, GKE or SNS. Corresponds to the JSON property service

Returns:

  • (String)


4517
4518
4519
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4517

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


4522
4523
4524
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4522

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4529

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @folders = args[:folders] if args.key?(:folders)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @organization = args[:organization] if args.key?(:organization)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end