Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the resource resides in.
-
#display_name ⇒ String
The human readable name of the resource.
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Output only.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#organization ⇒ String
Indicates which organization or tenant in the cloud provider the finding applies to.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project ID that the resource belongs to.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1::ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The parent service or product from which the resource is provided, for example, GKE or SNS.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource
constructor
A new instance of GoogleCloudSecuritycenterV1Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource
Returns a new instance of GoogleCloudSecuritycenterV1Resource.
4221 4222 4223 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
4123 4124 4125 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4123 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
4129 4130 4131 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4129 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
4135 4136 4137 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4135 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the resource resides in.
Corresponds to the JSON property cloudProvider
4140 4141 4142 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4140 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
4145 4146 4147 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4145 def display_name @display_name end |
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
4152 4153 4154 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4152 def folders @folders end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
4157 4158 4159 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4157 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
4163 4164 4165 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4163 def name @name end |
#organization ⇒ String
Indicates which organization or tenant in the cloud provider the finding
applies to.
Corresponds to the JSON property organization
4169 4170 4171 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4169 def organization @organization end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
4174 4175 4176 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4174 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
4179 4180 4181 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4179 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
4184 4185 4186 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4184 def project @project end |
#project_display_name ⇒ String
The project ID that the resource belongs to.
Corresponds to the JSON property projectDisplayName
4189 4190 4191 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4189 def project_display_name @project_display_name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1::ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
4195 4196 4197 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4195 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of organizations/organization_id/folders/folder_id/folders/
folder_id/projects/project_idwhere there can be any number of folders.
For AWS, it has the format of `org/`organization_id`/ou/`
organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id
where there can be any number of organizational units. For Azure, it has the
format of mg/management_group_id/mg/management_group_id/subscription/
subscription_id/rg/resource_group_name`where there can be any number of
management groups.
Corresponds to the JSON propertyresourcePathString`
4208 4209 4210 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4208 def resource_path_string @resource_path_string end |
#service ⇒ String
The parent service or product from which the resource is provided, for example,
GKE or SNS.
Corresponds to the JSON property service
4214 4215 4216 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4214 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
4219 4220 4221 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4219 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4226 4227 4228 4229 4230 4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4226 def update!(**args) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @folders = args[:folders] if args.key?(:folders) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @organization = args[:organization] if args.key?(:organization) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |