Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Consumer provided attributes for the application
Instance Attribute Summary collapse
-
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered Corresponds to the JSON property
businessOwners. -
#criticality ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload Corresponds to the JSON property
criticality. -
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
-
#environment ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload Corresponds to the JSON property
environment. -
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceApplicationAttributes
constructor
A new instance of GoogleCloudSecuritycenterV1ResourceApplicationAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceApplicationAttributes
Returns a new instance of GoogleCloudSecuritycenterV1ResourceApplicationAttributes.
4608 4609 4610 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered
Corresponds to the JSON property businessOwners
4586 4587 4588 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4586 def business_owners @business_owners end |
#criticality ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload
Corresponds to the JSON property criticality
4591 4592 4593 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4591 def criticality @criticality end |
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
Corresponds to the JSON property developerOwners
4596 4597 4598 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4596 def developer_owners @developer_owners end |
#environment ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload
Corresponds to the JSON property environment
4601 4602 4603 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4601 def environment @environment end |
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Corresponds to the JSON property operatorOwners
4606 4607 4608 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4606 def operator_owners @operator_owners end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4613 4614 4615 4616 4617 4618 4619 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4613 def update!(**args) @business_owners = args[:business_owners] if args.key?(:business_owners) @criticality = args[:criticality] if args.key?(:criticality) @developer_owners = args[:developer_owners] if args.key?(:developer_owners) @environment = args[:environment] if args.key?(:environment) @operator_owners = args[:operator_owners] if args.key?(:operator_owners) end |