Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Consumer provided attributes for the application
Instance Attribute Summary collapse
-
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered Corresponds to the JSON property
businessOwners. -
#criticality ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload Corresponds to the JSON property
criticality. -
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
-
#environment ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload Corresponds to the JSON property
environment. -
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceApplicationAttributes
constructor
A new instance of GoogleCloudSecuritycenterV1ResourceApplicationAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceApplicationAttributes
Returns a new instance of GoogleCloudSecuritycenterV1ResourceApplicationAttributes.
4302 4303 4304 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered
Corresponds to the JSON property businessOwners
4280 4281 4282 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4280 def business_owners @business_owners end |
#criticality ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload
Corresponds to the JSON property criticality
4285 4286 4287 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4285 def criticality @criticality end |
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
Corresponds to the JSON property developerOwners
4290 4291 4292 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4290 def developer_owners @developer_owners end |
#environment ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload
Corresponds to the JSON property environment
4295 4296 4297 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4295 def environment @environment end |
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Corresponds to the JSON property operatorOwners
4300 4301 4302 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4300 def operator_owners @operator_owners end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4307 def update!(**args) @business_owners = args[:business_owners] if args.key?(:business_owners) @criticality = args[:criticality] if args.key?(:criticality) @developer_owners = args[:developer_owners] if args.key?(:developer_owners) @environment = args[:environment] if args.key?(:environment) @operator_owners = args[:operator_owners] if args.key?(:operator_owners) end |