Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceValueConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A resource value configuration (RVC) is a mapping configuration of user's resources to resource values. Used in Attack path simulations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceValueConfig

Returns a new instance of GoogleCloudSecuritycenterV1ResourceValueConfig.



4771
4772
4773
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_providerString

Cloud provider this configuration applies to Corresponds to the JSON property cloudProvider

Returns:

  • (String)


4706
4707
4708
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4706

def cloud_provider
  @cloud_provider
end

#create_timeString

Output only. Timestamp this resource value configuration was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4711
4712
4713
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4711

def create_time
  @create_time
end

#descriptionString

Description of the resource value configuration. Corresponds to the JSON property description

Returns:

  • (String)


4716
4717
4718
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4716

def description
  @description
end

#nameString

Name for the resource value configuration Corresponds to the JSON property name

Returns:

  • (String)


4721
4722
4723
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4721

def name
  @name
end

#resource_labels_selectorHash<String,String>

List of resource labels to search for, evaluated with AND. For example, " resource_labels_selector":"key": "value", "env": "prod"`will match resources with labels "key": "value"AND"env": "prod" https://cloud.google. com/resource-manager/docs/creating-managing-labels Corresponds to the JSON propertyresourceLabelsSelector`

Returns:

  • (Hash<String,String>)


4729
4730
4731
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4729

def resource_labels_selector
  @resource_labels_selector
end

#resource_typeString

Apply resource_value only to resources that match resource_type. resource_type will be checked with AND of other resources. For example, "storage. googleapis.com/Bucket" with resource_value "HIGH" will apply "HIGH" value only to "storage.googleapis.com/Bucket" resources. Corresponds to the JSON property resourceType

Returns:

  • (String)


4737
4738
4739
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4737

def resource_type
  @resource_type
end

#resource_valueString

Required. Resource value level this expression represents Corresponds to the JSON property resourceValue

Returns:

  • (String)


4742
4743
4744
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4742

def resource_value
  @resource_value
end

#scopeString

Project or folder to scope this configuration to. For example, "project/456" would apply this configuration only to resources in "project/456" scope will be checked with AND of other resources. Corresponds to the JSON property scope

Returns:

  • (String)


4749
4750
4751
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4749

def scope
  @scope
end

#sensitive_data_protection_mappingGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping

Resource value mapping for Sensitive Data Protection findings. If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration. Corresponds to the JSON property sensitiveDataProtectionMapping



4756
4757
4758
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4756

def sensitive_data_protection_mapping
  @sensitive_data_protection_mapping
end

#tag_valuesArray<String>

Required. Tag values combined with AND to check against. For Google Cloud resources, they are tag value IDs in the form of "tagValues/123". Example: [ " tagValues/123", "tagValues/456", "tagValues/789" ] https://cloud.google.com/ resource-manager/docs/tags/tags-creating-and-managing Corresponds to the JSON property tagValues

Returns:

  • (Array<String>)


4764
4765
4766
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4764

def tag_values
  @tag_values
end

#update_timeString

Output only. Timestamp this resource value configuration was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4769
4770
4771
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4769

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4776
4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4776

def update!(**args)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @resource_labels_selector = args[:resource_labels_selector] if args.key?(:resource_labels_selector)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @resource_value = args[:resource_value] if args.key?(:resource_value)
  @scope = args[:scope] if args.key?(:scope)
  @sensitive_data_protection_mapping = args[:sensitive_data_protection_mapping] if args.key?(:sensitive_data_protection_mapping)
  @tag_values = args[:tag_values] if args.key?(:tag_values)
  @update_time = args[:update_time] if args.key?(:update_time)
end