Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents an instance of a Security Health Analytics custom module, including its full module name, display name, enablement state, and last updated time. You can create a custom module at the organization, folder, or project level. Custom modules that you create at the organization or folder level are inherited by the child folders and projects.
Instance Attribute Summary collapse
-
#ancestor_module ⇒ String
Output only.
-
#cloud_provider ⇒ String
The cloud provider of the custom module.
-
#custom_config ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1CustomConfig
Defines the properties in a custom module configuration for Security Health Analytics.
-
#display_name ⇒ String
The display name of the Security Health Analytics custom module.
-
#enablement_state ⇒ String
The enablement state of the custom module.
-
#last_editor ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule
constructor
A new instance of GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule
Returns a new instance of GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule.
4938 4939 4940 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ancestor_module ⇒ String
Output only. If empty, indicates that the custom module was created in the
organization, folder, or project in which you are viewing the custom module.
Otherwise, ancestor_module specifies the organization or folder from which
the custom module is inherited.
Corresponds to the JSON property ancestorModule
4889 4890 4891 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4889 def ancestor_module @ancestor_module end |
#cloud_provider ⇒ String
The cloud provider of the custom module.
Corresponds to the JSON property cloudProvider
4894 4895 4896 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4894 def cloud_provider @cloud_provider end |
#custom_config ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1CustomConfig
Defines the properties in a custom module configuration for Security Health
Analytics. Use the custom module configuration to create custom detectors that
generate custom findings for resources that you specify.
Corresponds to the JSON property customConfig
4901 4902 4903 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4901 def custom_config @custom_config end |
#display_name ⇒ String
The display name of the Security Health Analytics custom module. This display
name becomes the finding category for all findings that are returned by this
custom module. The display name must be between 1 and 128 characters, start
with a lowercase letter, and contain alphanumeric characters or underscores
only.
Corresponds to the JSON property displayName
4910 4911 4912 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4910 def display_name @display_name end |
#enablement_state ⇒ String
The enablement state of the custom module.
Corresponds to the JSON property enablementState
4915 4916 4917 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4915 def enablement_state @enablement_state end |
#last_editor ⇒ String
Output only. The editor that last updated the custom module.
Corresponds to the JSON property lastEditor
4920 4921 4922 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4920 def last_editor @last_editor end |
#name ⇒ String
Immutable. The resource name of the custom module. Its format is "
organizations/organization/securityHealthAnalyticsSettings/customModules/
customModule", or "folders/folder/securityHealthAnalyticsSettings/
customModules/customModule", or "projects/project/
securityHealthAnalyticsSettings/customModules/customModule" The id
customModule is server-generated and is not user settable. It will be a
numeric id containing 1-20 digits.
Corresponds to the JSON property name
4931 4932 4933 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4931 def name @name end |
#update_time ⇒ String
Output only. The time at which the custom module was last updated.
Corresponds to the JSON property updateTime
4936 4937 4938 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4936 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4943 4944 4945 4946 4947 4948 4949 4950 4951 4952 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 4943 def update!(**args) @ancestor_module = args[:ancestor_module] if args.key?(:ancestor_module) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @custom_config = args[:custom_config] if args.key?(:custom_config) @display_name = args[:display_name] if args.key?(:display_name) @enablement_state = args[:enablement_state] if args.key?(:enablement_state) @last_editor = args[:last_editor] if args.key?(:last_editor) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |