Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Conveys information about a Kubernetes access review (such as one returned by
a kubectl auth can-i command) that was involved in a
finding.
Instance Attribute Summary collapse
-
#group ⇒ String
The API group of the resource.
-
#name ⇒ String
The name of the resource being requested.
-
#ns ⇒ String
Namespace of the action being requested.
-
#resource ⇒ String
The optional resource type requested.
-
#subresource ⇒ String
The optional subresource type.
-
#verb ⇒ String
A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy.
-
#version ⇒ String
The API version of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview
constructor
A new instance of GoogleCloudSecuritycenterV2AccessReview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview
Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.
5456 5457 5458 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ String
The API group of the resource. "*" means all.
Corresponds to the JSON property group
5422 5423 5424 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5422 def group @group end |
#name ⇒ String
The name of the resource being requested. Empty means all.
Corresponds to the JSON property name
5427 5428 5429 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5427 def name @name end |
#ns ⇒ String
Namespace of the action being requested. Currently, there is no distinction
between no namespace and all namespaces. Both are represented by "" (empty).
Corresponds to the JSON property ns
5433 5434 5435 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5433 def ns @ns end |
#resource ⇒ String
The optional resource type requested. "*" means all.
Corresponds to the JSON property resource
5438 5439 5440 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5438 def resource @resource end |
#subresource ⇒ String
The optional subresource type.
Corresponds to the JSON property subresource
5443 5444 5445 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5443 def subresource @subresource end |
#verb ⇒ String
A Kubernetes resource API verb, like get, list, watch, create, update, delete,
proxy. "*" means all.
Corresponds to the JSON property verb
5449 5450 5451 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5449 def verb @verb end |
#version ⇒ String
The API version of the resource. "*" means all.
Corresponds to the JSON property version
5454 5455 5456 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5454 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5461 5462 5463 5464 5465 5466 5467 5468 5469 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5461 def update!(**args) @group = args[:group] if args.key?(:group) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) @resource = args[:resource] if args.key?(:resource) @subresource = args[:subresource] if args.key?(:subresource) @verb = args[:verb] if args.key?(:verb) @version = args[:version] if args.key?(:version) end |