Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Conveys information about a Kubernetes access review (such as one returned by
a kubectl auth can-i command) that was involved in a
finding.
Instance Attribute Summary collapse
-
#group ⇒ String
The API group of the resource.
-
#name ⇒ String
The name of the resource being requested.
-
#ns ⇒ String
Namespace of the action being requested.
-
#resource ⇒ String
The optional resource type requested.
-
#subresource ⇒ String
The optional subresource type.
-
#verb ⇒ String
A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy.
-
#version ⇒ String
The API version of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview
constructor
A new instance of GoogleCloudSecuritycenterV2AccessReview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview
Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.
5397 5398 5399 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ String
The API group of the resource. "*" means all.
Corresponds to the JSON property group
5363 5364 5365 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5363 def group @group end |
#name ⇒ String
The name of the resource being requested. Empty means all.
Corresponds to the JSON property name
5368 5369 5370 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5368 def name @name end |
#ns ⇒ String
Namespace of the action being requested. Currently, there is no distinction
between no namespace and all namespaces. Both are represented by "" (empty).
Corresponds to the JSON property ns
5374 5375 5376 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5374 def ns @ns end |
#resource ⇒ String
The optional resource type requested. "*" means all.
Corresponds to the JSON property resource
5379 5380 5381 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5379 def resource @resource end |
#subresource ⇒ String
The optional subresource type.
Corresponds to the JSON property subresource
5384 5385 5386 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5384 def subresource @subresource end |
#verb ⇒ String
A Kubernetes resource API verb, like get, list, watch, create, update, delete,
proxy. "*" means all.
Corresponds to the JSON property verb
5390 5391 5392 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5390 def verb @verb end |
#version ⇒ String
The API version of the resource. "*" means all.
Corresponds to the JSON property version
5395 5396 5397 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5395 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5402 5403 5404 5405 5406 5407 5408 5409 5410 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5402 def update!(**args) @group = args[:group] if args.key?(:group) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) @resource = args[:resource] if args.key?(:resource) @subresource = args[:subresource] if args.key?(:subresource) @verb = args[:verb] if args.key?(:verb) @version = args[:version] if args.key?(:version) end |