Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Conveys information about a Kubernetes access review (such as one returned by a kubectl auth can-i command) that was involved in a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview

Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.



5091
5092
5093
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

The API group of the resource. "*" means all. Corresponds to the JSON property group

Returns:

  • (String)


5057
5058
5059
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5057

def group
  @group
end

#nameString

The name of the resource being requested. Empty means all. Corresponds to the JSON property name

Returns:

  • (String)


5062
5063
5064
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5062

def name
  @name
end

#nsString

Namespace of the action being requested. Currently, there is no distinction between no namespace and all namespaces. Both are represented by "" (empty). Corresponds to the JSON property ns

Returns:

  • (String)


5068
5069
5070
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5068

def ns
  @ns
end

#resourceString

The optional resource type requested. "*" means all. Corresponds to the JSON property resource

Returns:

  • (String)


5073
5074
5075
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5073

def resource
  @resource
end

#subresourceString

The optional subresource type. Corresponds to the JSON property subresource

Returns:

  • (String)


5078
5079
5080
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5078

def subresource
  @subresource
end

#verbString

A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy. "*" means all. Corresponds to the JSON property verb

Returns:

  • (String)


5084
5085
5086
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5084

def verb
  @verb
end

#versionString

The API version of the resource. "*" means all. Corresponds to the JSON property version

Returns:

  • (String)


5089
5090
5091
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5089

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5096
5097
5098
5099
5100
5101
5102
5103
5104
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5096

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
  @resource = args[:resource] if args.key?(:resource)
  @subresource = args[:subresource] if args.key?(:subresource)
  @verb = args[:verb] if args.key?(:verb)
  @version = args[:version] if args.key?(:version)
end