Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AgentDataAccessEvent
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AgentDataAccessEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Details about a data access attempt made by an agent principal not authorized under applicable data security policy.
Instance Attribute Summary collapse
-
#event_id ⇒ String
Unique identifier for data access event.
-
#event_time ⇒ String
Timestamp of data access event.
-
#operation ⇒ String
The operation performed by the principal to access the data.
-
#principal_subject ⇒ String
The agent principal that accessed the data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AgentDataAccessEvent
constructor
A new instance of GoogleCloudSecuritycenterV2AgentDataAccessEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AgentDataAccessEvent
Returns a new instance of GoogleCloudSecuritycenterV2AgentDataAccessEvent.
5550 5551 5552 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
Unique identifier for data access event.
Corresponds to the JSON property eventId
5533 5534 5535 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5533 def event_id @event_id end |
#event_time ⇒ String
Timestamp of data access event.
Corresponds to the JSON property eventTime
5538 5539 5540 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5538 def event_time @event_time end |
#operation ⇒ String
The operation performed by the principal to access the data.
Corresponds to the JSON property operation
5543 5544 5545 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5543 def operation @operation end |
#principal_subject ⇒ String
The agent principal that accessed the data.
Corresponds to the JSON property principalSubject
5548 5549 5550 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5548 def principal_subject @principal_subject end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5555 5556 5557 5558 5559 5560 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5555 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) @operation = args[:operation] if args.key?(:operation) @principal_subject = args[:principal_subject] if args.key?(:principal_subject) end |