Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AiModel
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AiModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Contains information about the AI model associated with the finding.
Instance Attribute Summary collapse
-
#deployment_platform ⇒ String
The platform on which the model is deployed.
-
#display_name ⇒ String
The user defined display name of model.
-
#domain ⇒ String
The domain of the model, for example, “image-classification”.
-
#library ⇒ String
The name of the model library, for example, “transformers”.
-
#location ⇒ String
The region in which the model is used, for example, “us-central1”.
-
#name ⇒ String
The name of the AI model, for example, "gemini:1.0.0".
-
#publisher ⇒ String
The publisher of the model, for example, “google” or “nvidia”.
-
#usage_category ⇒ String
The purpose of the model, for example, "Inteference" or "Training".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel
constructor
A new instance of GoogleCloudSecuritycenterV2AiModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel
Returns a new instance of GoogleCloudSecuritycenterV2AiModel.
5607 5608 5609 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_platform ⇒ String
The platform on which the model is deployed.
Corresponds to the JSON property deploymentPlatform
5570 5571 5572 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5570 def deployment_platform @deployment_platform end |
#display_name ⇒ String
The user defined display name of model. Ex. baseline-classification-model
Corresponds to the JSON property displayName
5575 5576 5577 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5575 def display_name @display_name end |
#domain ⇒ String
The domain of the model, for example, “image-classification”.
Corresponds to the JSON property domain
5580 5581 5582 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5580 def domain @domain end |
#library ⇒ String
The name of the model library, for example, “transformers”.
Corresponds to the JSON property library
5585 5586 5587 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5585 def library @library end |
#location ⇒ String
The region in which the model is used, for example, “us-central1”.
Corresponds to the JSON property location
5590 5591 5592 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5590 def location @location end |
#name ⇒ String
The name of the AI model, for example, "gemini:1.0.0".
Corresponds to the JSON property name
5595 5596 5597 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5595 def name @name end |
#publisher ⇒ String
The publisher of the model, for example, “google” or “nvidia”.
Corresponds to the JSON property publisher
5600 5601 5602 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5600 def publisher @publisher end |
#usage_category ⇒ String
The purpose of the model, for example, "Inteference" or "Training".
Corresponds to the JSON property usageCategory
5605 5606 5607 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5605 def usage_category @usage_category end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5612 def update!(**args) @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform) @display_name = args[:display_name] if args.key?(:display_name) @domain = args[:domain] if args.key?(:domain) @library = args[:library] if args.key?(:library) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @publisher = args[:publisher] if args.key?(:publisher) @usage_category = args[:usage_category] if args.key?(:usage_category) end |