Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AiModel
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AiModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Contains information about the AI model associated with the finding.
Instance Attribute Summary collapse
-
#deployment_platform ⇒ String
The platform on which the model is deployed.
-
#display_name ⇒ String
The user defined display name of model.
-
#domain ⇒ String
The domain of the model, for example, “image-classification”.
-
#library ⇒ String
The name of the model library, for example, “transformers”.
-
#location ⇒ String
The region in which the model is used, for example, “us-central1”.
-
#name ⇒ String
The name of the AI model, for example, "gemini:1.0.0".
-
#publisher ⇒ String
The publisher of the model, for example, “google” or “nvidia”.
-
#usage_category ⇒ String
The purpose of the model, for example, "Inteference" or "Training".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel
constructor
A new instance of GoogleCloudSecuritycenterV2AiModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel
Returns a new instance of GoogleCloudSecuritycenterV2AiModel.
5195 5196 5197 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_platform ⇒ String
The platform on which the model is deployed.
Corresponds to the JSON property deploymentPlatform
5158 5159 5160 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5158 def deployment_platform @deployment_platform end |
#display_name ⇒ String
The user defined display name of model. Ex. baseline-classification-model
Corresponds to the JSON property displayName
5163 5164 5165 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5163 def display_name @display_name end |
#domain ⇒ String
The domain of the model, for example, “image-classification”.
Corresponds to the JSON property domain
5168 5169 5170 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5168 def domain @domain end |
#library ⇒ String
The name of the model library, for example, “transformers”.
Corresponds to the JSON property library
5173 5174 5175 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5173 def library @library end |
#location ⇒ String
The region in which the model is used, for example, “us-central1”.
Corresponds to the JSON property location
5178 5179 5180 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5178 def location @location end |
#name ⇒ String
The name of the AI model, for example, "gemini:1.0.0".
Corresponds to the JSON property name
5183 5184 5185 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5183 def name @name end |
#publisher ⇒ String
The publisher of the model, for example, “google” or “nvidia”.
Corresponds to the JSON property publisher
5188 5189 5190 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5188 def publisher @publisher end |
#usage_category ⇒ String
The purpose of the model, for example, "Inteference" or "Training".
Corresponds to the JSON property usageCategory
5193 5194 5195 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5193 def usage_category @usage_category end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5200 5201 5202 5203 5204 5205 5206 5207 5208 5209 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5200 def update!(**args) @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform) @display_name = args[:display_name] if args.key?(:display_name) @domain = args[:domain] if args.key?(:domain) @library = args[:library] if args.key?(:library) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @publisher = args[:publisher] if args.key?(:publisher) @usage_category = args[:usage_category] if args.key?(:usage_category) end |