Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ArtifactGuardPolicy
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ArtifactGuardPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents an artifact guard policy.
Instance Attribute Summary collapse
-
#failure_reason ⇒ String
The reason for the policy failure, for example, "severity=HIGH AND max_vuln_count=2".
-
#policy_id ⇒ String
The ID of the failing policy, for example, "organizations/3392779/locations/ global/policies/prod-policy".
-
#type ⇒ String
The type of the policy evaluation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ArtifactGuardPolicy
constructor
A new instance of GoogleCloudSecuritycenterV2ArtifactGuardPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ArtifactGuardPolicy
Returns a new instance of GoogleCloudSecuritycenterV2ArtifactGuardPolicy.
5304 5305 5306 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_reason ⇒ String
The reason for the policy failure, for example, "severity=HIGH AND
max_vuln_count=2".
Corresponds to the JSON property failureReason
5291 5292 5293 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5291 def failure_reason @failure_reason end |
#policy_id ⇒ String
The ID of the failing policy, for example, "organizations/3392779/locations/
global/policies/prod-policy".
Corresponds to the JSON property policyId
5297 5298 5299 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5297 def policy_id @policy_id end |
#type ⇒ String
The type of the policy evaluation.
Corresponds to the JSON property type
5302 5303 5304 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5302 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5309 5310 5311 5312 5313 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5309 def update!(**args) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @policy_id = args[:policy_id] if args.key?(:policy_id) @type = args[:type] if args.key?(:type) end |