Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AwsOrganization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

An organization is a collection of accounts that are centrally managed together using consolidated billing, organized hierarchically with organizational units (OUs), and controlled with policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AwsOrganization

Returns a new instance of GoogleCloudSecuritycenterV2AwsOrganization.



5497
5498
5499
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier (ID) for the organization. The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits. Corresponds to the JSON property id

Returns:

  • (String)


5495
5496
5497
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5495

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5502
5503
5504
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5502

def update!(**args)
  @id = args[:id] if args.key?(:id)
end