Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AzureMetadata

Returns a new instance of GoogleCloudSecuritycenterV2AzureMetadata.



5590
5591
5592
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#management_groupsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureManagementGroup>

A list of Azure management groups associated with the resource, ordered from lowest level (closest to the subscription) to highest level. Corresponds to the JSON property managementGroups



5573
5574
5575
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5573

def management_groups
  @management_groups
end

#resource_groupGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureResourceGroup

Represents an Azure resource group. Corresponds to the JSON property resourceGroup



5578
5579
5580
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5578

def resource_group
  @resource_group
end

#subscriptionGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureSubscription

Represents an Azure subscription. Corresponds to the JSON property subscription



5583
5584
5585
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5583

def subscription
  @subscription
end

#tenantGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureTenant

Represents a Microsoft Entra tenant. Corresponds to the JSON property tenant



5588
5589
5590
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5588

def tenant
  @tenant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5595
5596
5597
5598
5599
5600
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5595

def update!(**args)
  @management_groups = args[:management_groups] if args.key?(:management_groups)
  @resource_group = args[:resource_group] if args.key?(:resource_group)
  @subscription = args[:subscription] if args.key?(:subscription)
  @tenant = args[:tenant] if args.key?(:tenant)
end