Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2BackupDisasterRecovery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information related to Google Cloud Backup and DR Service findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2BackupDisasterRecovery

Returns a new instance of GoogleCloudSecuritycenterV2BackupDisasterRecovery.



5758
5759
5760
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applianceString

The name of the Backup and DR appliance that captures, moves, and manages the lifecycle of backup data. For example, backup-server-57137. Corresponds to the JSON property appliance

Returns:

  • (String)


5688
5689
5690
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5688

def appliance
  @appliance
end

#applicationsArray<String>

The names of Backup and DR applications. An application is a VM, database, or file system on a managed host monitored by a backup and recovery appliance. For example, centos7-01-vol00, centos7-01-vol01, centos7-01-vol02. Corresponds to the JSON property applications

Returns:

  • (Array<String>)


5695
5696
5697
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5695

def applications
  @applications
end

#backup_create_timeString

The timestamp at which the Backup and DR backup was created. Corresponds to the JSON property backupCreateTime

Returns:

  • (String)


5700
5701
5702
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5700

def backup_create_time
  @backup_create_time
end

#backup_templateString

The name of a Backup and DR template which comprises one or more backup policies. See the Backup and DR documentation for more information. For example, snap-ov. Corresponds to the JSON property backupTemplate

Returns:

  • (String)


5708
5709
5710
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5708

def backup_template
  @backup_template
end

#backup_typeString

The backup type of the Backup and DR image. For example, Snapshot, Remote Snapshot, OnVault. Corresponds to the JSON property backupType

Returns:

  • (String)


5714
5715
5716
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5714

def backup_type
  @backup_type
end

#hostString

The name of a Backup and DR host, which is managed by the backup and recovery appliance and known to the management console. The host can be of type Generic (for example, Compute Engine, SQL Server, Oracle DB, SMB file system, etc.), vCenter, or an ESX server. See the Backup and DR documentation on hosts for more information. For example, centos7-01. Corresponds to the JSON property host

Returns:

  • (String)


5724
5725
5726
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5724

def host
  @host
end

#policiesArray<String>

The names of Backup and DR policies that are associated with a template and that define when to run a backup, how frequently to run a backup, and how long to retain the backup image. For example, onvaults. Corresponds to the JSON property policies

Returns:

  • (Array<String>)


5731
5732
5733
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5731

def policies
  @policies
end

#policy_optionsArray<String>

The names of Backup and DR advanced policy options of a policy applying to an application. See the Backup and DR documentation on policy options. For example, skipofflineappsincongrp, nounmap. Corresponds to the JSON property policyOptions

Returns:

  • (Array<String>)


5739
5740
5741
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5739

def policy_options
  @policy_options
end

#profileString

The name of the Backup and DR resource profile that specifies the storage media for backups of application and VM data. See the Backup and DR documentation on profiles. For example, GCP. Corresponds to the JSON property profile

Returns:

  • (String)


5747
5748
5749
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5747

def profile
  @profile
end

#storage_poolString

The name of the Backup and DR storage pool that the backup and recovery appliance is storing data in. The storage pool could be of type Cloud, Primary, Snapshot, or OnVault. See the Backup and DR documentation on storage pools. For example, DiskPoolOne. Corresponds to the JSON property storagePool

Returns:

  • (String)


5756
5757
5758
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5756

def storage_pool
  @storage_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5763
5764
5765
5766
5767
5768
5769
5770
5771
5772
5773
5774
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5763

def update!(**args)
  @appliance = args[:appliance] if args.key?(:appliance)
  @applications = args[:applications] if args.key?(:applications)
  @backup_create_time = args[:backup_create_time] if args.key?(:backup_create_time)
  @backup_template = args[:backup_template] if args.key?(:backup_template)
  @backup_type = args[:backup_type] if args.key?(:backup_type)
  @host = args[:host] if args.key?(:host)
  @policies = args[:policies] if args.key?(:policies)
  @policy_options = args[:policy_options] if args.key?(:policy_options)
  @profile = args[:profile] if args.key?(:profile)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
end