Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2BigQueryExport
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2BigQueryExport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Configures how to deliver Findings to BigQuery Instance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Output only.
-
#dataset ⇒ String
The dataset to write findings' updates to.
-
#description ⇒ String
The description of the export (max of 1024 characters).
-
#filter ⇒ String
Expression that defines the filter to apply across create/update events of findings.
-
#most_recent_editor ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#principal ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2BigQueryExport
constructor
A new instance of GoogleCloudSecuritycenterV2BigQueryExport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2BigQueryExport
Returns a new instance of GoogleCloudSecuritycenterV2BigQueryExport.
5851 5852 5853 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the BigQuery export was created. This field is
set by the server and will be ignored if provided on export on creation.
Corresponds to the JSON property createTime
5785 5786 5787 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5785 def create_time @create_time end |
#crypto_key_name ⇒ String
Output only. The resource name of the Cloud KMS CryptoKey used to protect
this configuration's data, if configured during Security Command Center
activation.
Corresponds to the JSON property cryptoKeyName
5792 5793 5794 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5792 def crypto_key_name @crypto_key_name end |
#dataset ⇒ String
The dataset to write findings' updates to. Its format is "projects/[project_id]
/datasets/[bigquery_dataset_id]". BigQuery dataset unique ID must contain only
letters (a-z, A-Z), numbers (0-9), or underscores (_).
Corresponds to the JSON property dataset
5799 5800 5801 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5799 def dataset @dataset end |
#description ⇒ String
The description of the export (max of 1024 characters).
Corresponds to the JSON property description
5804 5805 5806 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5804 def description @description end |
#filter ⇒ String
Expression that defines the filter to apply across create/update events of
findings. The expression is a list of zero or more restrictions combined via
logical operators AND and OR. Parentheses are supported, and OR has
higher precedence than AND. Restrictions have the form and may have a -
character in front of them to indicate negation. The fields map to those
defined in the corresponding resource. The supported operators are: * = for
all value types. * >, <, >=, <= for integer values. * :, meaning
substring matching, for strings. The supported value types are: * string
literals in quotes. * integer literals without quotes. * boolean literals
true and false without quotes.
Corresponds to the JSON property filter
5818 5819 5820 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5818 def filter @filter end |
#most_recent_editor ⇒ String
Output only. Email address of the user who last edited the BigQuery export.
This field is set by the server and will be ignored if provided on export
creation or update.
Corresponds to the JSON property mostRecentEditor
5825 5826 5827 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5825 def most_recent_editor @most_recent_editor end |
#name ⇒ String
Identifier. The relative resource name of this export. See: https://cloud.
google.com/apis/design/resource_names#relative_resource_name. The following
list shows some examples: + organizations/organization_id/locations/
location_id/bigQueryExports/export_id+ `folders/`folder_id`/locations/`
location_id`/bigQueryExports/`export_id + projects/project_id/locations/
location_id/bigQueryExports/export_id`This field is provided in responses,
and is ignored when provided in create requests.
Corresponds to the JSON propertyname`
5836 5837 5838 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5836 def name @name end |
#principal ⇒ String
Output only. The service account that needs permission to create table and
upload data to the BigQuery dataset.
Corresponds to the JSON property principal
5842 5843 5844 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5842 def principal @principal end |
#update_time ⇒ String
Output only. The most recent time at which the BigQuery export was updated.
This field is set by the server and will be ignored if provided on export
creation or update.
Corresponds to the JSON property updateTime
5849 5850 5851 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5849 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 5856 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @dataset = args[:dataset] if args.key?(:dataset) @description = args[:description] if args.key?(:description) @filter = args[:filter] if args.key?(:filter) @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor) @name = args[:name] if args.key?(:name) @principal = args[:principal] if args.key?(:principal) @update_time = args[:update_time] if args.key?(:update_time) end |