Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudDlpDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudDlpDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
The data profile associated with the finding.
Instance Attribute Summary collapse
-
#data_profile ⇒ String
Name of the data profile, for example,
projects/123/locations/europe/ tableProfiles/8383929. -
#info_types ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2InfoType>
Type of information detected by SDP.
-
#parent_type ⇒ String
The resource hierarchy level at which the data profile was generated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudDlpDataProfile
constructor
A new instance of GoogleCloudSecuritycenterV2CloudDlpDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudDlpDataProfile
Returns a new instance of GoogleCloudSecuritycenterV2CloudDlpDataProfile.
6058 6059 6060 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6058 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_profile ⇒ String
Name of the data profile, for example, projects/123/locations/europe/
tableProfiles/8383929.
Corresponds to the JSON property dataProfile
6045 6046 6047 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6045 def data_profile @data_profile end |
#info_types ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2InfoType>
Type of information detected by SDP. Info type includes name, version and
sensitivity of the detected information type.
Corresponds to the JSON property infoTypes
6051 6052 6053 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6051 def info_types @info_types end |
#parent_type ⇒ String
The resource hierarchy level at which the data profile was generated.
Corresponds to the JSON property parentType
6056 6057 6058 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6056 def parent_type @parent_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6063 6064 6065 6066 6067 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6063 def update!(**args) @data_profile = args[:data_profile] if args.key?(:data_profile) @info_types = args[:info_types] if args.key?(:info_types) @parent_type = args[:parent_type] if args.key?(:parent_type) end |