Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Details about data retention deletion violations, in which the data is non- compliant based on their retention or deletion time, as defined in the applicable data security policy. The Data Retention Deletion (DRD) control is a control of the DSPM (Data Security Posture Management) suite that enables organizations to manage data retention and deletion policies in compliance with regulations, such as GDPR and CRPA. DRD supports two primary policy types: maximum storage length (max TTL) and minimum storage length (min TTL). Both are aimed at helping organizations meet regulatory and data management commitments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataRetentionDeletionEvent

Returns a new instance of GoogleCloudSecuritycenterV2DataRetentionDeletionEvent.



6679
6680
6681
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_object_countFixnum

Number of objects that violated the policy for this resource. If the number is less than 1,000, then the value of this field is the exact number. If the number of objects that violated the policy is greater than or equal to 1,000, then the value of this field is 1000. Corresponds to the JSON property dataObjectCount

Returns:

  • (Fixnum)


6657
6658
6659
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6657

def data_object_count
  @data_object_count
end

#event_detection_timeString

Timestamp indicating when the event was detected. Corresponds to the JSON property eventDetectionTime

Returns:

  • (String)


6662
6663
6664
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6662

def event_detection_time
  @event_detection_time
end

#event_typeString

Type of the DRD event. Corresponds to the JSON property eventType

Returns:

  • (String)


6667
6668
6669
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6667

def event_type
  @event_type
end

#max_retention_allowedString

Maximum duration of retention allowed from the DRD control. This comes from the DRD control where users set a max TTL for their data. For example, suppose that a user sets the max TTL for a Cloud Storage bucket to 90 days. However, an object in that bucket is 100 days old. In this case, a DataRetentionDeletionEvent will be generated for that Cloud Storage bucket, and the max_retention_allowed is 90 days. Corresponds to the JSON property maxRetentionAllowed

Returns:

  • (String)


6677
6678
6679
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6677

def max_retention_allowed
  @max_retention_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6684
6685
6686
6687
6688
6689
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6684

def update!(**args)
  @data_object_count = args[:data_object_count] if args.key?(:data_object_count)
  @event_detection_time = args[:event_detection_time] if args.key?(:event_detection_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @max_retention_allowed = args[:max_retention_allowed] if args.key?(:max_retention_allowed)
end