Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Database
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Database
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The human-readable name of the database that the user connected to.
-
#grantees ⇒ Array<String>
The target usernames, roles, or groups of an SQL privilege grant, which is not an IAM policy change.
-
#name ⇒ String
Some database resources may not have the full resource name populated because these resource types are not yet supported by Cloud Asset Inventory (e.g. Cloud SQL databases).
-
#query ⇒ String
The SQL statement that is associated with the database access.
-
#user_name ⇒ String
The username used to connect to the database.
-
#version ⇒ String
The version of the database, for example, POSTGRES_14.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Database
constructor
A new instance of GoogleCloudSecuritycenterV2Database.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Database
Returns a new instance of GoogleCloudSecuritycenterV2Database.
7159 7160 7161 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The human-readable name of the database that the user connected to.
Corresponds to the JSON property displayName
7124 7125 7126 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7124 def display_name @display_name end |
#grantees ⇒ Array<String>
The target usernames, roles, or groups of an SQL privilege grant, which is not
an IAM policy change.
Corresponds to the JSON property grantees
7130 7131 7132 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7130 def grantees @grantees end |
#name ⇒ String
Some database resources may not have the full resource name populated because these resource types are
not yet supported by Cloud Asset Inventory (e.g. Cloud SQL databases). In
these cases only the display name will be provided. The full resource name of the database that the user
connected to, if it is supported by Cloud Asset Inventory.
Corresponds to the JSON property name
7140 7141 7142 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7140 def name @name end |
#query ⇒ String
The SQL statement that is associated with the database access.
Corresponds to the JSON property query
7145 7146 7147 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7145 def query @query end |
#user_name ⇒ String
The username used to connect to the database. The username might not be an IAM
principal and does not have a set format.
Corresponds to the JSON property userName
7151 7152 7153 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7151 def user_name @user_name end |
#version ⇒ String
The version of the database, for example, POSTGRES_14. See the complete list.
Corresponds to the JSON property version
7157 7158 7159 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7157 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7164 7165 7166 7167 7168 7169 7170 7171 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7164 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @grantees = args[:grantees] if args.key?(:grantees) @name = args[:name] if args.key?(:name) @query = args[:query] if args.key?(:query) @user_name = args[:user_name] if args.key?(:user_name) @version = args[:version] if args.key?(:version) end |