Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DiscoveredWorkload

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Represents discovered, customer managed workload that is not registered with the respective GCP service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DiscoveredWorkload

Returns a new instance of GoogleCloudSecuritycenterV2DiscoveredWorkload.



7287
7288
7289
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceString

The confidence in detection of this workload. Corresponds to the JSON property confidence

Returns:

  • (String)


7259
7260
7261
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7259

def confidence
  @confidence
end

#detected_relevant_hardwareBoolean Also known as: detected_relevant_hardware?

A boolean flag set to true if associated hardware strongly predicts the workload type. Corresponds to the JSON property detectedRelevantHardware

Returns:

  • (Boolean)


7265
7266
7267
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7265

def detected_relevant_hardware
  @detected_relevant_hardware
end

#detected_relevant_keywordsBoolean Also known as: detected_relevant_keywords?

A boolean flag set to true if associated keywords strongly predict the workload type. Corresponds to the JSON property detectedRelevantKeywords

Returns:

  • (Boolean)


7272
7273
7274
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7272

def detected_relevant_keywords
  @detected_relevant_keywords
end

#detected_relevant_packagesBoolean Also known as: detected_relevant_packages?

A boolean flag set to true if installed packages strongly predict the workload type. Corresponds to the JSON property detectedRelevantPackages

Returns:

  • (Boolean)


7279
7280
7281
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7279

def detected_relevant_packages
  @detected_relevant_packages
end

#workload_typeString

The type of workload. Corresponds to the JSON property workloadType

Returns:

  • (String)


7285
7286
7287
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7285

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7292
7293
7294
7295
7296
7297
7298
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7292

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @detected_relevant_hardware = args[:detected_relevant_hardware] if args.key?(:detected_relevant_hardware)
  @detected_relevant_keywords = args[:detected_relevant_keywords] if args.key?(:detected_relevant_keywords)
  @detected_relevant_packages = args[:detected_relevant_packages] if args.key?(:detected_relevant_packages)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end