Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Exfiltration
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Exfiltration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Exfiltration represents a data exfiltration attempt from one or more sources
to one or more targets. The sources attribute lists the sources of the
exfiltrated data. The targets attribute lists the destinations the data was
copied to.
Instance Attribute Summary collapse
-
#sources ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExfilResource>
If there are multiple sources, then the data is considered "joined" between them.
-
#targets ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExfilResource>
If there are multiple targets, each target would get a complete copy of the " joined" source data.
-
#total_exfiltrated_bytes ⇒ Fixnum
Total exfiltrated bytes processed for the entire job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Exfiltration
constructor
A new instance of GoogleCloudSecuritycenterV2Exfiltration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Exfiltration
Returns a new instance of GoogleCloudSecuritycenterV2Exfiltration.
6986 6987 6988 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6986 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sources ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExfilResource>
If there are multiple sources, then the data is considered "joined" between
them. For instance, BigQuery can join multiple tables, and each table would be
considered a source.
Corresponds to the JSON property sources
6973 6974 6975 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6973 def sources @sources end |
#targets ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExfilResource>
If there are multiple targets, each target would get a complete copy of the "
joined" source data.
Corresponds to the JSON property targets
6979 6980 6981 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6979 def targets @targets end |
#total_exfiltrated_bytes ⇒ Fixnum
Total exfiltrated bytes processed for the entire job.
Corresponds to the JSON property totalExfiltratedBytes
6984 6985 6986 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6984 def total_exfiltrated_bytes @total_exfiltrated_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6991 6992 6993 6994 6995 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 6991 def update!(**args) @sources = args[:sources] if args.key?(:sources) @targets = args[:targets] if args.key?(:targets) @total_exfiltrated_bytes = args[:total_exfiltrated_bytes] if args.key?(:total_exfiltrated_bytes) end |