Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalSystem
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalSystem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Representation of third party SIEM/SOAR fields within SCC.
Instance Attribute Summary collapse
-
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
-
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
-
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
-
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
-
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
-
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
-
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
-
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the external system.
-
#name ⇒ String
Full resource name of the external system.
-
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the external system.
-
#ticket_info ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2TicketInfo
Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalSystem
constructor
A new instance of GoogleCloudSecuritycenterV2ExternalSystem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalSystem
Returns a new instance of GoogleCloudSecuritycenterV2ExternalSystem.
7749 7750 7751 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignees ⇒ Array<String>
References primary/secondary etc assignees in the external system.
Corresponds to the JSON property assignees
7687 7688 7689 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7687 def assignees @assignees end |
#case_close_time ⇒ String
The time when the case was closed, as reported by the external system.
Corresponds to the JSON property caseCloseTime
7692 7693 7694 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7692 def case_close_time @case_close_time end |
#case_create_time ⇒ String
The time when the case was created, as reported by the external system.
Corresponds to the JSON property caseCreateTime
7697 7698 7699 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7697 def case_create_time @case_create_time end |
#case_priority ⇒ String
The priority of the finding's corresponding case in the external system.
Corresponds to the JSON property casePriority
7702 7703 7704 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7702 def case_priority @case_priority end |
#case_sla ⇒ String
The SLA of the finding's corresponding case in the external system.
Corresponds to the JSON property caseSla
7707 7708 7709 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7707 def case_sla @case_sla end |
#case_uri ⇒ String
The link to the finding's corresponding case in the external system.
Corresponds to the JSON property caseUri
7712 7713 7714 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7712 def case_uri @case_uri end |
#external_system_update_time ⇒ String
The time when the case was last updated, as reported by the external system.
Corresponds to the JSON property externalSystemUpdateTime
7717 7718 7719 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7717 def external_system_update_time @external_system_update_time end |
#external_uid ⇒ String
The identifier that's used to track the finding's corresponding case in the
external system.
Corresponds to the JSON property externalUid
7723 7724 7725 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7723 def external_uid @external_uid end |
#name ⇒ String
Full resource name of the external system. The following list shows some
examples: + organizations/1234/sources/5678/findings/123456/externalSystems/
jira + organizations/1234/sources/5678/locations/us/findings/123456/
externalSystems/jira + folders/1234/sources/5678/findings/123456/
externalSystems/jira + folders/1234/sources/5678/locations/us/findings/
123456/externalSystems/jira + projects/1234/sources/5678/findings/123456/
externalSystems/jira + projects/1234/sources/5678/locations/us/findings/
123456/externalSystems/jira
Corresponds to the JSON property name
7735 7736 7737 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7735 def name @name end |
#status ⇒ String
The most recent status of the finding's corresponding case, as reported by the
external system.
Corresponds to the JSON property status
7741 7742 7743 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7741 def status @status end |
#ticket_info ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2TicketInfo
Information about the ticket, if any, that is being used to track the
resolution of the issue that is identified by this finding.
Corresponds to the JSON property ticketInfo
7747 7748 7749 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7747 def ticket_info @ticket_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7754 def update!(**args) @assignees = args[:assignees] if args.key?(:assignees) @case_close_time = args[:case_close_time] if args.key?(:case_close_time) @case_create_time = args[:case_create_time] if args.key?(:case_create_time) @case_priority = args[:case_priority] if args.key?(:case_priority) @case_sla = args[:case_sla] if args.key?(:case_sla) @case_uri = args[:case_uri] if args.key?(:case_uri) @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time) @external_uid = args[:external_uid] if args.key?(:external_uid) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @ticket_info = args[:ticket_info] if args.key?(:ticket_info) end |