Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Representation of third party SIEM/SOAR fields within SCC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalSystem

Returns a new instance of GoogleCloudSecuritycenterV2ExternalSystem.



7067
7068
7069
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneesArray<String>

References primary/secondary etc assignees in the external system. Corresponds to the JSON property assignees

Returns:

  • (Array<String>)


7005
7006
7007
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7005

def assignees
  @assignees
end

#case_close_timeString

The time when the case was closed, as reported by the external system. Corresponds to the JSON property caseCloseTime

Returns:

  • (String)


7010
7011
7012
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7010

def case_close_time
  @case_close_time
end

#case_create_timeString

The time when the case was created, as reported by the external system. Corresponds to the JSON property caseCreateTime

Returns:

  • (String)


7015
7016
7017
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7015

def case_create_time
  @case_create_time
end

#case_priorityString

The priority of the finding's corresponding case in the external system. Corresponds to the JSON property casePriority

Returns:

  • (String)


7020
7021
7022
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7020

def case_priority
  @case_priority
end

#case_slaString

The SLA of the finding's corresponding case in the external system. Corresponds to the JSON property caseSla

Returns:

  • (String)


7025
7026
7027
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7025

def case_sla
  @case_sla
end

#case_uriString

The link to the finding's corresponding case in the external system. Corresponds to the JSON property caseUri

Returns:

  • (String)


7030
7031
7032
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7030

def case_uri
  @case_uri
end

#external_system_update_timeString

The time when the case was last updated, as reported by the external system. Corresponds to the JSON property externalSystemUpdateTime

Returns:

  • (String)


7035
7036
7037
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7035

def external_system_update_time
  @external_system_update_time
end

#external_uidString

The identifier that's used to track the finding's corresponding case in the external system. Corresponds to the JSON property externalUid

Returns:

  • (String)


7041
7042
7043
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7041

def external_uid
  @external_uid
end

#nameString

Full resource name of the external system. The following list shows some examples: + organizations/1234/sources/5678/findings/123456/externalSystems/ jira + organizations/1234/sources/5678/locations/us/findings/123456/ externalSystems/jira + folders/1234/sources/5678/findings/123456/ externalSystems/jira + folders/1234/sources/5678/locations/us/findings/ 123456/externalSystems/jira + projects/1234/sources/5678/findings/123456/ externalSystems/jira + projects/1234/sources/5678/locations/us/findings/ 123456/externalSystems/jira Corresponds to the JSON property name

Returns:

  • (String)


7053
7054
7055
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7053

def name
  @name
end

#statusString

The most recent status of the finding's corresponding case, as reported by the external system. Corresponds to the JSON property status

Returns:

  • (String)


7059
7060
7061
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7059

def status
  @status
end

#ticket_infoGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2TicketInfo

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding. Corresponds to the JSON property ticketInfo



7065
7066
7067
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7065

def ticket_info
  @ticket_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7072
7073
7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
7084
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7072

def update!(**args)
  @assignees = args[:assignees] if args.key?(:assignees)
  @case_close_time = args[:case_close_time] if args.key?(:case_close_time)
  @case_create_time = args[:case_create_time] if args.key?(:case_create_time)
  @case_priority = args[:case_priority] if args.key?(:case_priority)
  @case_sla = args[:case_sla] if args.key?(:case_sla)
  @case_uri = args[:case_uri] if args.key?(:case_uri)
  @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time)
  @external_uid = args[:external_uid] if args.key?(:external_uid)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @ticket_info = args[:ticket_info] if args.key?(:ticket_info)
end