Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

File information about the related binary/library used by an executable, or the script used by a script interpreter

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2File

Returns a new instance of GoogleCloudSecuritycenterV2File.



7704
7705
7706
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Prefix of the file contents as a JSON-encoded string. Corresponds to the JSON property contents

Returns:

  • (String)


7659
7660
7661
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7659

def contents
  @contents
end

#disk_pathGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DiskPath

Path of the file in terms of underlying disk/partition identifiers. Corresponds to the JSON property diskPath



7664
7665
7666
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7664

def disk_path
  @disk_path
end

#file_load_stateString

The load state of the file. Corresponds to the JSON property fileLoadState

Returns:

  • (String)


7669
7670
7671
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7669

def file_load_state
  @file_load_state
end

#hashed_sizeFixnum

The length in bytes of the file prefix that was hashed. If hashed_size == size, any hashes reported represent the entire file. Corresponds to the JSON property hashedSize

Returns:

  • (Fixnum)


7675
7676
7677
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7675

def hashed_size
  @hashed_size
end

#operationsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2FileOperation>

Operation(s) performed on a file. Corresponds to the JSON property operations



7680
7681
7682
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7680

def operations
  @operations
end

#partially_hashedBoolean Also known as: partially_hashed?

True when the hash covers only a prefix of the file. Corresponds to the JSON property partiallyHashed

Returns:

  • (Boolean)


7685
7686
7687
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7685

def partially_hashed
  @partially_hashed
end

#pathString

Absolute path of the file as a JSON encoded string. Corresponds to the JSON property path

Returns:

  • (String)


7691
7692
7693
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7691

def path
  @path
end

#sha256String

SHA256 hash of the first hashed_size bytes of the file encoded as a hex string. If hashed_size == size, sha256 represents the SHA256 hash of the entire file. Corresponds to the JSON property sha256

Returns:

  • (String)


7697
7698
7699
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7697

def sha256
  @sha256
end

#sizeFixnum

Size of the file in bytes. Corresponds to the JSON property size

Returns:

  • (Fixnum)


7702
7703
7704
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7702

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7709
7710
7711
7712
7713
7714
7715
7716
7717
7718
7719
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7709

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @disk_path = args[:disk_path] if args.key?(:disk_path)
  @file_load_state = args[:file_load_state] if args.key?(:file_load_state)
  @hashed_size = args[:hashed_size] if args.key?(:hashed_size)
  @operations = args[:operations] if args.key?(:operations)
  @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed)
  @path = args[:path] if args.key?(:path)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @size = args[:size] if args.key?(:size)
end