Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Security Command Center finding. A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Finding

Returns a new instance of GoogleCloudSecuritycenterV2Finding.



8186
8187
8188
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Access

Represents an access event. Corresponds to the JSON property access



7752
7753
7754
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7752

def access
  @access
end

#affected_resourcesGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AffectedResources

Details about resources affected by this finding. Corresponds to the JSON property affectedResources



7757
7758
7759
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7757

def affected_resources
  @affected_resources
end

#agent_data_access_eventsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AgentDataAccessEvent>

Agent data access events associated with the finding. Corresponds to the JSON property agentDataAccessEvents



7762
7763
7764
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7762

def agent_data_access_events
  @agent_data_access_events
end

#ai_modelGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AiModel

Contains information about the AI model associated with the finding. Corresponds to the JSON property aiModel



7767
7768
7769
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7767

def ai_model
  @ai_model
end

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Application

Represents an application associated with a finding. Corresponds to the JSON property application



7772
7773
7774
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7772

def application
  @application
end

#artifact_guard_policiesGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ArtifactGuardPolicies

Represents the result of evaluating artifact guard policies. Corresponds to the JSON property artifactGuardPolicies



7777
7778
7779
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7777

def artifact_guard_policies
  @artifact_guard_policies
end

#attack_exposureGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AttackExposure

An attack exposure contains the results of an attack path simulation run. Corresponds to the JSON property attackExposure



7782
7783
7784
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7782

def attack_exposure
  @attack_exposure
end

#backup_disaster_recoveryGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2BackupDisasterRecovery

Information related to Google Cloud Backup and DR Service findings. Corresponds to the JSON property backupDisasterRecovery



7787
7788
7789
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7787

def backup_disaster_recovery
  @backup_disaster_recovery
end

#canonical_nameString

Output only. The canonical name of the finding. The following list shows some examples: + organizations/organization_id/sources/source_id/locations/ location_id/findings/finding_id+ `folders/`folder_id`/sources/`source_id`/ locations/`location_id`/findings/`finding_id + projects/project_id/ sources/source_id/locations/location_id/findings/finding_id`The prefix is the closest CRM ancestor of the resource associated with the finding. Corresponds to the JSON propertycanonicalName`

Returns:

  • (String)


7797
7798
7799
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7797

def canonical_name
  @canonical_name
end

#categoryString

Immutable. The additional taxonomy group within findings from a given source. Example: "XSS_FLASH_INJECTION" Corresponds to the JSON property category

Returns:

  • (String)


7803
7804
7805
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7803

def category
  @category
end

#chokepointGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Chokepoint

Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations. Corresponds to the JSON property chokepoint



7811
7812
7813
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7811

def chokepoint
  @chokepoint
end

#cloud_armorGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudArmor

Fields related to Google Cloud Armor findings. Corresponds to the JSON property cloudArmor



7816
7817
7818
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7816

def cloud_armor
  @cloud_armor
end

#cloud_dlp_data_profileGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudDlpDataProfile

The data profile associated with the finding. Corresponds to the JSON property cloudDlpDataProfile



7822
7823
7824
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7822

def cloud_dlp_data_profile
  @cloud_dlp_data_profile
end

#cloud_dlp_inspectionGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudDlpInspection

Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the finding. Corresponds to the JSON property cloudDlpInspection



7829
7830
7831
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7829

def cloud_dlp_inspection
  @cloud_dlp_inspection
end

#compliance_detailsGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ComplianceDetails

Compliance Details associated with the finding. Corresponds to the JSON property complianceDetails



7834
7835
7836
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7834

def compliance_details
  @compliance_details
end

#compliancesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Compliance>

Contains compliance information for security standards associated to the finding. Corresponds to the JSON property compliances



7840
7841
7842
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7840

def compliances
  @compliances
end

#connectionsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Connection>

Contains information about the IP connection associated with the finding. Corresponds to the JSON property connections



7845
7846
7847
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7845

def connections
  @connections
end

#contactsHash<String,Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ContactDetails>

Output only. Map containing the points of contact for the given finding. The key represents the type of contact, while the value contains a list of all the contacts that pertain. Please refer to: https://cloud.google.com/resource- manager/docs/managing-notification-contacts#notification-categories " security": "contacts": [ "email": "person1@company.com", "email": " person2@company.com" ] Corresponds to the JSON property contacts



7855
7856
7857
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7855

def contacts
  @contacts
end

#containersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Container>

Containers associated with the finding. This field provides information for both Kubernetes and non-Kubernetes containers. Corresponds to the JSON property containers



7861
7862
7863
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7861

def containers
  @containers
end

#create_timeString

Output only. The time at which the finding was created in Security Command Center. Corresponds to the JSON property createTime

Returns:

  • (String)


7867
7868
7869
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7867

def create_time
  @create_time
end

#crypto_key_nameString

Output only. The name of the Cloud KMS key used to encrypt this finding, if any. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


7873
7874
7875
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7873

def crypto_key_name
  @crypto_key_name
end

#data_access_eventsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataAccessEvent>

Data access events associated with the finding. Corresponds to the JSON property dataAccessEvents



7878
7879
7880
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7878

def data_access_events
  @data_access_events
end

#data_flow_eventsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataFlowEvent>

Data flow events associated with the finding. Corresponds to the JSON property dataFlowEvents



7883
7884
7885
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7883

def data_flow_events
  @data_flow_events
end

#data_retention_deletion_eventsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent>

Data retention deletion events associated with the finding. Corresponds to the JSON property dataRetentionDeletionEvents



7888
7889
7890
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7888

def data_retention_deletion_events
  @data_retention_deletion_events
end

#databaseGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Database

Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided. Corresponds to the JSON property database



7899
7900
7901
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7899

def database
  @database
end

#descriptionString

Contains more details about the finding. Corresponds to the JSON property description

Returns:

  • (String)


7904
7905
7906
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7904

def description
  @description
end

#discovered_workloadGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DiscoveredWorkload

Represents discovered, customer managed workload that is not registered with the respective GCP service. Corresponds to the JSON property discoveredWorkload



7910
7911
7912
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7910

def discovered_workload
  @discovered_workload
end

#diskGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Disk

Contains information about the disk associated with the finding. Corresponds to the JSON property disk



7915
7916
7917
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7915

def disk
  @disk
end

#event_timeString

The time the finding was first detected. If an existing finding is updated, then this is the time the update occurred. For example, if the finding represents an open firewall, this property captures the time the detector believes the firewall became open. The accuracy is determined by the detector. If the finding is later resolved, then this time reflects when the finding was resolved. This must not be set to a value greater than the current timestamp. Corresponds to the JSON property eventTime

Returns:

  • (String)


7925
7926
7927
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7925

def event_time
  @event_time
end

#exfiltrationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Exfiltration

Exfiltration represents a data exfiltration attempt from one or more sources to one or more targets. The sources attribute lists the sources of the exfiltrated data. The targets attribute lists the destinations the data was copied to. Corresponds to the JSON property exfiltration



7933
7934
7935
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7933

def exfiltration
  @exfiltration
end

#external_exposureGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalExposure

Details about the externally exposed resource associated with the finding. Corresponds to the JSON property externalExposure



7938
7939
7940
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7938

def external_exposure
  @external_exposure
end

#external_systemsHash<String,Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalSystem>

Output only. Third party SIEM/SOAR fields within SCC, contains external system information and external system finding fields. Corresponds to the JSON property externalSystems



7944
7945
7946
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7944

def external_systems
  @external_systems
end

#external_uriString

The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found. This field is guaranteed to be either empty or a well formed URL. Corresponds to the JSON property externalUri

Returns:

  • (String)


7951
7952
7953
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7951

def external_uri
  @external_uri
end

#filesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File>

File associated with the finding. Corresponds to the JSON property files



7956
7957
7958
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7956

def files
  @files
end

#finding_classString

The class of the finding. Corresponds to the JSON property findingClass

Returns:

  • (String)


7961
7962
7963
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7961

def finding_class
  @finding_class
end

#group_membershipsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2GroupMembership>

Contains details about groups of which this finding is a member. A group is a collection of findings that are related in some way. This field cannot be updated. Its value is ignored in all update requests. Corresponds to the JSON property groupMemberships



7968
7969
7970
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7968

def group_memberships
  @group_memberships
end

#iam_bindingsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IamBinding>

Represents IAM bindings associated with the finding. Corresponds to the JSON property iamBindings



7973
7974
7975
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7973

def iam_bindings
  @iam_bindings
end

#indicatorGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Indicator

Represents what's commonly known as an indicator of compromise (IoC) in computer forensics. This is an artifact observed on a network or in an operating system that, with high confidence, indicates a computer intrusion. For more information, see Indicator of compromise. Corresponds to the JSON property indicator



7982
7983
7984
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7982

def indicator
  @indicator
end

#ip_rulesGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IpRules

IP rules associated with the finding. Corresponds to the JSON property ipRules



7987
7988
7989
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7987

def ip_rules
  @ip_rules
end

#jobGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Job

Describes a job Corresponds to the JSON property job



7992
7993
7994
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7992

def job
  @job
end

#kernel_rootkitGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2KernelRootkit

Kernel mode rootkit signatures. Corresponds to the JSON property kernelRootkit



7997
7998
7999
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7997

def kernel_rootkit
  @kernel_rootkit
end

#kubernetesGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Kubernetes

Kubernetes-related attributes. Corresponds to the JSON property kubernetes



8002
8003
8004
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8002

def kubernetes
  @kubernetes
end

#load_balancersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2LoadBalancer>

The load balancers associated with the finding. Corresponds to the JSON property loadBalancers



8007
8008
8009
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8007

def load_balancers
  @load_balancers
end

#log_entriesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2LogEntry>

Log entries that are relevant to the finding. Corresponds to the JSON property logEntries



8012
8013
8014
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8012

def log_entries
  @log_entries
end

#mitre_attackGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2MitreAttack

MITRE ATT&CK tactics and techniques related to this finding. See: https:// attack.mitre.org Corresponds to the JSON property mitreAttack



8018
8019
8020
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8018

def mitre_attack
  @mitre_attack
end

#module_nameString

Unique identifier of the module which generated the finding. Example: folders/ 598186756061/securityHealthAnalyticsSettings/customModules/56799441161885 Corresponds to the JSON property moduleName

Returns:

  • (String)


8024
8025
8026
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8024

def module_name
  @module_name
end

#muteString

Indicates the mute state of a finding (either muted, unmuted or undefined). Unlike other attributes of a finding, a finding provider shouldn't set the value of mute. Corresponds to the JSON property mute

Returns:

  • (String)


8031
8032
8033
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8031

def mute
  @mute
end

#mute_infoGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2MuteInfo

Mute information about the finding, including whether the finding has a static mute or any matching dynamic mute rules. Corresponds to the JSON property muteInfo



8037
8038
8039
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8037

def mute_info
  @mute_info
end

#mute_initiatorString

Records additional information about the mute operation, for example, the mute configuration that muted the finding and the user who muted the finding. Corresponds to the JSON property muteInitiator

Returns:

  • (String)


8044
8045
8046
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8044

def mute_initiator
  @mute_initiator
end

#mute_update_timeString

Output only. The most recent time this finding was muted or unmuted. Corresponds to the JSON property muteUpdateTime

Returns:

  • (String)


8049
8050
8051
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8049

def mute_update_time
  @mute_update_time
end

#nameString

Identifier. The relative resource name of the finding. The following list shows some examples: + organizations/organization_id/sources/source_id/ findings/finding_id+ `organizations/`organization_id`/sources/`source_id`/ locations/`location_id`/findings/`finding_id + folders/folder_id/sources/ source_id/findings/finding_id+ `folders/`folder_id`/sources/`source_id`/ locations/`location_id`/findings/`finding_id + projects/project_id/ sources/source_id/findings/finding_id+ `projects/`project_id`/sources/` source_id`/locations/`location_id`/findings/`finding_id Corresponds to the JSON property name

Returns:

  • (String)


8062
8063
8064
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8062

def name
  @name
end

#networksArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Network>

Represents the VPC networks that the resource is attached to. Corresponds to the JSON property networks



8067
8068
8069
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8067

def networks
  @networks
end

#next_stepsString

Steps to address the finding. Corresponds to the JSON property nextSteps

Returns:

  • (String)


8072
8073
8074
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8072

def next_steps
  @next_steps
end

#notebookGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Notebook

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding. Corresponds to the JSON property notebook



8079
8080
8081
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8079

def notebook
  @notebook
end

#org_policiesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2OrgPolicy>

Contains information about the org policies associated with the finding. Corresponds to the JSON property orgPolicies



8084
8085
8086
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8084

def org_policies
  @org_policies
end

#parentString

The relative resource name of the source and location the finding belongs to. See: https://cloud.google.com/apis/design/resource_names# relative_resource_name This field is immutable after creation time. The following list shows some examples: + organizations/organization_id/sources/ source_id+ `folders/`folders_id`/sources/`source_id + projects/ projects_id/sources/source_id+ `organizations/`organization_id`/sources/` source_id`/locations/`location_id + folders/folders_id/sources/source_id /locations/location_id+ `projects/`projects_id`/sources/`source_id`/ locations/`location_id Corresponds to the JSON property parent

Returns:

  • (String)


8097
8098
8099
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8097

def parent
  @parent
end

#parent_display_nameString

Output only. The human readable display name of the finding source such as " Event Threat Detection" or "Security Health Analytics". Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


8103
8104
8105
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8103

def parent_display_name
  @parent_display_name
end

#policy_violation_summaryGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PolicyViolationSummary

Metadata summarizing policy violations of child resources of the affected resource. finding_category and resource determine the exact semantics of the counts. For example, when category= DATA_SECURITY_POSTURE_OBJECT_PUBLIC_ACCESS_VIOLATION and resource='storage. googleapis.com/buckets/my-bucket-name' then this counts the number of Cloud Storage objects in my-bucket-name which violate a Public Access control. Corresponds to the JSON property policyViolationSummary



8113
8114
8115
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8113

def policy_violation_summary
  @policy_violation_summary
end

#processesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Process>

Represents operating system processes associated with the Finding. Corresponds to the JSON property processes



8118
8119
8120
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8118

def processes
  @processes
end

#resource_nameString

Immutable. For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for. See: https://cloud.google.com/ apis/design/resource_names#full_resource_name When the finding is for a non- Google Cloud resource, the resourceName can be a customer or partner defined string. Corresponds to the JSON property resourceName

Returns:

  • (String)


8127
8128
8129
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8127

def resource_name
  @resource_name
end

#secretGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Secret

Details about a secret or credential associated with the finding. Corresponds to the JSON property secret



8132
8133
8134
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8132

def secret
  @secret
end

#security_marksGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SecurityMarks

User specified security marks that are attached to the parent Security Command Center resource. Security marks are scoped within a Security Command Center organization -- they can be modified and viewed by all users who have proper permissions on the organization. Corresponds to the JSON property securityMarks



8140
8141
8142
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8140

def security_marks
  @security_marks
end

#security_postureGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SecurityPosture

Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud. Corresponds to the JSON property securityPosture



8148
8149
8150
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8148

def security_posture
  @security_posture
end

#severityString

The severity of the finding. This field is managed by the source that writes the finding. Corresponds to the JSON property severity

Returns:

  • (String)


8154
8155
8156
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8154

def severity
  @severity
end

#source_propertiesHash<String,Object>

Source specific properties. These properties are managed by the source that writes the finding. The key names in the source_properties map must be between 1 and 255 characters, and must start with a letter and contain alphanumeric characters or underscores only. Corresponds to the JSON property sourceProperties

Returns:



8162
8163
8164
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8162

def source_properties
  @source_properties
end

#stateString

Output only. The state of the finding. Corresponds to the JSON property state

Returns:

  • (String)


8167
8168
8169
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8167

def state
  @state
end

#toxic_combinationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ToxicCombination

Contains details about a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently. A group of such issues is referred to as a toxic combination. Corresponds to the JSON property toxicCombination



8174
8175
8176
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8174

def toxic_combination
  @toxic_combination
end

#vertex_aiGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2VertexAi

Vertex AI-related information associated with the finding. Corresponds to the JSON property vertexAi



8179
8180
8181
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8179

def vertex_ai
  @vertex_ai
end

#vulnerabilityGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Vulnerability

Refers to common vulnerability fields e.g. cve, cvss, cwe etc. Corresponds to the JSON property vulnerability



8184
8185
8186
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8184

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8191
8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
8226
8227
8228
8229
8230
8231
8232
8233
8234
8235
8236
8237
8238
8239
8240
8241
8242
8243
8244
8245
8246
8247
8248
8249
8250
8251
8252
8253
8254
8255
8256
8257
8258
8259
8260
8261
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8191

def update!(**args)
  @access = args[:access] if args.key?(:access)
  @affected_resources = args[:affected_resources] if args.key?(:affected_resources)
  @agent_data_access_events = args[:agent_data_access_events] if args.key?(:agent_data_access_events)
  @ai_model = args[:ai_model] if args.key?(:ai_model)
  @application = args[:application] if args.key?(:application)
  @artifact_guard_policies = args[:artifact_guard_policies] if args.key?(:artifact_guard_policies)
  @attack_exposure = args[:attack_exposure] if args.key?(:attack_exposure)
  @backup_disaster_recovery = args[:backup_disaster_recovery] if args.key?(:backup_disaster_recovery)
  @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
  @category = args[:category] if args.key?(:category)
  @chokepoint = args[:chokepoint] if args.key?(:chokepoint)
  @cloud_armor = args[:cloud_armor] if args.key?(:cloud_armor)
  @cloud_dlp_data_profile = args[:cloud_dlp_data_profile] if args.key?(:cloud_dlp_data_profile)
  @cloud_dlp_inspection = args[:cloud_dlp_inspection] if args.key?(:cloud_dlp_inspection)
  @compliance_details = args[:compliance_details] if args.key?(:compliance_details)
  @compliances = args[:compliances] if args.key?(:compliances)
  @connections = args[:connections] if args.key?(:connections)
  @contacts = args[:contacts] if args.key?(:contacts)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @data_access_events = args[:data_access_events] if args.key?(:data_access_events)
  @data_flow_events = args[:data_flow_events] if args.key?(:data_flow_events)
  @data_retention_deletion_events = args[:data_retention_deletion_events] if args.key?(:data_retention_deletion_events)
  @database = args[:database] if args.key?(:database)
  @description = args[:description] if args.key?(:description)
  @discovered_workload = args[:discovered_workload] if args.key?(:discovered_workload)
  @disk = args[:disk] if args.key?(:disk)
  @event_time = args[:event_time] if args.key?(:event_time)
  @exfiltration = args[:exfiltration] if args.key?(:exfiltration)
  @external_exposure = args[:external_exposure] if args.key?(:external_exposure)
  @external_systems = args[:external_systems] if args.key?(:external_systems)
  @external_uri = args[:external_uri] if args.key?(:external_uri)
  @files = args[:files] if args.key?(:files)
  @finding_class = args[:finding_class] if args.key?(:finding_class)
  @group_memberships = args[:group_memberships] if args.key?(:group_memberships)
  @iam_bindings = args[:iam_bindings] if args.key?(:iam_bindings)
  @indicator = args[:indicator] if args.key?(:indicator)
  @ip_rules = args[:ip_rules] if args.key?(:ip_rules)
  @job = args[:job] if args.key?(:job)
  @kernel_rootkit = args[:kernel_rootkit] if args.key?(:kernel_rootkit)
  @kubernetes = args[:kubernetes] if args.key?(:kubernetes)
  @load_balancers = args[:load_balancers] if args.key?(:load_balancers)
  @log_entries = args[:log_entries] if args.key?(:log_entries)
  @mitre_attack = args[:mitre_attack] if args.key?(:mitre_attack)
  @module_name = args[:module_name] if args.key?(:module_name)
  @mute = args[:mute] if args.key?(:mute)
  @mute_info = args[:mute_info] if args.key?(:mute_info)
  @mute_initiator = args[:mute_initiator] if args.key?(:mute_initiator)
  @mute_update_time = args[:mute_update_time] if args.key?(:mute_update_time)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @next_steps = args[:next_steps] if args.key?(:next_steps)
  @notebook = args[:notebook] if args.key?(:notebook)
  @org_policies = args[:org_policies] if args.key?(:org_policies)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @policy_violation_summary = args[:policy_violation_summary] if args.key?(:policy_violation_summary)
  @processes = args[:processes] if args.key?(:processes)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @secret = args[:secret] if args.key?(:secret)
  @security_marks = args[:security_marks] if args.key?(:security_marks)
  @security_posture = args[:security_posture] if args.key?(:security_posture)
  @severity = args[:severity] if args.key?(:severity)
  @source_properties = args[:source_properties] if args.key?(:source_properties)
  @state = args[:state] if args.key?(:state)
  @toxic_combination = args[:toxic_combination] if args.key?(:toxic_combination)
  @vertex_ai = args[:vertex_ai] if args.key?(:vertex_ai)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end