Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Security Command Center finding. A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Finding

Returns a new instance of GoogleCloudSecuritycenterV2Finding.



7596
7597
7598
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7596

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Access

Represents an access event. Corresponds to the JSON property access



7188
7189
7190
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7188

def access
  @access
end

#affected_resourcesGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AffectedResources

Details about resources affected by this finding. Corresponds to the JSON property affectedResources



7193
7194
7195
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7193

def affected_resources
  @affected_resources
end

#ai_modelGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AiModel

Contains information about the AI model associated with the finding. Corresponds to the JSON property aiModel



7198
7199
7200
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7198

def ai_model
  @ai_model
end

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Application

Represents an application associated with a finding. Corresponds to the JSON property application



7203
7204
7205
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7203

def application
  @application
end

#artifact_guard_policiesGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ArtifactGuardPolicies

Represents the result of evaluating artifact guard policies. Corresponds to the JSON property artifactGuardPolicies



7208
7209
7210
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7208

def artifact_guard_policies
  @artifact_guard_policies
end

#attack_exposureGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AttackExposure

An attack exposure contains the results of an attack path simulation run. Corresponds to the JSON property attackExposure



7213
7214
7215
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7213

def attack_exposure
  @attack_exposure
end

#backup_disaster_recoveryGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2BackupDisasterRecovery

Information related to Google Cloud Backup and DR Service findings. Corresponds to the JSON property backupDisasterRecovery



7218
7219
7220
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7218

def backup_disaster_recovery
  @backup_disaster_recovery
end

#canonical_nameString

Output only. The canonical name of the finding. The following list shows some examples: + organizations/organization_id/sources/source_id/locations/ location_id/findings/finding_id+ `folders/`folder_id`/sources/`source_id`/ locations/`location_id`/findings/`finding_id + projects/project_id/ sources/source_id/locations/location_id/findings/finding_id`The prefix is the closest CRM ancestor of the resource associated with the finding. Corresponds to the JSON propertycanonicalName`

Returns:

  • (String)


7228
7229
7230
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7228

def canonical_name
  @canonical_name
end

#categoryString

Immutable. The additional taxonomy group within findings from a given source. Example: "XSS_FLASH_INJECTION" Corresponds to the JSON property category

Returns:

  • (String)


7234
7235
7236
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7234

def category
  @category
end

#chokepointGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Chokepoint

Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations. Corresponds to the JSON property chokepoint



7242
7243
7244
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7242

def chokepoint
  @chokepoint
end

#cloud_armorGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudArmor

Fields related to Google Cloud Armor findings. Corresponds to the JSON property cloudArmor



7247
7248
7249
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7247

def cloud_armor
  @cloud_armor
end

#cloud_dlp_data_profileGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudDlpDataProfile

The data profile associated with the finding. Corresponds to the JSON property cloudDlpDataProfile



7253
7254
7255
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7253

def cloud_dlp_data_profile
  @cloud_dlp_data_profile
end

#cloud_dlp_inspectionGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2CloudDlpInspection

Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the finding. Corresponds to the JSON property cloudDlpInspection



7260
7261
7262
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7260

def cloud_dlp_inspection
  @cloud_dlp_inspection
end

#compliance_detailsGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ComplianceDetails

Compliance Details associated with the finding. Corresponds to the JSON property complianceDetails



7265
7266
7267
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7265

def compliance_details
  @compliance_details
end

#compliancesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Compliance>

Contains compliance information for security standards associated to the finding. Corresponds to the JSON property compliances



7271
7272
7273
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7271

def compliances
  @compliances
end

#connectionsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Connection>

Contains information about the IP connection associated with the finding. Corresponds to the JSON property connections



7276
7277
7278
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7276

def connections
  @connections
end

#contactsHash<String,Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ContactDetails>

Output only. Map containing the points of contact for the given finding. The key represents the type of contact, while the value contains a list of all the contacts that pertain. Please refer to: https://cloud.google.com/resource- manager/docs/managing-notification-contacts#notification-categories " security": "contacts": [ "email": "person1@company.com", "email": " person2@company.com" ] Corresponds to the JSON property contacts



7286
7287
7288
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7286

def contacts
  @contacts
end

#containersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Container>

Containers associated with the finding. This field provides information for both Kubernetes and non-Kubernetes containers. Corresponds to the JSON property containers



7292
7293
7294
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7292

def containers
  @containers
end

#create_timeString

Output only. The time at which the finding was created in Security Command Center. Corresponds to the JSON property createTime

Returns:

  • (String)


7298
7299
7300
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7298

def create_time
  @create_time
end

#crypto_key_nameString

Output only. The name of the Cloud KMS key used to encrypt this finding, if any. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


7304
7305
7306
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7304

def crypto_key_name
  @crypto_key_name
end

#data_access_eventsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataAccessEvent>

Data access events associated with the finding. Corresponds to the JSON property dataAccessEvents



7309
7310
7311
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7309

def data_access_events
  @data_access_events
end

#data_flow_eventsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataFlowEvent>

Data flow events associated with the finding. Corresponds to the JSON property dataFlowEvents



7314
7315
7316
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7314

def data_flow_events
  @data_flow_events
end

#data_retention_deletion_eventsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent>

Data retention deletion events associated with the finding. Corresponds to the JSON property dataRetentionDeletionEvents



7319
7320
7321
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7319

def data_retention_deletion_events
  @data_retention_deletion_events
end

#databaseGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Database

Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided. Corresponds to the JSON property database



7330
7331
7332
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7330

def database
  @database
end

#descriptionString

Contains more details about the finding. Corresponds to the JSON property description

Returns:

  • (String)


7335
7336
7337
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7335

def description
  @description
end

#diskGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Disk

Contains information about the disk associated with the finding. Corresponds to the JSON property disk



7340
7341
7342
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7340

def disk
  @disk
end

#event_timeString

The time the finding was first detected. If an existing finding is updated, then this is the time the update occurred. For example, if the finding represents an open firewall, this property captures the time the detector believes the firewall became open. The accuracy is determined by the detector. If the finding is later resolved, then this time reflects when the finding was resolved. This must not be set to a value greater than the current timestamp. Corresponds to the JSON property eventTime

Returns:

  • (String)


7350
7351
7352
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7350

def event_time
  @event_time
end

#exfiltrationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Exfiltration

Exfiltration represents a data exfiltration attempt from one or more sources to one or more targets. The sources attribute lists the sources of the exfiltrated data. The targets attribute lists the destinations the data was copied to. Corresponds to the JSON property exfiltration



7358
7359
7360
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7358

def exfiltration
  @exfiltration
end

#external_systemsHash<String,Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ExternalSystem>

Output only. Third party SIEM/SOAR fields within SCC, contains external system information and external system finding fields. Corresponds to the JSON property externalSystems



7364
7365
7366
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7364

def external_systems
  @external_systems
end

#external_uriString

The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found. This field is guaranteed to be either empty or a well formed URL. Corresponds to the JSON property externalUri

Returns:

  • (String)


7371
7372
7373
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7371

def external_uri
  @external_uri
end

#filesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File>

File associated with the finding. Corresponds to the JSON property files



7376
7377
7378
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7376

def files
  @files
end

#finding_classString

The class of the finding. Corresponds to the JSON property findingClass

Returns:

  • (String)


7381
7382
7383
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7381

def finding_class
  @finding_class
end

#group_membershipsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2GroupMembership>

Contains details about groups of which this finding is a member. A group is a collection of findings that are related in some way. This field cannot be updated. Its value is ignored in all update requests. Corresponds to the JSON property groupMemberships



7388
7389
7390
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7388

def group_memberships
  @group_memberships
end

#iam_bindingsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IamBinding>

Represents IAM bindings associated with the finding. Corresponds to the JSON property iamBindings



7393
7394
7395
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7393

def iam_bindings
  @iam_bindings
end

#indicatorGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Indicator

Represents what's commonly known as an indicator of compromise (IoC) in computer forensics. This is an artifact observed on a network or in an operating system that, with high confidence, indicates a computer intrusion. For more information, see Indicator of compromise. Corresponds to the JSON property indicator



7402
7403
7404
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7402

def indicator
  @indicator
end

#ip_rulesGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IpRules

IP rules associated with the finding. Corresponds to the JSON property ipRules



7407
7408
7409
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7407

def ip_rules
  @ip_rules
end

#jobGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Job

Describes a job Corresponds to the JSON property job



7412
7413
7414
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7412

def job
  @job
end

#kernel_rootkitGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2KernelRootkit

Kernel mode rootkit signatures. Corresponds to the JSON property kernelRootkit



7417
7418
7419
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7417

def kernel_rootkit
  @kernel_rootkit
end

#kubernetesGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Kubernetes

Kubernetes-related attributes. Corresponds to the JSON property kubernetes



7422
7423
7424
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7422

def kubernetes
  @kubernetes
end

#load_balancersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2LoadBalancer>

The load balancers associated with the finding. Corresponds to the JSON property loadBalancers



7427
7428
7429
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7427

def load_balancers
  @load_balancers
end

#log_entriesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2LogEntry>

Log entries that are relevant to the finding. Corresponds to the JSON property logEntries



7432
7433
7434
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7432

def log_entries
  @log_entries
end

#mitre_attackGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2MitreAttack

MITRE ATT&CK tactics and techniques related to this finding. See: https:// attack.mitre.org Corresponds to the JSON property mitreAttack



7438
7439
7440
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7438

def mitre_attack
  @mitre_attack
end

#module_nameString

Unique identifier of the module which generated the finding. Example: folders/ 598186756061/securityHealthAnalyticsSettings/customModules/56799441161885 Corresponds to the JSON property moduleName

Returns:

  • (String)


7444
7445
7446
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7444

def module_name
  @module_name
end

#muteString

Indicates the mute state of a finding (either muted, unmuted or undefined). Unlike other attributes of a finding, a finding provider shouldn't set the value of mute. Corresponds to the JSON property mute

Returns:

  • (String)


7451
7452
7453
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7451

def mute
  @mute
end

#mute_infoGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2MuteInfo

Mute information about the finding, including whether the finding has a static mute or any matching dynamic mute rules. Corresponds to the JSON property muteInfo



7457
7458
7459
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7457

def mute_info
  @mute_info
end

#mute_initiatorString

Records additional information about the mute operation, for example, the mute configuration that muted the finding and the user who muted the finding. Corresponds to the JSON property muteInitiator

Returns:

  • (String)


7464
7465
7466
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7464

def mute_initiator
  @mute_initiator
end

#mute_update_timeString

Output only. The most recent time this finding was muted or unmuted. Corresponds to the JSON property muteUpdateTime

Returns:

  • (String)


7469
7470
7471
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7469

def mute_update_time
  @mute_update_time
end

#nameString

Identifier. The relative resource name of the finding. The following list shows some examples: + organizations/organization_id/sources/source_id/ findings/finding_id+ `organizations/`organization_id`/sources/`source_id`/ locations/`location_id`/findings/`finding_id + folders/folder_id/sources/ source_id/findings/finding_id+ `folders/`folder_id`/sources/`source_id`/ locations/`location_id`/findings/`finding_id + projects/project_id/ sources/source_id/findings/finding_id+ `projects/`project_id`/sources/` source_id`/locations/`location_id`/findings/`finding_id Corresponds to the JSON property name

Returns:

  • (String)


7482
7483
7484
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7482

def name
  @name
end

#networksArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Network>

Represents the VPC networks that the resource is attached to. Corresponds to the JSON property networks



7487
7488
7489
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7487

def networks
  @networks
end

#next_stepsString

Steps to address the finding. Corresponds to the JSON property nextSteps

Returns:

  • (String)


7492
7493
7494
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7492

def next_steps
  @next_steps
end

#notebookGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Notebook

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding. Corresponds to the JSON property notebook



7499
7500
7501
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7499

def notebook
  @notebook
end

#org_policiesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2OrgPolicy>

Contains information about the org policies associated with the finding. Corresponds to the JSON property orgPolicies



7504
7505
7506
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7504

def org_policies
  @org_policies
end

#parentString

The relative resource name of the source and location the finding belongs to. See: https://cloud.google.com/apis/design/resource_names# relative_resource_name This field is immutable after creation time. The following list shows some examples: + organizations/organization_id/sources/ source_id+ `folders/`folders_id`/sources/`source_id + projects/ projects_id/sources/source_id+ `organizations/`organization_id`/sources/` source_id`/locations/`location_id + folders/folders_id/sources/source_id /locations/location_id+ `projects/`projects_id`/sources/`source_id`/ locations/`location_id Corresponds to the JSON property parent

Returns:

  • (String)


7517
7518
7519
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7517

def parent
  @parent
end

#parent_display_nameString

Output only. The human readable display name of the finding source such as " Event Threat Detection" or "Security Health Analytics". Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


7523
7524
7525
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7523

def parent_display_name
  @parent_display_name
end

#processesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Process>

Represents operating system processes associated with the Finding. Corresponds to the JSON property processes



7528
7529
7530
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7528

def processes
  @processes
end

#resource_nameString

Immutable. For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for. See: https://cloud.google.com/ apis/design/resource_names#full_resource_name When the finding is for a non- Google Cloud resource, the resourceName can be a customer or partner defined string. Corresponds to the JSON property resourceName

Returns:

  • (String)


7537
7538
7539
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7537

def resource_name
  @resource_name
end

#secretGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Secret

Details about a secret or credential associated with the finding. Corresponds to the JSON property secret



7542
7543
7544
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7542

def secret
  @secret
end

#security_marksGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SecurityMarks

User specified security marks that are attached to the parent Security Command Center resource. Security marks are scoped within a Security Command Center organization -- they can be modified and viewed by all users who have proper permissions on the organization. Corresponds to the JSON property securityMarks



7550
7551
7552
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7550

def security_marks
  @security_marks
end

#security_postureGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2SecurityPosture

Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud. Corresponds to the JSON property securityPosture



7558
7559
7560
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7558

def security_posture
  @security_posture
end

#severityString

The severity of the finding. This field is managed by the source that writes the finding. Corresponds to the JSON property severity

Returns:

  • (String)


7564
7565
7566
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7564

def severity
  @severity
end

#source_propertiesHash<String,Object>

Source specific properties. These properties are managed by the source that writes the finding. The key names in the source_properties map must be between 1 and 255 characters, and must start with a letter and contain alphanumeric characters or underscores only. Corresponds to the JSON property sourceProperties

Returns:



7572
7573
7574
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7572

def source_properties
  @source_properties
end

#stateString

Output only. The state of the finding. Corresponds to the JSON property state

Returns:

  • (String)


7577
7578
7579
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7577

def state
  @state
end

#toxic_combinationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ToxicCombination

Contains details about a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently. A group of such issues is referred to as a toxic combination. Corresponds to the JSON property toxicCombination



7584
7585
7586
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7584

def toxic_combination
  @toxic_combination
end

#vertex_aiGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2VertexAi

Vertex AI-related information associated with the finding. Corresponds to the JSON property vertexAi



7589
7590
7591
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7589

def vertex_ai
  @vertex_ai
end

#vulnerabilityGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Vulnerability

Refers to common vulnerability fields e.g. cve, cvss, cwe etc. Corresponds to the JSON property vulnerability



7594
7595
7596
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7594

def vulnerability
  @vulnerability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
7622
7623
7624
7625
7626
7627
7628
7629
7630
7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
7641
7642
7643
7644
7645
7646
7647
7648
7649
7650
7651
7652
7653
7654
7655
7656
7657
7658
7659
7660
7661
7662
7663
7664
7665
7666
7667
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7601

def update!(**args)
  @access = args[:access] if args.key?(:access)
  @affected_resources = args[:affected_resources] if args.key?(:affected_resources)
  @ai_model = args[:ai_model] if args.key?(:ai_model)
  @application = args[:application] if args.key?(:application)
  @artifact_guard_policies = args[:artifact_guard_policies] if args.key?(:artifact_guard_policies)
  @attack_exposure = args[:attack_exposure] if args.key?(:attack_exposure)
  @backup_disaster_recovery = args[:backup_disaster_recovery] if args.key?(:backup_disaster_recovery)
  @canonical_name = args[:canonical_name] if args.key?(:canonical_name)
  @category = args[:category] if args.key?(:category)
  @chokepoint = args[:chokepoint] if args.key?(:chokepoint)
  @cloud_armor = args[:cloud_armor] if args.key?(:cloud_armor)
  @cloud_dlp_data_profile = args[:cloud_dlp_data_profile] if args.key?(:cloud_dlp_data_profile)
  @cloud_dlp_inspection = args[:cloud_dlp_inspection] if args.key?(:cloud_dlp_inspection)
  @compliance_details = args[:compliance_details] if args.key?(:compliance_details)
  @compliances = args[:compliances] if args.key?(:compliances)
  @connections = args[:connections] if args.key?(:connections)
  @contacts = args[:contacts] if args.key?(:contacts)
  @containers = args[:containers] if args.key?(:containers)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @data_access_events = args[:data_access_events] if args.key?(:data_access_events)
  @data_flow_events = args[:data_flow_events] if args.key?(:data_flow_events)
  @data_retention_deletion_events = args[:data_retention_deletion_events] if args.key?(:data_retention_deletion_events)
  @database = args[:database] if args.key?(:database)
  @description = args[:description] if args.key?(:description)
  @disk = args[:disk] if args.key?(:disk)
  @event_time = args[:event_time] if args.key?(:event_time)
  @exfiltration = args[:exfiltration] if args.key?(:exfiltration)
  @external_systems = args[:external_systems] if args.key?(:external_systems)
  @external_uri = args[:external_uri] if args.key?(:external_uri)
  @files = args[:files] if args.key?(:files)
  @finding_class = args[:finding_class] if args.key?(:finding_class)
  @group_memberships = args[:group_memberships] if args.key?(:group_memberships)
  @iam_bindings = args[:iam_bindings] if args.key?(:iam_bindings)
  @indicator = args[:indicator] if args.key?(:indicator)
  @ip_rules = args[:ip_rules] if args.key?(:ip_rules)
  @job = args[:job] if args.key?(:job)
  @kernel_rootkit = args[:kernel_rootkit] if args.key?(:kernel_rootkit)
  @kubernetes = args[:kubernetes] if args.key?(:kubernetes)
  @load_balancers = args[:load_balancers] if args.key?(:load_balancers)
  @log_entries = args[:log_entries] if args.key?(:log_entries)
  @mitre_attack = args[:mitre_attack] if args.key?(:mitre_attack)
  @module_name = args[:module_name] if args.key?(:module_name)
  @mute = args[:mute] if args.key?(:mute)
  @mute_info = args[:mute_info] if args.key?(:mute_info)
  @mute_initiator = args[:mute_initiator] if args.key?(:mute_initiator)
  @mute_update_time = args[:mute_update_time] if args.key?(:mute_update_time)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @next_steps = args[:next_steps] if args.key?(:next_steps)
  @notebook = args[:notebook] if args.key?(:notebook)
  @org_policies = args[:org_policies] if args.key?(:org_policies)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @processes = args[:processes] if args.key?(:processes)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @secret = args[:secret] if args.key?(:secret)
  @security_marks = args[:security_marks] if args.key?(:security_marks)
  @security_posture = args[:security_posture] if args.key?(:security_posture)
  @severity = args[:severity] if args.key?(:severity)
  @source_properties = args[:source_properties] if args.key?(:source_properties)
  @state = args[:state] if args.key?(:state)
  @toxic_combination = args[:toxic_combination] if args.key?(:toxic_combination)
  @vertex_ai = args[:vertex_ai] if args.key?(:vertex_ai)
  @vulnerability = args[:vulnerability] if args.key?(:vulnerability)
end