Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Framework
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Framework
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Compliance framework associated with the finding.
Instance Attribute Summary collapse
-
#category ⇒ Array<String>
Category of the framework associated with the finding.
-
#controls ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Control>
The controls associated with the framework.
-
#display_name ⇒ String
Display name of the framework.
-
#name ⇒ String
Name of the framework associated with the finding Corresponds to the JSON property
name. -
#type ⇒ String
Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Framework
constructor
A new instance of GoogleCloudSecuritycenterV2Framework.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Framework
Returns a new instance of GoogleCloudSecuritycenterV2Framework.
7730 7731 7732 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Array<String>
Category of the framework associated with the finding. E.g. Security Benchmark,
or Assured Workloads
Corresponds to the JSON property category
7704 7705 7706 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7704 def category @category end |
#controls ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Control>
The controls associated with the framework.
Corresponds to the JSON property controls
7709 7710 7711 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7709 def controls @controls end |
#display_name ⇒ String
Display name of the framework. For a standard framework, this will look like e.
g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined
string like MyFramework
Corresponds to the JSON property displayName
7716 7717 7718 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7716 def display_name @display_name end |
#name ⇒ String
Name of the framework associated with the finding
Corresponds to the JSON property name
7721 7722 7723 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7721 def name @name end |
#type ⇒ String
Type of the framework associated with the finding, to specify whether the
framework is built-in (pre-defined and immutable) or a custom framework
defined by the customer (equivalent to security posture)
Corresponds to the JSON property type
7728 7729 7730 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7728 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7735 7736 7737 7738 7739 7740 7741 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7735 def update!(**args) @category = args[:category] if args.key?(:category) @controls = args[:controls] if args.key?(:controls) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |