Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2HttpResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2HttpResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
The http response returned by the web application.
Instance Attribute Summary collapse
-
#path ⇒ String
The http path for which response code was returned by web application, for example, "https://test-app.a.run.app/test".
-
#status_code ⇒ String
The http response code returned by the web application, for example, 200.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2HttpResponse
constructor
A new instance of GoogleCloudSecuritycenterV2HttpResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2HttpResponse
Returns a new instance of GoogleCloudSecuritycenterV2HttpResponse.
8516 8517 8518 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#path ⇒ String
The http path for which response code was returned by web application, for
example, "https://test-app.a.run.app/test".
Corresponds to the JSON property path
8509 8510 8511 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8509 def path @path end |
#status_code ⇒ String
The http response code returned by the web application, for example, 200.
Corresponds to the JSON property statusCode
8514 8515 8516 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8514 def status_code @status_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8521 8522 8523 8524 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8521 def update!(**args) @path = args[:path] if args.key?(:path) @status_code = args[:status_code] if args.key?(:status_code) end |