Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IpRule
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IpRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
IP rule information.
Instance Attribute Summary collapse
-
#port_ranges ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PortRange>
Optional.
-
#protocol ⇒ String
The IP protocol this rule applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IpRule
constructor
A new instance of GoogleCloudSecuritycenterV2IpRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IpRule
Returns a new instance of GoogleCloudSecuritycenterV2IpRule.
7919 7920 7921 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port_ranges ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PortRange>
Optional. An optional list of ports to which this rule applies. This field is
only applicable for the UDP or (S)TCP protocols. Each entry must be either an
integer or a range including a min and max port number.
Corresponds to the JSON property portRanges
7910 7911 7912 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7910 def port_ranges @port_ranges end |
#protocol ⇒ String
The IP protocol this rule applies to. This value can either be one of the
following well known protocol strings (TCP, UDP, ICMP, ESP, AH, IPIP, SCTP) or
a string representation of the integer value.
Corresponds to the JSON property protocol
7917 7918 7919 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7917 def protocol @protocol end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7924 7925 7926 7927 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 7924 def update!(**args) @port_ranges = args[:port_ranges] if args.key?(:port_ranges) @protocol = args[:protocol] if args.key?(:protocol) end |