Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A resource associated with the an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource

Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.



8880
8881
8882
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8880

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



8827
8828
8829
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8827

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



8832
8833
8834
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8832

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



8837
8838
8839
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8837

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplication

The AppHub application associated with the resource, if any. Corresponds to the JSON property application



8842
8843
8844
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8842

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

The AWS metadata of a resource associated with an issue. Corresponds to the JSON property awsMetadata



8847
8848
8849
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8847

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata

The Azure metadata of a resource associated with an issue. Corresponds to the JSON property azureMetadata



8852
8853
8854
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8852

def 
  @azure_metadata
end

#cloud_providerString

The cloud provider of the resource associated with the issue. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


8857
8858
8859
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8857

def cloud_provider
  @cloud_provider
end

#display_nameString

The resource-type specific display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


8863
8864
8865
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8863

def display_name
  @display_name
end

#google_cloud_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata

Google Cloud metadata of a resource associated with an issue. Corresponds to the JSON property googleCloudMetadata



8868
8869
8870
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8868

def 
  @google_cloud_metadata
end

#nameString

The full resource name of the resource associated with the issue. Corresponds to the JSON property name

Returns:

  • (String)


8873
8874
8875
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8873

def name
  @name
end

#typeString

The type of the resource associated with the issue. Corresponds to the JSON property type

Returns:

  • (String)


8878
8879
8880
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8878

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8885
8886
8887
8888
8889
8890
8891
8892
8893
8894
8895
8896
8897
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8885

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end