Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A resource associated with the an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource

Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.



8271
8272
8273
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplication

The AppHub application associated with the resource, if any. Corresponds to the JSON property application



8233
8234
8235
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8233

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

The AWS metadata of a resource associated with an issue. Corresponds to the JSON property awsMetadata



8238
8239
8240
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8238

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata

The Azure metadata of a resource associated with an issue. Corresponds to the JSON property azureMetadata



8243
8244
8245
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8243

def 
  @azure_metadata
end

#cloud_providerString

The cloud provider of the resource associated with the issue. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


8248
8249
8250
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8248

def cloud_provider
  @cloud_provider
end

#display_nameString

The resource-type specific display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


8254
8255
8256
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8254

def display_name
  @display_name
end

#google_cloud_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata

Google Cloud metadata of a resource associated with an issue. Corresponds to the JSON property googleCloudMetadata



8259
8260
8261
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8259

def 
  @google_cloud_metadata
end

#nameString

The full resource name of the resource associated with the issue. Corresponds to the JSON property name

Returns:

  • (String)


8264
8265
8266
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8264

def name
  @name
end

#typeString

The type of the resource associated with the issue. Corresponds to the JSON property type

Returns:

  • (String)


8269
8270
8271
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8269

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8276
8277
8278
8279
8280
8281
8282
8283
8284
8285
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8276

def update!(**args)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end