Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes.



9023
9024
9025
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



9001
9002
9003
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9001

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



9006
9007
9008
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9006

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



9011
9012
9013
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9011

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



9016
9017
9018
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9016

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



9021
9022
9023
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9021

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9028
9029
9030
9031
9032
9033
9034
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9028

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end