Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes.



8343
8344
8345
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



8321
8322
8323
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8321

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



8326
8327
8328
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8326

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



8331
8332
8333
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8331

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



8336
8337
8338
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8336

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



8341
8342
8343
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8341

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8348
8349
8350
8351
8352
8353
8354
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8348

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end