Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Job
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Describes a job
Instance Attribute Summary collapse
-
#error_code ⇒ Fixnum
Optional.
-
#location ⇒ String
Optional.
-
#name ⇒ String
The fully-qualified name for a job.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
constructor
A new instance of GoogleCloudSecuritycenterV2Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
Returns a new instance of GoogleCloudSecuritycenterV2Job.
8620 8621 8622 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8620 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ Fixnum
Optional. If the job did not complete successfully, this field describes why.
Corresponds to the JSON property errorCode
8603 8604 8605 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8603 def error_code @error_code end |
#location ⇒ String
Optional. Gives the location where the job ran, such as US or europe-west1
Corresponds to the JSON property location
8608 8609 8610 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8608 def location @location end |
#name ⇒ String
The fully-qualified name for a job. e.g. projects//jobs/
Corresponds to the JSON property name
8613 8614 8615 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8613 def name @name end |
#state ⇒ String
Output only. State of the job, such as RUNNING or PENDING.
Corresponds to the JSON property state
8618 8619 8620 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8618 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8625 8626 8627 8628 8629 8630 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8625 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |