Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Kubernetes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Kubernetes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Kubernetes-related attributes.
Instance Attribute Summary collapse
-
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview>
Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding.
-
#bindings ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Binding>
Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings.
-
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2NodePool>
GKE node pools associated with the finding.
-
#nodes ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Node>
Provides Kubernetes node information.
-
#objects ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Object>
Kubernetes objects related to the finding.
-
#pods ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Pod>
Kubernetes Pods associated with the finding.
-
#roles ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Role>
Provides Kubernetes role information for findings that involve Roles or ClusterRoles.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes
constructor
A new instance of GoogleCloudSecuritycenterV2Kubernetes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes
Returns a new instance of GoogleCloudSecuritycenterV2Kubernetes.
9443 9444 9445 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview>
Provides information on any Kubernetes access reviews (privilege checks)
relevant to the finding.
Corresponds to the JSON property accessReviews
9402 9403 9404 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9402 def access_reviews @access_reviews end |
#bindings ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Binding>
Provides Kubernetes role binding information for findings that involve
RoleBindings or ClusterRoleBindings.
Corresponds to the JSON property bindings
9409 9410 9411 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9409 def bindings @bindings end |
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2NodePool>
GKE node pools associated with the finding. This field contains node pool information
for each node, when it is available.
Corresponds to the JSON property nodePools
9416 9417 9418 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9416 def node_pools @node_pools end |
#nodes ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Node>
Provides Kubernetes node information.
Corresponds to the JSON property nodes
9422 9423 9424 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9422 def nodes @nodes end |
#objects ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Object>
Kubernetes objects related to the finding.
Corresponds to the JSON property objects
9427 9428 9429 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9427 def objects @objects end |
#pods ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Pod>
Kubernetes Pods
associated with the finding. This field contains Pod records for each
container that is owned by a Pod.
Corresponds to the JSON property pods
9434 9435 9436 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9434 def pods @pods end |
#roles ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Role>
Provides Kubernetes role information for findings that involve Roles or
ClusterRoles.
Corresponds to the JSON property roles
9441 9442 9443 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9441 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9448 9449 9450 9451 9452 9453 9454 9455 9456 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9448 def update!(**args) @access_reviews = args[:access_reviews] if args.key?(:access_reviews) @bindings = args[:bindings] if args.key?(:bindings) @node_pools = args[:node_pools] if args.key?(:node_pools) @nodes = args[:nodes] if args.key?(:nodes) @objects = args[:objects] if args.key?(:objects) @pods = args[:pods] if args.key?(:pods) @roles = args[:roles] if args.key?(:roles) end |