Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Kubernetes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Kubernetes-related attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes

Returns a new instance of GoogleCloudSecuritycenterV2Kubernetes.



8763
8764
8765
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reviewsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AccessReview>

Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding. Corresponds to the JSON property accessReviews



8722
8723
8724
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8722

def access_reviews
  @access_reviews
end

#bindingsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Binding>

Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings. Corresponds to the JSON property bindings



8729
8730
8731
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8729

def bindings
  @bindings
end

#node_poolsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2NodePool>

GKE node pools associated with the finding. This field contains node pool information for each node, when it is available. Corresponds to the JSON property nodePools



8736
8737
8738
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8736

def node_pools
  @node_pools
end

#nodesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Node>

Provides Kubernetes node information. Corresponds to the JSON property nodes



8742
8743
8744
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8742

def nodes
  @nodes
end

#objectsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Object>

Kubernetes objects related to the finding. Corresponds to the JSON property objects



8747
8748
8749
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8747

def objects
  @objects
end

#podsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Pod>

Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod. Corresponds to the JSON property pods



8754
8755
8756
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8754

def pods
  @pods
end

#rolesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Role>

Provides Kubernetes role information for findings that involve Roles or ClusterRoles. Corresponds to the JSON property roles



8761
8762
8763
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8761

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8768
8769
8770
8771
8772
8773
8774
8775
8776
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 8768

def update!(**args)
  @access_reviews = args[:access_reviews] if args.key?(:access_reviews)
  @bindings = args[:bindings] if args.key?(:bindings)
  @node_pools = args[:node_pools] if args.key?(:node_pools)
  @nodes = args[:nodes] if args.key?(:nodes)
  @objects = args[:objects] if args.key?(:objects)
  @pods = args[:pods] if args.key?(:pods)
  @roles = args[:roles] if args.key?(:roles)
end