Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Notebook
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
Instance Attribute Summary collapse
-
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
-
#name ⇒ String
The name of the notebook.
-
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
-
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook
constructor
A new instance of GoogleCloudSecuritycenterV2Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook
Returns a new instance of GoogleCloudSecuritycenterV2Notebook.
9813 9814 9815 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
Corresponds to the JSON property lastAuthor
9796 9797 9798 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9796 def @last_author end |
#name ⇒ String
The name of the notebook.
Corresponds to the JSON property name
9801 9802 9803 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9801 def name @name end |
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
Corresponds to the JSON property notebookUpdateTime
9806 9807 9808 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9806 def notebook_update_time @notebook_update_time end |
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Corresponds to the JSON property service
9811 9812 9813 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9811 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9818 9819 9820 9821 9822 9823 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9818 def update!(**args) @last_author = args[:last_author] if args.key?(:last_author) @name = args[:name] if args.key?(:name) @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time) @service = args[:service] if args.key?(:service) end |