Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Package

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Package is a generic definition of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Package

Returns a new instance of GoogleCloudSecuritycenterV2Package.



9272
9273
9274
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpe_uriString

The CPE URI where the vulnerability was detected. Corresponds to the JSON property cpeUri

Returns:

  • (String)


9255
9256
9257
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9255

def cpe_uri
  @cpe_uri
end

#package_nameString

The name of the package where the vulnerability was detected. Corresponds to the JSON property packageName

Returns:

  • (String)


9260
9261
9262
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9260

def package_name
  @package_name
end

#package_typeString

Type of package, for example, os, maven, or go. Corresponds to the JSON property packageType

Returns:

  • (String)


9265
9266
9267
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9265

def package_type
  @package_type
end

#package_versionString

The version of the package. Corresponds to the JSON property packageVersion

Returns:

  • (String)


9270
9271
9272
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9270

def package_version
  @package_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9277
9278
9279
9280
9281
9282
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9277

def update!(**args)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @package_name = args[:package_name] if args.key?(:package_name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @package_version = args[:package_version] if args.key?(:package_version)
end