Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PolicyViolationSummary
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PolicyViolationSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Metadata summarizing policy violations of child resources of the affected
resource. finding_category and resource determine the exact semantics of
the counts. For example, when category=
DATA_SECURITY_POSTURE_OBJECT_PUBLIC_ACCESS_VIOLATION and resource='storage.
googleapis.com/buckets/my-bucket-name' then this counts the number of Cloud
Storage objects in my-bucket-name which violate a Public Access control.
Instance Attribute Summary collapse
-
#conformant_resources_count ⇒ Fixnum
Total number of child resources that conform to the policy.
-
#evaluation_errors_count ⇒ Fixnum
Number of child resources for which errors during evaluation occurred.
-
#out_of_scope_resources_count ⇒ Fixnum
Total count of child resources which were not in scope for evaluation.
-
#policy_violations_count ⇒ Fixnum
Count of child resources in violation of the policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PolicyViolationSummary
constructor
A new instance of GoogleCloudSecuritycenterV2PolicyViolationSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PolicyViolationSummary
Returns a new instance of GoogleCloudSecuritycenterV2PolicyViolationSummary.
10093 10094 10095 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conformant_resources_count ⇒ Fixnum
Total number of child resources that conform to the policy.
Corresponds to the JSON property conformantResourcesCount
10075 10076 10077 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10075 def conformant_resources_count @conformant_resources_count end |
#evaluation_errors_count ⇒ Fixnum
Number of child resources for which errors during evaluation occurred. The
evaluation result for these child resources is effectively "unknown".
Corresponds to the JSON property evaluationErrorsCount
10081 10082 10083 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10081 def evaluation_errors_count @evaluation_errors_count end |
#out_of_scope_resources_count ⇒ Fixnum
Total count of child resources which were not in scope for evaluation.
Corresponds to the JSON property outOfScopeResourcesCount
10086 10087 10088 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10086 def out_of_scope_resources_count @out_of_scope_resources_count end |
#policy_violations_count ⇒ Fixnum
Count of child resources in violation of the policy.
Corresponds to the JSON property policyViolationsCount
10091 10092 10093 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10091 def policy_violations_count @policy_violations_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10098 10099 10100 10101 10102 10103 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10098 def update!(**args) @conformant_resources_count = args[:conformant_resources_count] if args.key?(:conformant_resources_count) @evaluation_errors_count = args[:evaluation_errors_count] if args.key?(:evaluation_errors_count) @out_of_scope_resources_count = args[:out_of_scope_resources_count] if args.key?(:out_of_scope_resources_count) @policy_violations_count = args[:policy_violations_count] if args.key?(:policy_violations_count) end |