Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PortRange
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2PortRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
A port range which is inclusive of the min and max values. Values are between 0 and 2^16-1. The max can be equal / must be not smaller than the min value. If min and max are equal this indicates that it is a single port.
Instance Attribute Summary collapse
-
#max ⇒ Fixnum
Maximum port value.
-
#min ⇒ Fixnum
Minimum port value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PortRange
constructor
A new instance of GoogleCloudSecuritycenterV2PortRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PortRange
Returns a new instance of GoogleCloudSecuritycenterV2PortRange.
9399 9400 9401 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max ⇒ Fixnum
Maximum port value.
Corresponds to the JSON property max
9392 9393 9394 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9392 def max @max end |
#min ⇒ Fixnum
Minimum port value.
Corresponds to the JSON property min
9397 9398 9399 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9397 def min @min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9404 9405 9406 9407 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9404 def update!(**args) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) end |