Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Process
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Process
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Represents an operating system process.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
-
#arguments_truncated ⇒ Boolean
(also: #arguments_truncated?)
True if
argsis incomplete. -
#binary ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
binary. -
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2EnvironmentVariable>
Process environment variables.
-
#env_variables_truncated ⇒ Boolean
(also: #env_variables_truncated?)
True if
env_variablesis incomplete. -
#libraries ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File>
File information for libraries loaded by the process.
-
#name ⇒ String
The process name, as displayed in utilities like
topandps. -
#parent_pid ⇒ Fixnum
The parent process ID.
-
#pid ⇒ Fixnum
The process ID.
-
#script ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
script. -
#user_id ⇒ Fixnum
The ID of the user that executed the process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process
constructor
A new instance of GoogleCloudSecuritycenterV2Process.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process
Returns a new instance of GoogleCloudSecuritycenterV2Process.
10198 10199 10200 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
Corresponds to the JSON property args
10140 10141 10142 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10140 def args @args end |
#arguments_truncated ⇒ Boolean Also known as: arguments_truncated?
True if args is incomplete.
Corresponds to the JSON property argumentsTruncated
10145 10146 10147 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10145 def arguments_truncated @arguments_truncated end |
#binary ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property binary
10152 10153 10154 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10152 def binary @binary end |
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2EnvironmentVariable>
Process environment variables.
Corresponds to the JSON property envVariables
10157 10158 10159 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10157 def env_variables @env_variables end |
#env_variables_truncated ⇒ Boolean Also known as: env_variables_truncated?
True if env_variables is incomplete.
Corresponds to the JSON property envVariablesTruncated
10162 10163 10164 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10162 def env_variables_truncated @env_variables_truncated end |
#libraries ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File>
File information for libraries loaded by the process.
Corresponds to the JSON property libraries
10168 10169 10170 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10168 def libraries @libraries end |
#name ⇒ String
The process name, as displayed in utilities like top and ps. This name can
be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME).
Corresponds to the JSON property name
10174 10175 10176 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10174 def name @name end |
#parent_pid ⇒ Fixnum
The parent process ID.
Corresponds to the JSON property parentPid
10179 10180 10181 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10179 def parent_pid @parent_pid end |
#pid ⇒ Fixnum
The process ID.
Corresponds to the JSON property pid
10184 10185 10186 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10184 def pid @pid end |
#script ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property script
10190 10191 10192 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10190 def script @script end |
#user_id ⇒ Fixnum
The ID of the user that executed the process. E.g. If this is the root user
this will always be 0.
Corresponds to the JSON property userId
10196 10197 10198 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10196 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10203 10204 10205 10206 10207 10208 10209 10210 10211 10212 10213 10214 10215 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10203 def update!(**args) @args = args[:args] if args.key?(:args) @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated) @binary = args[:binary] if args.key?(:binary) @env_variables = args[:env_variables] if args.key?(:env_variables) @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated) @libraries = args[:libraries] if args.key?(:libraries) @name = args[:name] if args.key?(:name) @parent_pid = args[:parent_pid] if args.key?(:parent_pid) @pid = args[:pid] if args.key?(:pid) @script = args[:script] if args.key?(:script) @user_id = args[:user_id] if args.key?(:user_id) end |