Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Process

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Represents an operating system process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process

Returns a new instance of GoogleCloudSecuritycenterV2Process.



9475
9476
9477
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Process arguments as JSON encoded strings. Corresponds to the JSON property args

Returns:

  • (Array<String>)


9417
9418
9419
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9417

def args
  @args
end

#arguments_truncatedBoolean Also known as: arguments_truncated?

True if args is incomplete. Corresponds to the JSON property argumentsTruncated

Returns:

  • (Boolean)


9422
9423
9424
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9422

def arguments_truncated
  @arguments_truncated
end

#binaryGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property binary



9429
9430
9431
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9429

def binary
  @binary
end

#env_variablesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2EnvironmentVariable>

Process environment variables. Corresponds to the JSON property envVariables



9434
9435
9436
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9434

def env_variables
  @env_variables
end

#env_variables_truncatedBoolean Also known as: env_variables_truncated?

True if env_variables is incomplete. Corresponds to the JSON property envVariablesTruncated

Returns:

  • (Boolean)


9439
9440
9441
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9439

def env_variables_truncated
  @env_variables_truncated
end

#librariesArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File>

File information for libraries loaded by the process. Corresponds to the JSON property libraries



9445
9446
9447
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9445

def libraries
  @libraries
end

#nameString

The process name, as displayed in utilities like top and ps. This name can be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME). Corresponds to the JSON property name

Returns:

  • (String)


9451
9452
9453
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9451

def name
  @name
end

#parent_pidFixnum

The parent process ID. Corresponds to the JSON property parentPid

Returns:

  • (Fixnum)


9456
9457
9458
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9456

def parent_pid
  @parent_pid
end

#pidFixnum

The process ID. Corresponds to the JSON property pid

Returns:

  • (Fixnum)


9461
9462
9463
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9461

def pid
  @pid
end

#scriptGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2File

File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property script



9467
9468
9469
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9467

def script
  @script
end

#user_idFixnum

The ID of the user that executed the process. E.g. If this is the root user this will always be 0. Corresponds to the JSON property userId

Returns:

  • (Fixnum)


9473
9474
9475
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9473

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9480
9481
9482
9483
9484
9485
9486
9487
9488
9489
9490
9491
9492
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9480

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated)
  @binary = args[:binary] if args.key?(:binary)
  @env_variables = args[:env_variables] if args.key?(:env_variables)
  @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated)
  @libraries = args[:libraries] if args.key?(:libraries)
  @name = args[:name] if args.key?(:name)
  @parent_pid = args[:parent_pid] if args.key?(:parent_pid)
  @pid = args[:pid] if args.key?(:pid)
  @script = args[:script] if args.key?(:script)
  @user_id = args[:user_id] if args.key?(:user_id)
end