Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource

Returns a new instance of GoogleCloudSecuritycenterV2Resource.



10406
10407
10408
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



10321
10322
10323
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10321

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



10326
10327
10328
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10326

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



10331
10332
10333
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10331

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



10336
10337
10338
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10336

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



10342
10343
10344
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10342

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



10348
10349
10350
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10348

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the finding is from. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


10353
10354
10355
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10353

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


10358
10359
10360
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10358

def display_name
  @display_name
end

#gcp_metadataGoogle::Apis::SecuritycenterV1::GcpMetadata

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud. Corresponds to the JSON property gcpMetadata



10364
10365
10366
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10364

def 
  @gcp_metadata
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


10369
10370
10371
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10369

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


10375
10376
10377
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10375

def name
  @name
end

#resource_pathGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



10381
10382
10383
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10381

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


10394
10395
10396
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10394

def resource_path_string
  @resource_path_string
end

#serviceString

The service or resource provider associated with the resource. Corresponds to the JSON property service

Returns:

  • (String)


10399
10400
10401
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10399

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


10404
10405
10406
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10404

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10411
10412
10413
10414
10415
10416
10417
10418
10419
10420
10421
10422
10423
10424
10425
10426
10427
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10411

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end