Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
-
#display_name ⇒ String
The human readable name of the resource.
-
#gcp_metadata ⇒ Google::Apis::SecuritycenterV1::GcpMetadata
Google Cloud metadata associated with the resource.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The service or resource provider associated with the resource.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource
constructor
A new instance of GoogleCloudSecuritycenterV2Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource
Returns a new instance of GoogleCloudSecuritycenterV2Resource.
9668 9669 9670 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
9598 9599 9600 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9598 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
9604 9605 9606 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9604 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
9610 9611 9612 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9610 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
Corresponds to the JSON property cloudProvider
9615 9616 9617 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9615 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
9620 9621 9622 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9620 def display_name @display_name end |
#gcp_metadata ⇒ Google::Apis::SecuritycenterV1::GcpMetadata
Google Cloud metadata associated with the resource. Only applicable if the
finding's cloud provider is Google Cloud.
Corresponds to the JSON property gcpMetadata
9626 9627 9628 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9626 def @gcp_metadata end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
9631 9632 9633 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9631 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
9637 9638 9639 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9637 def name @name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
9643 9644 9645 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9643 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of organizations/organization_id/folders/folder_id/folders/
folder_id/projects/project_idwhere there can be any number of folders.
For AWS, it has the format of `org/`organization_id`/ou/`
organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id
where there can be any number of organizational units. For Azure, it has the
format of mg/management_group_id/mg/management_group_id/subscription/
subscription_id/rg/resource_group_name`where there can be any number of
management groups.
Corresponds to the JSON propertyresourcePathString`
9656 9657 9658 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9656 def resource_path_string @resource_path_string end |
#service ⇒ String
The service or resource provider associated with the resource.
Corresponds to the JSON property service
9661 9662 9663 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9661 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
9666 9667 9668 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9666 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 9684 9685 9686 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9673 def update!(**args) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |