Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Consumer provided attributes for the application
Instance Attribute Summary collapse
-
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered Corresponds to the JSON property
businessOwners. -
#criticality ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload Corresponds to the JSON property
criticality. -
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
-
#environment ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload Corresponds to the JSON property
environment. -
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes
constructor
A new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes
Returns a new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.
10485 10486 10487 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered
Corresponds to the JSON property businessOwners
10463 10464 10465 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10463 def business_owners @business_owners end |
#criticality ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload
Corresponds to the JSON property criticality
10468 10469 10470 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10468 def criticality @criticality end |
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
Corresponds to the JSON property developerOwners
10473 10474 10475 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10473 def developer_owners @developer_owners end |
#environment ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload
Corresponds to the JSON property environment
10478 10479 10480 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10478 def environment @environment end |
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Corresponds to the JSON property operatorOwners
10483 10484 10485 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10483 def operator_owners @operator_owners end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10490 10491 10492 10493 10494 10495 10496 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10490 def update!(**args) @business_owners = args[:business_owners] if args.key?(:business_owners) @criticality = args[:criticality] if args.key?(:criticality) @developer_owners = args[:developer_owners] if args.key?(:developer_owners) @environment = args[:environment] if args.key?(:environment) @operator_owners = args[:operator_owners] if args.key?(:operator_owners) end |