Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.



9744
9745
9746
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



9722
9723
9724
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9722

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



9727
9728
9729
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9727

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



9732
9733
9734
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9732

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



9737
9738
9739
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9737

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



9742
9743
9744
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9742

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9749
9750
9751
9752
9753
9754
9755
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 9749

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end