Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



11199
11200
11201
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


11172
11173
11174
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11172

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


11177
11178
11179
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11177

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


11182
11183
11184
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11182

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


11187
11188
11189
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11187

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


11192
11193
11194
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11192

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


11197
11198
11199
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11197

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11204
11205
11206
11207
11208
11209
11210
11211
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11204

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end