Class: Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



10458
10459
10460
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


10431
10432
10433
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10431

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


10436
10437
10438
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10436

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


10441
10442
10443
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10441

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


10446
10447
10448
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10446

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


10451
10452
10453
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10451

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


10456
10457
10458
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10456

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10463
10464
10465
10466
10467
10468
10469
10470
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 10463

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end