Class: Google::Apis::SecuritycenterV1::IamPolicy
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::IamPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Cloud IAM Policy information associated with the Google Cloud resource described by the Security Command Center asset. This information is managed and defined by the Google Cloud resource and cannot be modified by the user.
Instance Attribute Summary collapse
-
#policy_blob ⇒ String
The JSON representation of the Policy associated with the asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IamPolicy
constructor
A new instance of IamPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IamPolicy
Returns a new instance of IamPolicy.
11737 11738 11739 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#policy_blob ⇒ String
The JSON representation of the Policy associated with the asset. See https://
cloud.google.com/iam/reference/rest/v1/Policy for format details.
Corresponds to the JSON property policyBlob
11735 11736 11737 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11735 def policy_blob @policy_blob end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11742 11743 11744 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11742 def update!(**args) @policy_blob = args[:policy_blob] if args.key?(:policy_blob) end |