Class: Google::Apis::SecuritycenterV1::InfoType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Type of information detected by the API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InfoType

Returns a new instance of InfoType.



11072
11073
11074
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the information type. Either a name of your choosing when creating a CustomInfoType, or one of the names listed at https://cloud.google.com/ sensitive-data-protection/docs/infotypes-reference when specifying a built-in type. When sending Cloud DLP results to Data Catalog, infoType names should conform to the pattern [A-Za-z0-9$_-]1,64`. Corresponds to the JSON propertyname`

Returns:

  • (String)


11059
11060
11061
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11059

def name
  @name
end

#sensitivity_scoreGoogle::Apis::SecuritycenterV1::SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



11065
11066
11067
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11065

def sensitivity_score
  @sensitivity_score
end

#versionString

Optional version name for this InfoType. Corresponds to the JSON property version

Returns:

  • (String)


11070
11071
11072
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11070

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11077
11078
11079
11080
11081
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11077

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @version = args[:version] if args.key?(:version)
end