Class: Google::Apis::SecuritycenterV1::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



11933
11934
11935
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


11916
11917
11918
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11916

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


11921
11922
11923
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11921

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


11926
11927
11928
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11926

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


11931
11932
11933
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11931

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11938
11939
11940
11941
11942
11943
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11938

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end