Class: Google::Apis::SecuritycenterV1::Kubernetes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Kubernetes-related attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Kubernetes

Returns a new instance of Kubernetes.



11335
11336
11337
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reviewsArray<Google::Apis::SecuritycenterV1::AccessReview>

Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding. Corresponds to the JSON property accessReviews



11294
11295
11296
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11294

def access_reviews
  @access_reviews
end

#bindingsArray<Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1Binding>

Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings. Corresponds to the JSON property bindings



11301
11302
11303
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11301

def bindings
  @bindings
end

#node_poolsArray<Google::Apis::SecuritycenterV1::NodePool>

GKE node pools associated with the finding. This field contains node pool information for each node, when it is available. Corresponds to the JSON property nodePools



11308
11309
11310
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11308

def node_pools
  @node_pools
end

#nodesArray<Google::Apis::SecuritycenterV1::Node>

Provides Kubernetes node information. Corresponds to the JSON property nodes



11314
11315
11316
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11314

def nodes
  @nodes
end

#objectsArray<Google::Apis::SecuritycenterV1::Object>

Kubernetes objects related to the finding. Corresponds to the JSON property objects



11319
11320
11321
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11319

def objects
  @objects
end

#podsArray<Google::Apis::SecuritycenterV1::Pod>

Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod. Corresponds to the JSON property pods



11326
11327
11328
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11326

def pods
  @pods
end

#rolesArray<Google::Apis::SecuritycenterV1::Role>

Provides Kubernetes role information for findings that involve Roles or ClusterRoles. Corresponds to the JSON property roles



11333
11334
11335
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11333

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11340
11341
11342
11343
11344
11345
11346
11347
11348
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11340

def update!(**args)
  @access_reviews = args[:access_reviews] if args.key?(:access_reviews)
  @bindings = args[:bindings] if args.key?(:bindings)
  @node_pools = args[:node_pools] if args.key?(:node_pools)
  @nodes = args[:nodes] if args.key?(:nodes)
  @objects = args[:objects] if args.key?(:objects)
  @pods = args[:pods] if args.key?(:pods)
  @roles = args[:roles] if args.key?(:roles)
end