Class: Google::Apis::SecuritycenterV1::ListAssetsResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Result containing the Asset and its State.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAssetsResult

Returns a new instance of ListAssetsResult.



12177
12178
12179
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetGoogle::Apis::SecuritycenterV1::Asset

Security Command Center representation of a Google Cloud resource. The Asset is a Security Command Center resource that captures information about a single Google Cloud resource. All modifications to an Asset are only within the context of Security Command Center and don't affect the referenced Google Cloud resource. Corresponds to the JSON property asset



12170
12171
12172
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12170

def asset
  @asset
end

#state_changeString

State change of the asset between the points in time. Corresponds to the JSON property stateChange

Returns:

  • (String)


12175
12176
12177
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12175

def state_change
  @state_change
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12182
12183
12184
12185
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12182

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @state_change = args[:state_change] if args.key?(:state_change)
end