Class: Google::Apis::SecuritycenterV1::ListAssetsResult
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::ListAssetsResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Result containing the Asset and its State.
Instance Attribute Summary collapse
-
#asset ⇒ Google::Apis::SecuritycenterV1::Asset
Security Command Center representation of a Google Cloud resource.
-
#state_change ⇒ String
State change of the asset between the points in time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAssetsResult
constructor
A new instance of ListAssetsResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAssetsResult
Returns a new instance of ListAssetsResult.
11436 11437 11438 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ Google::Apis::SecuritycenterV1::Asset
Security Command Center representation of a Google Cloud resource. The Asset
is a Security Command Center resource that captures information about a single
Google Cloud resource. All modifications to an Asset are only within the
context of Security Command Center and don't affect the referenced Google
Cloud resource.
Corresponds to the JSON property asset
11429 11430 11431 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11429 def asset @asset end |
#state_change ⇒ String
State change of the asset between the points in time.
Corresponds to the JSON property stateChange
11434 11435 11436 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11434 def state_change @state_change end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11441 11442 11443 11444 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 11441 def update!(**args) @asset = args[:asset] if args.key?(:asset) @state_change = args[:state_change] if args.key?(:state_change) end |