Class: Google::Apis::SecuritycenterV1::Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Object

Returns a new instance of Object.



12232
12233
12234
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1::Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



12207
12208
12209
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12207

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


12212
12213
12214
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12212

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


12217
12218
12219
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12217

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


12223
12224
12225
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12223

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


12230
12231
12232
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12230

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12237
12238
12239
12240
12241
12242
12243
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12237

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end