Class: Google::Apis::SecuritycenterV1::OrganizationSettings
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::OrganizationSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
User specified settings that are attached to the Security Command Center organization.
Instance Attribute Summary collapse
-
#asset_discovery_config ⇒ Google::Apis::SecuritycenterV1::AssetDiscoveryConfig
The configuration used for Asset Discovery runs.
-
#enable_asset_discovery ⇒ Boolean
(also: #enable_asset_discovery?)
A flag that indicates if Asset Discovery should be enabled.
-
#name ⇒ String
The relative resource name of the settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrganizationSettings
constructor
A new instance of OrganizationSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrganizationSettings
Returns a new instance of OrganizationSettings.
13094 13095 13096 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_discovery_config ⇒ Google::Apis::SecuritycenterV1::AssetDiscoveryConfig
The configuration used for Asset Discovery runs.
Corresponds to the JSON property assetDiscoveryConfig
13077 13078 13079 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13077 def asset_discovery_config @asset_discovery_config end |
#enable_asset_discovery ⇒ Boolean Also known as: enable_asset_discovery?
A flag that indicates if Asset Discovery should be enabled. If the flag is set
to true, then discovery of assets will occur. If it is set to false, all
historical assets will remain, but discovery of future assets will not occur.
Corresponds to the JSON property enableAssetDiscovery
13084 13085 13086 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13084 def enable_asset_discovery @enable_asset_discovery end |
#name ⇒ String
The relative resource name of the settings. See: https://cloud.google.com/apis/
design/resource_names#relative_resource_name Example: "organizations/
organization_id/organizationSettings".
Corresponds to the JSON property name
13092 13093 13094 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13092 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13099 13100 13101 13102 13103 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13099 def update!(**args) @asset_discovery_config = args[:asset_discovery_config] if args.key?(:asset_discovery_config) @enable_asset_discovery = args[:enable_asset_discovery] if args.key?(:enable_asset_discovery) @name = args[:name] if args.key?(:name) end |