Class: Google::Apis::SecuritycenterV1::OrganizationSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

User specified settings that are attached to the Security Command Center organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationSettings

Returns a new instance of OrganizationSettings.



12353
12354
12355
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_discovery_configGoogle::Apis::SecuritycenterV1::AssetDiscoveryConfig

The configuration used for Asset Discovery runs. Corresponds to the JSON property assetDiscoveryConfig



12336
12337
12338
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12336

def asset_discovery_config
  @asset_discovery_config
end

#enable_asset_discoveryBoolean Also known as: enable_asset_discovery?

A flag that indicates if Asset Discovery should be enabled. If the flag is set to true, then discovery of assets will occur. If it is set to false, all historical assets will remain, but discovery of future assets will not occur. Corresponds to the JSON property enableAssetDiscovery

Returns:

  • (Boolean)


12343
12344
12345
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12343

def enable_asset_discovery
  @enable_asset_discovery
end

#nameString

The relative resource name of the settings. See: https://cloud.google.com/apis/ design/resource_names#relative_resource_name Example: "organizations/ organization_id/organizationSettings". Corresponds to the JSON property name

Returns:

  • (String)


12351
12352
12353
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12351

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12358
12359
12360
12361
12362
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12358

def update!(**args)
  @asset_discovery_config = args[:asset_discovery_config] if args.key?(:asset_discovery_config)
  @enable_asset_discovery = args[:enable_asset_discovery] if args.key?(:enable_asset_discovery)
  @name = args[:name] if args.key?(:name)
end