Class: Google::Apis::SecuritycenterV1::Package
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::Package
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Package is a generic definition of a package.
Instance Attribute Summary collapse
-
#cpe_uri ⇒ String
The CPE URI where the vulnerability was detected.
-
#package_name ⇒ String
The name of the package where the vulnerability was detected.
-
#package_type ⇒ String
Type of package, for example, os, maven, or go.
-
#package_version ⇒ String
The version of the package.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Package
constructor
A new instance of Package.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Package
Returns a new instance of Package.
12389 12390 12391 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpe_uri ⇒ String
The CPE URI where the vulnerability was detected.
Corresponds to the JSON property cpeUri
12372 12373 12374 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12372 def cpe_uri @cpe_uri end |
#package_name ⇒ String
The name of the package where the vulnerability was detected.
Corresponds to the JSON property packageName
12377 12378 12379 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12377 def package_name @package_name end |
#package_type ⇒ String
Type of package, for example, os, maven, or go.
Corresponds to the JSON property packageType
12382 12383 12384 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12382 def package_type @package_type end |
#package_version ⇒ String
The version of the package.
Corresponds to the JSON property packageVersion
12387 12388 12389 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12387 def package_version @package_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12394 12395 12396 12397 12398 12399 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12394 def update!(**args) @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri) @package_name = args[:package_name] if args.key?(:package_name) @package_type = args[:package_type] if args.key?(:package_type) @package_version = args[:package_version] if args.key?(:package_version) end |