Class: Google::Apis::SecuritycenterV1::PathNodeAssociatedFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A finding that is associated with this node in the attack path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PathNodeAssociatedFinding

Returns a new instance of PathNodeAssociatedFinding.



13163
13164
13165
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_findingString

Canonical name of the associated findings. Example: organizations/123/sources/ 456/findings/789 Corresponds to the JSON property canonicalFinding

Returns:

  • (String)


13151
13152
13153
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13151

def canonical_finding
  @canonical_finding
end

#finding_categoryString

The additional taxonomy group within findings from a given source. Corresponds to the JSON property findingCategory

Returns:

  • (String)


13156
13157
13158
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13156

def finding_category
  @finding_category
end

#nameString

Full resource name of the finding. Corresponds to the JSON property name

Returns:

  • (String)


13161
13162
13163
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13161

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13168
13169
13170
13171
13172
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13168

def update!(**args)
  @canonical_finding = args[:canonical_finding] if args.key?(:canonical_finding)
  @finding_category = args[:finding_category] if args.key?(:finding_category)
  @name = args[:name] if args.key?(:name)
end