Class: Google::Apis::SecuritycenterV1::Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Information related to the Google Cloud resource that is associated with this finding.
Instance Attribute Summary collapse
-
#adc_application ⇒ Google::Apis::SecuritycenterV1::AdcApplication
Represents an ADC application associated with the finding.
-
#adc_application_template ⇒ Google::Apis::SecuritycenterV1::AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
-
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1::AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
-
#display_name ⇒ String
The human readable name of the resource.
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Contains a Folder message for each folder in the assets ancestry.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#organization ⇒ String
Indicates which organization / tenant the finding is for.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#parent_name ⇒ String
The full resource name of resource's parent.
-
#project_display_name ⇒ String
The project ID that the resource belongs to.
-
#project_name ⇒ String
The full resource name of project that the resource belongs to.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1::ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The service or resource provider associated with the resource.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Resource
constructor
A new instance of Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Resource
Returns a new instance of Resource.
13762 13763 13764 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adc_application ⇒ Google::Apis::SecuritycenterV1::AdcApplication
Represents an ADC application associated with the finding.
Corresponds to the JSON property adcApplication
13652 13653 13654 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13652 def adc_application @adc_application end |
#adc_application_template ⇒ Google::Apis::SecuritycenterV1::AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
Corresponds to the JSON property adcApplicationTemplate
13657 13658 13659 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13657 def adc_application_template @adc_application_template end |
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1::AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
Corresponds to the JSON property adcSharedTemplate
13662 13663 13664 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13662 def adc_shared_template @adc_shared_template end |
#application ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
13667 13668 13669 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13667 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
13673 13674 13675 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13673 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
13679 13680 13681 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13679 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the finding is from.
Corresponds to the JSON property cloudProvider
13684 13685 13686 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13684 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
13689 13690 13691 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13689 def display_name @display_name end |
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Contains a Folder message for each folder in the assets ancestry. The first
folder is the deepest nested folder, and the last folder is the folder
directly under the Organization.
Corresponds to the JSON property folders
13696 13697 13698 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13696 def folders @folders end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
13701 13702 13703 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13701 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
13707 13708 13709 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13707 def name @name end |
#organization ⇒ String
Indicates which organization / tenant the finding is for.
Corresponds to the JSON property organization
13712 13713 13714 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13712 def organization @organization end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
13717 13718 13719 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13717 def parent_display_name @parent_display_name end |
#parent_name ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parentName
13722 13723 13724 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13722 def parent_name @parent_name end |
#project_display_name ⇒ String
The project ID that the resource belongs to.
Corresponds to the JSON property projectDisplayName
13727 13728 13729 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13727 def project_display_name @project_display_name end |
#project_name ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property projectName
13732 13733 13734 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13732 def project_name @project_name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1::ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
13738 13739 13740 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13738 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of org/organization_id/folder/folder_id/folder/folder_id/project/
project_idwhere there can be any number of folders. For AWS, it has the
format of `org/`organization_id`/ou/`organizational_unit_id`/ou/`
organizational_unit_id`/account/`account_id where there can be any number of
organizational units. For Azure, it has the format of mg/management_group_id
/mg/management_group_id/subscription/subscription_id/rg/
resource_group_name`where there can be any number of management groups.
Corresponds to the JSON propertyresourcePathString`
13750 13751 13752 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13750 def resource_path_string @resource_path_string end |
#service ⇒ String
The service or resource provider associated with the resource.
Corresponds to the JSON property service
13755 13756 13757 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13755 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
13760 13761 13762 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13760 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13767 13768 13769 13770 13771 13772 13773 13774 13775 13776 13777 13778 13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13767 def update!(**args) @adc_application = args[:adc_application] if args.key?(:adc_application) @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template) @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @folders = args[:folders] if args.key?(:folders) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @organization = args[:organization] if args.key?(:organization) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @parent_name = args[:parent_name] if args.key?(:parent_name) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) @project_name = args[:project_name] if args.key?(:project_name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |