Class: Google::Apis::SecuritycenterV1::Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information related to the Google Cloud resource that is associated with this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Resource

Returns a new instance of Resource.



12963
12964
12965
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#applicationGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



12868
12869
12870
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12868

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1::AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



12874
12875
12876
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12874

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1::AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



12880
12881
12882
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12880

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the finding is from. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


12885
12886
12887
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12885

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


12890
12891
12892
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12890

def display_name
  @display_name
end

#foldersArray<Google::Apis::SecuritycenterV1::Folder>

Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



12897
12898
12899
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12897

def folders
  @folders
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


12902
12903
12904
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12902

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


12908
12909
12910
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12908

def name
  @name
end

#organizationString

Indicates which organization / tenant the finding is for. Corresponds to the JSON property organization

Returns:

  • (String)


12913
12914
12915
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12913

def organization
  @organization
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


12918
12919
12920
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12918

def parent_display_name
  @parent_display_name
end

#parent_nameString

The full resource name of resource's parent. Corresponds to the JSON property parentName

Returns:

  • (String)


12923
12924
12925
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12923

def parent_name
  @parent_name
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


12928
12929
12930
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12928

def project_display_name
  @project_display_name
end

#project_nameString

The full resource name of project that the resource belongs to. Corresponds to the JSON property projectName

Returns:

  • (String)


12933
12934
12935
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12933

def project_name
  @project_name
end

#resource_pathGoogle::Apis::SecuritycenterV1::ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



12939
12940
12941
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12939

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of org/organization_id/folder/folder_id/folder/folder_id/project/ project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/`organizational_unit_id`/ou/` organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id /mg/management_group_id/subscription/subscription_id/rg/ resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


12951
12952
12953
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12951

def resource_path_string
  @resource_path_string
end

#serviceString

The service or resource provider associated with the resource. Corresponds to the JSON property service

Returns:

  • (String)


12956
12957
12958
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12956

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


12961
12962
12963
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12961

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12968
12969
12970
12971
12972
12973
12974
12975
12976
12977
12978
12979
12980
12981
12982
12983
12984
12985
12986
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 12968

def update!(**args)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @folders = args[:folders] if args.key?(:folders)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @organization = args[:organization] if args.key?(:organization)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @parent_name = args[:parent_name] if args.key?(:parent_name)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
  @project_name = args[:project_name] if args.key?(:project_name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end