Class: Google::Apis::SecuritycenterV1::SecurityCenterProperties
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::SecurityCenterProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Security Command Center managed properties. These properties are managed by Security Command Center and cannot be modified by the user.
Instance Attribute Summary collapse
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Contains a Folder message for each folder in the assets ancestry.
-
#resource_display_name ⇒ String
The user defined display name for this resource.
-
#resource_name ⇒ String
The full resource name of the Google Cloud resource this asset represents.
-
#resource_owners ⇒ Array<String>
Owners of the Google Cloud resource.
-
#resource_parent ⇒ String
The full resource name of the immediate parent of the resource.
-
#resource_parent_display_name ⇒ String
The user defined display name for the parent of this resource.
-
#resource_project ⇒ String
The full resource name of the project the resource belongs to.
-
#resource_project_display_name ⇒ String
The user defined display name for the project of this resource.
-
#resource_type ⇒ String
The type of the Google Cloud resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityCenterProperties
constructor
A new instance of SecurityCenterProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityCenterProperties
Returns a new instance of SecurityCenterProperties.
14269 14270 14271 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14269 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Contains a Folder message for each folder in the assets ancestry. The first
folder is the deepest nested folder, and the last folder is the folder
directly under the Organization.
Corresponds to the JSON property folders
14221 14222 14223 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14221 def folders @folders end |
#resource_display_name ⇒ String
The user defined display name for this resource.
Corresponds to the JSON property resourceDisplayName
14226 14227 14228 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14226 def resource_display_name @resource_display_name end |
#resource_name ⇒ String
The full resource name of the Google Cloud resource this asset represents.
This field is immutable after create time. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property resourceName
14233 14234 14235 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14233 def resource_name @resource_name end |
#resource_owners ⇒ Array<String>
Owners of the Google Cloud resource.
Corresponds to the JSON property resourceOwners
14238 14239 14240 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14238 def resource_owners @resource_owners end |
#resource_parent ⇒ String
The full resource name of the immediate parent of the resource. See: https://
cloud.google.com/apis/design/resource_names#full_resource_name
Corresponds to the JSON property resourceParent
14244 14245 14246 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14244 def resource_parent @resource_parent end |
#resource_parent_display_name ⇒ String
The user defined display name for the parent of this resource.
Corresponds to the JSON property resourceParentDisplayName
14249 14250 14251 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14249 def resource_parent_display_name @resource_parent_display_name end |
#resource_project ⇒ String
The full resource name of the project the resource belongs to. See: https://
cloud.google.com/apis/design/resource_names#full_resource_name
Corresponds to the JSON property resourceProject
14255 14256 14257 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14255 def resource_project @resource_project end |
#resource_project_display_name ⇒ String
The user defined display name for the project of this resource.
Corresponds to the JSON property resourceProjectDisplayName
14260 14261 14262 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14260 def resource_project_display_name @resource_project_display_name end |
#resource_type ⇒ String
The type of the Google Cloud resource. Examples include: APPLICATION, PROJECT,
and ORGANIZATION. This is a case insensitive field defined by Security Command
Center and/or the producer of the resource and is immutable after create time.
Corresponds to the JSON property resourceType
14267 14268 14269 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14267 def resource_type @resource_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14274 14275 14276 14277 14278 14279 14280 14281 14282 14283 14284 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14274 def update!(**args) @folders = args[:folders] if args.key?(:folders) @resource_display_name = args[:resource_display_name] if args.key?(:resource_display_name) @resource_name = args[:resource_name] if args.key?(:resource_name) @resource_owners = args[:resource_owners] if args.key?(:resource_owners) @resource_parent = args[:resource_parent] if args.key?(:resource_parent) @resource_parent_display_name = args[:resource_parent_display_name] if args.key?(:resource_parent_display_name) @resource_project = args[:resource_project] if args.key?(:resource_project) @resource_project_display_name = args[:resource_project_display_name] if args.key?(:resource_project_display_name) @resource_type = args[:resource_type] if args.key?(:resource_type) end |