Class: Google::Apis::SecuritycenterV1::SecurityCenterProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Security Command Center managed properties. These properties are managed by Security Command Center and cannot be modified by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityCenterProperties

Returns a new instance of SecurityCenterProperties.



14099
14100
14101
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#foldersArray<Google::Apis::SecuritycenterV1::Folder>

Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



14051
14052
14053
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14051

def folders
  @folders
end

#resource_display_nameString

The user defined display name for this resource. Corresponds to the JSON property resourceDisplayName

Returns:

  • (String)


14056
14057
14058
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14056

def resource_display_name
  @resource_display_name
end

#resource_nameString

The full resource name of the Google Cloud resource this asset represents. This field is immutable after create time. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property resourceName

Returns:

  • (String)


14063
14064
14065
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14063

def resource_name
  @resource_name
end

#resource_ownersArray<String>

Owners of the Google Cloud resource. Corresponds to the JSON property resourceOwners

Returns:

  • (Array<String>)


14068
14069
14070
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14068

def resource_owners
  @resource_owners
end

#resource_parentString

The full resource name of the immediate parent of the resource. See: https:// cloud.google.com/apis/design/resource_names#full_resource_name Corresponds to the JSON property resourceParent

Returns:

  • (String)


14074
14075
14076
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14074

def resource_parent
  @resource_parent
end

#resource_parent_display_nameString

The user defined display name for the parent of this resource. Corresponds to the JSON property resourceParentDisplayName

Returns:

  • (String)


14079
14080
14081
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14079

def resource_parent_display_name
  @resource_parent_display_name
end

#resource_projectString

The full resource name of the project the resource belongs to. See: https:// cloud.google.com/apis/design/resource_names#full_resource_name Corresponds to the JSON property resourceProject

Returns:

  • (String)


14085
14086
14087
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14085

def resource_project
  @resource_project
end

#resource_project_display_nameString

The user defined display name for the project of this resource. Corresponds to the JSON property resourceProjectDisplayName

Returns:

  • (String)


14090
14091
14092
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14090

def resource_project_display_name
  @resource_project_display_name
end

#resource_typeString

The type of the Google Cloud resource. Examples include: APPLICATION, PROJECT, and ORGANIZATION. This is a case insensitive field defined by Security Command Center and/or the producer of the resource and is immutable after create time. Corresponds to the JSON property resourceType

Returns:

  • (String)


14097
14098
14099
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14097

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14104
14105
14106
14107
14108
14109
14110
14111
14112
14113
14114
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14104

def update!(**args)
  @folders = args[:folders] if args.key?(:folders)
  @resource_display_name = args[:resource_display_name] if args.key?(:resource_display_name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_owners = args[:resource_owners] if args.key?(:resource_owners)
  @resource_parent = args[:resource_parent] if args.key?(:resource_parent)
  @resource_parent_display_name = args[:resource_parent_display_name] if args.key?(:resource_parent_display_name)
  @resource_project = args[:resource_project] if args.key?(:resource_project)
  @resource_project_display_name = args[:resource_project_display_name] if args.key?(:resource_project_display_name)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end