Class: Google::Apis::SecuritycenterV1::SecurityCenterProperties
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::SecurityCenterProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Security Command Center managed properties. These properties are managed by Security Command Center and cannot be modified by the user.
Instance Attribute Summary collapse
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Contains a Folder message for each folder in the assets ancestry.
-
#resource_display_name ⇒ String
The user defined display name for this resource.
-
#resource_name ⇒ String
The full resource name of the Google Cloud resource this asset represents.
-
#resource_owners ⇒ Array<String>
Owners of the Google Cloud resource.
-
#resource_parent ⇒ String
The full resource name of the immediate parent of the resource.
-
#resource_parent_display_name ⇒ String
The user defined display name for the parent of this resource.
-
#resource_project ⇒ String
The full resource name of the project the resource belongs to.
-
#resource_project_display_name ⇒ String
The user defined display name for the project of this resource.
-
#resource_type ⇒ String
The type of the Google Cloud resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityCenterProperties
constructor
A new instance of SecurityCenterProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityCenterProperties
Returns a new instance of SecurityCenterProperties.
13297 13298 13299 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folders ⇒ Array<Google::Apis::SecuritycenterV1::Folder>
Contains a Folder message for each folder in the assets ancestry. The first
folder is the deepest nested folder, and the last folder is the folder
directly under the Organization.
Corresponds to the JSON property folders
13249 13250 13251 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13249 def folders @folders end |
#resource_display_name ⇒ String
The user defined display name for this resource.
Corresponds to the JSON property resourceDisplayName
13254 13255 13256 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13254 def resource_display_name @resource_display_name end |
#resource_name ⇒ String
The full resource name of the Google Cloud resource this asset represents.
This field is immutable after create time. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property resourceName
13261 13262 13263 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13261 def resource_name @resource_name end |
#resource_owners ⇒ Array<String>
Owners of the Google Cloud resource.
Corresponds to the JSON property resourceOwners
13266 13267 13268 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13266 def resource_owners @resource_owners end |
#resource_parent ⇒ String
The full resource name of the immediate parent of the resource. See: https://
cloud.google.com/apis/design/resource_names#full_resource_name
Corresponds to the JSON property resourceParent
13272 13273 13274 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13272 def resource_parent @resource_parent end |
#resource_parent_display_name ⇒ String
The user defined display name for the parent of this resource.
Corresponds to the JSON property resourceParentDisplayName
13277 13278 13279 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13277 def resource_parent_display_name @resource_parent_display_name end |
#resource_project ⇒ String
The full resource name of the project the resource belongs to. See: https://
cloud.google.com/apis/design/resource_names#full_resource_name
Corresponds to the JSON property resourceProject
13283 13284 13285 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13283 def resource_project @resource_project end |
#resource_project_display_name ⇒ String
The user defined display name for the project of this resource.
Corresponds to the JSON property resourceProjectDisplayName
13288 13289 13290 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13288 def resource_project_display_name @resource_project_display_name end |
#resource_type ⇒ String
The type of the Google Cloud resource. Examples include: APPLICATION, PROJECT,
and ORGANIZATION. This is a case insensitive field defined by Security Command
Center and/or the producer of the resource and is immutable after create time.
Corresponds to the JSON property resourceType
13295 13296 13297 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13295 def resource_type @resource_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13302 13303 13304 13305 13306 13307 13308 13309 13310 13311 13312 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13302 def update!(**args) @folders = args[:folders] if args.key?(:folders) @resource_display_name = args[:resource_display_name] if args.key?(:resource_display_name) @resource_name = args[:resource_name] if args.key?(:resource_name) @resource_owners = args[:resource_owners] if args.key?(:resource_owners) @resource_parent = args[:resource_parent] if args.key?(:resource_parent) @resource_parent_display_name = args[:resource_parent_display_name] if args.key?(:resource_parent_display_name) @resource_project = args[:resource_project] if args.key?(:resource_project) @resource_project_display_name = args[:resource_project_display_name] if args.key?(:resource_project_display_name) @resource_type = args[:resource_type] if args.key?(:resource_type) end |