Class: Google::Apis::SecuritycenterV1::SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SensitivityScore

Returns a new instance of SensitivityScore.



13476
13477
13478
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


13474
13475
13476
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13474

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13481
13482
13483
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13481

def update!(**args)
  @score = args[:score] if args.key?(:score)
end