Class: Google::Apis::SecuritycenterV1::SensitivityScore
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::SensitivityScore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.
Instance Attribute Summary collapse
-
#score ⇒ String
The sensitivity score applied to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SensitivityScore
constructor
A new instance of SensitivityScore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SensitivityScore
Returns a new instance of SensitivityScore.
13476 13477 13478 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#score ⇒ String
The sensitivity score applied to the resource.
Corresponds to the JSON property score
13474 13475 13476 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13474 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13481 13482 13483 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13481 def update!(**args) @score = args[:score] if args.key?(:score) end |