Class: Google::Apis::SecuritycenterV1::SimulateSecurityHealthAnalyticsCustomModuleRequest
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::SimulateSecurityHealthAnalyticsCustomModuleRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Request message to simulate a CustomConfig against a given test resource. Maximum size of the request is 4 MB by default.
Instance Attribute Summary collapse
-
#custom_config ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1CustomConfig
Defines the properties in a custom module configuration for Security Health Analytics.
-
#resource ⇒ Google::Apis::SecuritycenterV1::SimulatedResource
Manually constructed resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SimulateSecurityHealthAnalyticsCustomModuleRequest
constructor
A new instance of SimulateSecurityHealthAnalyticsCustomModuleRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SimulateSecurityHealthAnalyticsCustomModuleRequest
Returns a new instance of SimulateSecurityHealthAnalyticsCustomModuleRequest.
14606 14607 14608 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_config ⇒ Google::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1CustomConfig
Defines the properties in a custom module configuration for Security Health
Analytics. Use the custom module configuration to create custom detectors that
generate custom findings for resources that you specify.
Corresponds to the JSON property customConfig
14597 14598 14599 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14597 def custom_config @custom_config end |
#resource ⇒ Google::Apis::SecuritycenterV1::SimulatedResource
Manually constructed resource name. If the custom module evaluates against
only the resource data, you can omit the iam_policy_data field. If it
evaluates only the iam_policy_data field, you can omit the resource data.
Corresponds to the JSON property resource
14604 14605 14606 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14604 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14611 14612 14613 14614 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14611 def update!(**args) @custom_config = args[:custom_config] if args.key?(:custom_config) @resource = args[:resource] if args.key?(:resource) end |