Class: Google::Apis::SecuritycenterV1::SimulateSecurityHealthAnalyticsCustomModuleRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Request message to simulate a CustomConfig against a given test resource. Maximum size of the request is 4 MB by default.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SimulateSecurityHealthAnalyticsCustomModuleRequest

Returns a new instance of SimulateSecurityHealthAnalyticsCustomModuleRequest.



14436
14437
14438
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_configGoogle::Apis::SecuritycenterV1::GoogleCloudSecuritycenterV1CustomConfig

Defines the properties in a custom module configuration for Security Health Analytics. Use the custom module configuration to create custom detectors that generate custom findings for resources that you specify. Corresponds to the JSON property customConfig



14427
14428
14429
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14427

def custom_config
  @custom_config
end

#resourceGoogle::Apis::SecuritycenterV1::SimulatedResource

Manually constructed resource name. If the custom module evaluates against only the resource data, you can omit the iam_policy_data field. If it evaluates only the iam_policy_data field, you can omit the resource data. Corresponds to the JSON property resource



14434
14435
14436
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14434

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14441
14442
14443
14444
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14441

def update!(**args)
  @custom_config = args[:custom_config] if args.key?(:custom_config)
  @resource = args[:resource] if args.key?(:resource)
end