Class: Google::Apis::SecuritycenterV1::SimulatedResult
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::SimulatedResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
Possible test result.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::SecuritycenterV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#finding ⇒ Google::Apis::SecuritycenterV1::Finding
Security Command Center finding.
-
#no_violation ⇒ Google::Apis::SecuritycenterV1::Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SimulatedResult
constructor
A new instance of SimulatedResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SimulatedResult
Returns a new instance of SimulatedResult.
14558 14559 14560 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::SecuritycenterV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
14539 14540 14541 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14539 def error @error end |
#finding ⇒ Google::Apis::SecuritycenterV1::Finding
Security Command Center finding. A finding is a record of assessment data like
security, risk, health, or privacy, that is ingested into Security Command
Center for presentation, notification, analysis, policy testing, and
enforcement. For example, a cross-site scripting (XSS) vulnerability in an App
Engine application is a finding.
Corresponds to the JSON property finding
14548 14549 14550 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14548 def finding @finding end |
#no_violation ⇒ Google::Apis::SecuritycenterV1::Empty
A generic empty message that you can re-use to avoid defining duplicated empty
messages in your APIs. A typical example is to use it as the request or the
response type of an API method. For instance: service Foo rpc Bar(google.
protobuf.Empty) returns (google.protobuf.Empty);
Corresponds to the JSON property noViolation
14556 14557 14558 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14556 def no_violation @no_violation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14563 14564 14565 14566 14567 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14563 def update!(**args) @error = args[:error] if args.key?(:error) @finding = args[:finding] if args.key?(:finding) @no_violation = args[:no_violation] if args.key?(:no_violation) end |