Class: Google::Apis::SecuritycenterV1::StaticMute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information about the static mute state. A static mute state overrides any dynamic mute rules that apply to this finding. The static mute state can be set by a static mute rule or by muting the finding directly.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StaticMute

Returns a new instance of StaticMute.



13874
13875
13876
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apply_timeString

When the static mute was applied. Corresponds to the JSON property applyTime

Returns:

  • (String)


13866
13867
13868
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13866

def apply_time
  @apply_time
end

#stateString

The static mute state. If the value is MUTED or UNMUTED, then the finding' s overall mute state will have the same value. Corresponds to the JSON property state

Returns:

  • (String)


13872
13873
13874
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13872

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13879
13880
13881
13882
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 13879

def update!(**args)
  @apply_time = args[:apply_time] if args.key?(:apply_time)
  @state = args[:state] if args.key?(:state)
end