Class: Google::Apis::SecuritycenterV1::TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketInfo

Returns a new instance of TicketInfo.



14861
14862
14863
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


14834
14835
14836
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14834

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


14839
14840
14841
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14839

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


14844
14845
14846
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14844

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


14849
14850
14851
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14849

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


14854
14855
14856
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14854

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


14859
14860
14861
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14859

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14866
14867
14868
14869
14870
14871
14872
14873
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14866

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end