Class: Google::Apis::SecuritycenterV1::TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketInfo

Returns a new instance of TicketInfo.



14059
14060
14061
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


14032
14033
14034
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14032

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


14037
14038
14039
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14037

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


14042
14043
14044
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14042

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


14047
14048
14049
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14047

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


14052
14053
14054
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14052

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


14057
14058
14059
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14057

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14064
14065
14066
14067
14068
14069
14070
14071
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14064

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end