Class: Google::Apis::SecuritycenterV1::ValuedResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb

Overview

A resource that is determined to have value to a user's system

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValuedResource

Returns a new instance of ValuedResource.



14997
14998
14999
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Human-readable name of the valued resource. Corresponds to the JSON property displayName

Returns:

  • (String)


14960
14961
14962
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14960

def display_name
  @display_name
end

#exposed_scoreFloat

Exposed score for this valued resource. A value of 0 means no exposure was detected exposure. Corresponds to the JSON property exposedScore

Returns:

  • (Float)


14966
14967
14968
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14966

def exposed_score
  @exposed_score
end

#nameString

Valued resource name, for example, e.g.: organizations/123/simulations/456/ valuedResources/789 Corresponds to the JSON property name

Returns:

  • (String)


14972
14973
14974
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14972

def name
  @name
end

#resourceString

The full resource name of the valued resource. Corresponds to the JSON property resource

Returns:

  • (String)


14978
14979
14980
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14978

def resource
  @resource
end

#resource_typeString

The resource type of the valued resource. Corresponds to the JSON property resourceType

Returns:

  • (String)


14984
14985
14986
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14984

def resource_type
  @resource_type
end

#resource_valueString

How valuable this resource is. Corresponds to the JSON property resourceValue

Returns:

  • (String)


14989
14990
14991
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14989

def resource_value
  @resource_value
end

#resource_value_configs_usedArray<Google::Apis::SecuritycenterV1::ResourceValueConfigMetadata>

List of resource value configurations' metadata used to determine the value of this resource. Maximum of 100. Corresponds to the JSON property resourceValueConfigsUsed



14995
14996
14997
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14995

def resource_value_configs_used
  @resource_value_configs_used
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15002
15003
15004
15005
15006
15007
15008
15009
15010
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 15002

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exposed_score = args[:exposed_score] if args.key?(:exposed_score)
  @name = args[:name] if args.key?(:name)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @resource_value = args[:resource_value] if args.key?(:resource_value)
  @resource_value_configs_used = args[:resource_value_configs_used] if args.key?(:resource_value_configs_used)
end