Class: Google::Apis::SecuritycenterV1::ValuedResource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1::ValuedResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1/classes.rb,
lib/google/apis/securitycenter_v1/representations.rb,
lib/google/apis/securitycenter_v1/representations.rb
Overview
A resource that is determined to have value to a user's system
Instance Attribute Summary collapse
-
#display_name ⇒ String
Human-readable name of the valued resource.
-
#exposed_score ⇒ Float
Exposed score for this valued resource.
-
#name ⇒ String
Valued resource name, for example, e.g.:
organizations/123/simulations/456/ valuedResources/789Corresponds to the JSON propertyname. -
#resource ⇒ String
The full resource name of the valued resource.
-
#resource_type ⇒ String
The resource type of the valued resource.
-
#resource_value ⇒ String
How valuable this resource is.
-
#resource_value_configs_used ⇒ Array<Google::Apis::SecuritycenterV1::ResourceValueConfigMetadata>
List of resource value configurations' metadata used to determine the value of this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ValuedResource
constructor
A new instance of ValuedResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ValuedResource
Returns a new instance of ValuedResource.
14195 14196 14197 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Human-readable name of the valued resource.
Corresponds to the JSON property displayName
14158 14159 14160 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14158 def display_name @display_name end |
#exposed_score ⇒ Float
Exposed score for this valued resource. A value of 0 means no exposure was
detected exposure.
Corresponds to the JSON property exposedScore
14164 14165 14166 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14164 def exposed_score @exposed_score end |
#name ⇒ String
Valued resource name, for example, e.g.: organizations/123/simulations/456/
valuedResources/789
Corresponds to the JSON property name
14170 14171 14172 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14170 def name @name end |
#resource ⇒ String
The full resource name of the valued resource.
Corresponds to the JSON property resource
14176 14177 14178 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14176 def resource @resource end |
#resource_type ⇒ String
The resource type of the valued resource.
Corresponds to the JSON property resourceType
14182 14183 14184 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14182 def resource_type @resource_type end |
#resource_value ⇒ String
How valuable this resource is.
Corresponds to the JSON property resourceValue
14187 14188 14189 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14187 def resource_value @resource_value end |
#resource_value_configs_used ⇒ Array<Google::Apis::SecuritycenterV1::ResourceValueConfigMetadata>
List of resource value configurations' metadata used to determine the value of
this resource. Maximum of 100.
Corresponds to the JSON property resourceValueConfigsUsed
14193 14194 14195 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14193 def resource_value_configs_used @resource_value_configs_used end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14200 14201 14202 14203 14204 14205 14206 14207 14208 |
# File 'lib/google/apis/securitycenter_v1/classes.rb', line 14200 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @exposed_score = args[:exposed_score] if args.key?(:exposed_score) @name = args[:name] if args.key?(:name) @resource = args[:resource] if args.key?(:resource) @resource_type = args[:resource_type] if args.key?(:resource_type) @resource_value = args[:resource_value] if args.key?(:resource_value) @resource_value_configs_used = args[:resource_value_configs_used] if args.key?(:resource_value_configs_used) end |